@@ -1,34 +1,33 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *
  *	University of Notre Dame LAM
- *	$Id: master.c,v 6.8 1999/09/01 18:24:24 jsquyres Exp $
+ *	$Id: master.c,v 6.9 2000/10/31 05:23:35 jsquyres Exp $
  *
  *	Function:	- master program of mandelbrot demo
  *			- distributes work orders to the slaves
@@ -67,9 +66,9 @@ struct sunras {					/* Sun raster file header */
 /*
  * local functions
  */
-static int		harvest();		/* gets results */
-static void		seed();			/* distributes work */
-static void		color_map();		/* generate color map */
+static int		harvest(void);		/* gets results */
+static void		seed(int rank, int x, int y); /* distributes work */
+static void		color_map(int fd);	/* generate color map */
 static void		check_endian(struct sunras *rasterfile);
 
 /*
@@ -83,11 +82,7 @@ static int		myrank;			/* compute task's rank */
 
 
 int
-main(argc, argv)
-
-int			argc;
-char			*argv[];
-
+main(int argc, char* argv[])
 {
 	float		grid_coord[4];		/* complex grid description */
 	float		init[4];		/* scale and translate data */
@@ -233,8 +228,7 @@ char			*argv[];
  *	Function:	- receives results from one slave
  * Returns: - slave's rank */
 static int
-harvest()
-
+harvest(void)
 {
 	int		len0, len1;		/* x,y dim region length */
 	int		i;
@@ -272,11 +266,7 @@ harvest()
  *	Function:	- sends out work request
  */
 static void
-seed(rank, x, y)
-
-int			rank;
-int			x, y;
-
+seed(int rank, int x, int y)
 {
 	int		work[4];	/* network message desc. */
 
@@ -301,10 +291,7 @@ int			x, y;
  *	Accepts:	- file descriptor
  */
 static void
-color_map(fd)
-
-int			fd;
-
+color_map(int fd)
 {
 	int		i;		/* color map index */
 	int		r, g, b;	/* individual color map indices */
