@@ -1,34 +1,33 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *
  *	University of Notre Dame LAM
- *	$Id: ezstart.c,v 6.4 1999/07/09 04:38:31 jsquyres Exp $
+ *	$Id: ezstart.c,v 6.5 2000/10/31 05:23:35 jsquyres Exp $
  *
  */
 
@@ -40,8 +39,12 @@
 #define DIETAG		2
 #define NUM_WORK_REQS	200
 
-static void		master();
-static void		slave();
+/*
+ * Local functions
+ */
+static void		master(void);
+static void		slave(void);
+
 
 /*
  * main
@@ -49,11 +52,7 @@ static void		slave();
  * simplicity in launching the application.
  */
 int
-main(argc, argv)
-
-int			argc;
-char			*argv[];
-
+main(int argc, char* argv[])
 {
 	int		myrank;
 
@@ -77,8 +76,7 @@ char			*argv[];
  * and collects results.
  */
 static void
-master()
-
+master(void)
 {
 	int		ntasks, rank, work;
 	double		result;
@@ -141,8 +139,7 @@ master()
  * results until a special termination request is received.
  */
 static void
-slave()
-
+slave(void)
 {
 	double		result;
 	int		work;
