@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB/RBD
  *
- *	$Id: bfctl.c,v 6.6 1999/06/12 17:11:12 kmeyer1 Exp $
+ *	$Id: bfctl.c,v 6.8 2000/10/12 00:21:58 jsquyres Exp $
  *
  *	Function:	- buffer daemon control command
  */
@@ -105,8 +104,8 @@ char			*argv[];
  * Initialize and attach to Trollius kernel.
  */
 	if (kinit(PRCMD)) {
-		terror("bfctl (kinit)");
-		exit(errno);
+	  show_help(NULL, "no-lamd", "bfctl", NULL);
+	  exit(errno);
 	}
 
 	if (nid_parse(&argc, argv) || (errno = (argc == 1) ? 0 : EUSAGE)) {
@@ -175,7 +174,7 @@ help()
 	printf("\t\t-s #\t\tSet buffer size.\n");
 	printf("\t\t-e <event>\tSweep messages of one event.\n");
 	printf("\t\t-R\t\tSweep all messages.\n");
-	mnusage();
+	nid_usage();
 	printf("\t\th (local), o (origin), N (all)\n");
 	printf("\nExample:	bfctl N -s 0x100000\n");
 	printf("\t\t\t\"Set max buffer space to 1M bytes on all nodes.\"\n");
