@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: bfstate.c,v 6.5 1999/06/12 17:11:13 kmeyer1 Exp $
+ *	$Id: bfstate.c,v 6.7 2000/10/12 00:21:55 jsquyres Exp $
  *
  *	Function:	- prints Trollius buffer status
  */
@@ -121,8 +120,8 @@ char   			*argv[];
  * Attach to kernel.
  */
 	if (kinit(PRCMD)) {
-		terror("bfstate (kinit)");
-		exit(errno);
+	  show_help(NULL, "no-lamd", "bfstate", NULL);
+	  exit(errno);
 	}
 
 	if (nid_parse(&argc, argv) || (errno = (argc == 1) ? 0 : EUSAGE)) {
@@ -192,8 +191,8 @@ int			nodeid;
 		}
 
 		if (totlength >= 0) {
-			printf("%-9.9s", mnemonic(nodeid));
-			printf(" %-9.9s", mnemonic(pi->bfs_node));
+			printf("%-9.9s", nid_fmt(nodeid));
+			printf(" %-9.9s", nid_fmt(pi->bfs_node));
 
 			if ((pi->bfs_flags & KSYNCSQL) ||
 					(((pi->bfs_event & 0xFFFF0000) != 0)
@@ -214,7 +213,7 @@ int			nodeid;
 	}
 
 	if (opt_taken('l')) {
-		printf("%-9.9s", mnemonic(nodeid));
+		printf("%-9.9s", nid_fmt(nodeid));
 		printf(" max space = %d, used space = %d\n",
 				parms.bfp_maxspace, parms.bfp_nspace);
 	}
@@ -236,7 +235,7 @@ help()
 	printf("\t\t-l	Also print buffer levels and maximums.\n");
 	printf("\t\t-p	Print each packet.\n");
 	printf("\t\t-B <#>	Set maximum # of messages to print.\n");
-	mnusage();
+	nid_usage();
 	printf("\t\th (local), o (origin), N (all)\n");
 	printf("\nExample:	bfstate h n3-9,11\n");
 	printf("\t\t\t\"Get buffer status information on the local\n");
