@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: fctl.c,v 6.5 1999/06/12 17:11:14 kmeyer1 Exp $
+ *	$Id: fctl.c,v 6.7 2000/10/12 00:21:47 jsquyres Exp $
  *
  *	Function:	- command to control certain filed functions
  *	Accepts:	- see the "usage" variable
@@ -107,8 +106,8 @@ char   			*argv[];
  * Attach to kernel.
  */
 	if (kinit(PRCMD)) {
-		terror("fctl (kinit)");
-		exit(errno);
+	  show_help(NULL, "no-lamd", "fctl", NULL);
+	  exit(errno);
 	}
 
 	if ((nid_parse(&argc, argv)) || (errno = (argc <= 2) ? 0 : EUSAGE)) {
@@ -174,7 +173,7 @@ help()
 	printf("\t\t-s <#>	Blow away one specific descriptor.\n");
 	printf("\t\t<dir>	Change to new working directory.\n");
 	printf("\t\tnone	Print current working directory.\n");
-	mnusage();
+	nid_usage();
 	printf("\t\th (local), o (origin), N (all)\n");
 	printf("\nExample:	fctl h -S\n");
 	printf("\t\t\t\"Clean up (reset) the file daemon.\"\n");
