@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB/RBD
  *
- *	$Id: fstate.c,v 6.5 1999/06/12 17:11:15 kmeyer1 Exp $
+ *	$Id: fstate.c,v 6.7 2000/10/12 00:21:43 jsquyres Exp $
  * 
  *	Function:	- command to print Trillium filed status info
  *	Accepts:	- see the "usage" variable
@@ -119,8 +118,8 @@ char			*argv[];
  * Attach to kernel.
  */
 	if (kinit(PRCMD)) {
-		terror("fstate (kinit)");
-		exit(errno);
+	  show_help(NULL, "no-lamd", "fstate", NULL);
+	  exit(errno);
 	}
 
 	if (nid_parse(&argc, argv) || (errno = (argc == 1) ? 0 : EUSAGE)) {
@@ -245,7 +244,7 @@ help()
 	printf("\nOptions:	-h	Print this help message.\n");
 	printf("\t\t-a	Display active descriptors only.\n");
 	printf("\t\t-F <#>	Set maximum # of descriptors to print.\n");
-	mnusage();
+	nid_usage();
 	printf("\t\th (local), o (origin), N (all)\n");
 	printf("\nExample:	fstate h\n");
 	printf("\t\t\t\"Get file status information on the local node.\"\n");
