@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: lamgrow.c,v 6.5 1999/06/12 17:11:18 kmeyer1 Exp $
+ *	$Id: lamgrow.c,v 6.7 2000/09/14 22:42:14 jsquyres Exp $
  * 
  *	Function:	- adds a node to an existing LAM session
  */
@@ -39,6 +38,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <sys/socket.h>
 #include <unistd.h>
 
@@ -110,6 +110,7 @@ char			*argv[];
 	struct direq	*pdiq;		/* dli request */
 	struct direply	*pdir;		/* dli reply */
 	struct nmsg	nhq;		/* request message */
+        mode_t          mode;
 
 	/* Ensure that we are not root */
 
@@ -141,7 +142,10 @@ char			*argv[];
 /*
  * Initialize LAM.
  */
-	if (kenter("lamgrow", PRCMD)) lamfail("lamgrow (kinit)");
+	if (kenter("lamgrow", PRCMD)) {
+	  show_help(NULL, "no-lamd", "lamgrow", NULL);
+	  exit(LAM_EEXIT);
+	}
 
 	if (nid_parse(&argc, argv) || (errno = (argc == 2) ? 0 : EUSAGE)) {
 		fprintf(stderr, usage);
@@ -305,20 +309,24 @@ char			*argv[];
 	}
 
 	if (opt_taken('c')) {
-		if ((fp = fopen(getparam('c'), "a")) == NULL)
-				cleanup("lamgrow (fopen)");
-		p = "# next line added by lamgrow\n";
-
-		fwrite(p, 1, strlen(p), fp);
-		fwrite(hname, 1, strlen(hname), fp);
-
-		if (uname != 0) {
-			fwrite(" ", 1, 1, fp);
-			fwrite(uname, 1, strlen(uname), fp);
-		}
-
-		fwrite("\n", 1, 1, fp);
-		fclose(fp);
+	  mode = umask(077);
+	  if ((fp = fopen(getparam('c'), "a")) == NULL) {
+	    umask(mode);
+	    cleanup("lamgrow (fopen)");
+	  }
+	  p = "# next line added by lamgrow\n";
+	  
+	  fwrite(p, 1, strlen(p), fp);
+	  fwrite(hname, 1, strlen(hname), fp);
+	  
+	  if (uname != 0) {
+	    fwrite(" ", 1, 1, fp);
+	    fwrite(uname, 1, strlen(uname), fp);
+	  }
+	  
+	  fwrite("\n", 1, 1, fp);
+	  fclose(fp);
+	  umask(mode);
 	}
 
 	free((char *) doljones);
