@@ -1,53 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1995 The Ohio State University
  *	GDB
  *
- *	$Log: lamshrink.c,v $
- *	Revision 6.4  1999/06/12 17:11:18  kmeyer1
- *	added copyright
- *	
- *	Revision 6.3  1999/06/09 16:36:29  jsquyres
- *	Added <sys/types.h> and <unistd.h> (if they weren't there already) for
- *	getuid() and geteuid().
- *	
- *	Revision 6.2  1999/06/07 01:50:58  jsquyres
- *	Added code to bail if root invokes this program.
- *	Added some error messages, too.  Still may need to add more show_help()
- *	references.
- *	
- *	Revision 6.1  1996/11/23 18:27:50  nevin
- *	Ohio Release
- *	
- * Revision 6.0  96/03/02  01:44:01  gdburns
- * Ohio Release
+ *      $Id: lamshrink.c,v 6.6 2000/09/05 17:10:47 jsquyres Exp $
  * 
  *	Function:	- removes a node from an existing LAM session
  */
@@ -144,8 +126,8 @@ char			*argv[];
  * Initialize LAM.
  */
 	if (kinit(PRCMD)) {
-		terror("lamshrink (kinit)");
-		exit(errno);
+	  show_help(NULL, "no-lamd", "lamshrink", NULL);
+	  exit(errno);
 	}
 
 	if (nid_parse(&argc, argv) || ((errno = (argc == 2) ? 0 : EUSAGE))) {
