@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	GDB
  *
- *	$Id: lamtrace.c,v 6.4 1999/08/27 21:51:49 jsquyres Exp $
+ *	$Id: lamtrace.c,v 6.7 2000/10/06 21:13:54 jsquyres Exp $
  *
  *	Function:	- unloads trace data
  *	Examples:	- lamtrace n10
@@ -58,8 +57,6 @@
 #include <args.h>
 #include <debug.h>
 #include <lam_ksignal.h>
-#include <mpi.h>
-#include <mpisys.h>
 #include <mpitrace.h>
 #include <portable.h>
 #include <preq.h>
@@ -144,8 +141,8 @@ char   			*argv[];
  * Attach to kernel.
  */
 	if (kinit(PRCMD)) {
-		terror("lamtrace (kinit)");
-		exit(errno);
+	  show_help(NULL, "no-lamd", "lamtrace", NULL);
+	  exit(errno);
 	}
 /*
  * Parse nodes and processes.
@@ -451,7 +448,7 @@ help()
 	printf("\t\t-f <#>	Signal to flush, then delay <#> secs.\n");
 	printf("\t\t-R	Sweep clean traces.\n");
 	printf("\n\t\tfile\tPut trace data in file (default: def.lamtr)\n");
-	mnusage();
+	nid_usage();
 	printf("\t\th (local), o (origin), N (all)\n");
 	printf("\nProcesses:	p<list> (identifiers)\n");
 	printf("\t\t%%<list> (indices)\n");
