@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN/JRV
  *
- *	$Id: mpimsg.c,v 6.5 1999/06/12 17:11:20 kmeyer1 Exp $
+ *	$Id: mpimsg.c,v 6.7 2000/10/06 21:26:44 jsquyres Exp $
  *
  *	Function:	- prints MPI message buffer status
  */
@@ -151,7 +150,10 @@ char   			*argv[];
 /*
  * Attach to kernel.
  */
-	if (kinit(PRCMD)) lampanic("mpimsg (kinit)");
+	if (kinit(PRCMD)) {
+	  show_help(NULL, "no-lamd", "mpimsg", NULL);
+	  exit(LAM_EEXIT);
+	}
 
 	if (nid_parse(&argc, argv) || pid_parse(&argc, argv) ||
 			(errno = (argc == 1) ? 0 : EUSAGE)) {
@@ -581,7 +583,7 @@ help()
 	printf("\t\t-e <#>	Set maximum # of message elements to print.\n");
 	printf("\t\t-m <#> 	Print contents of message #.\n");
 	printf("\t\t-B <#>	Set maximum # of messages to print.\n");
-	mnusage();
+	nid_usage();
 	printf("\t\th (local), o (origin), N (all)\n");
 	printf("\nProcesses:	p<list> (identifiers)\n");
 	printf("\t\t%%<list> (indices)\n");
