@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: mpirun.c,v 6.30 1999/09/12 05:05:24 jsquyres Exp $
+ *	$Id: mpirun.c,v 6.43 2001/03/23 19:53:22 jsquyres Exp $
  *
  *	Function:	- start an MPI application
  */
@@ -56,8 +55,6 @@
 #include "freq.h"
 #include "kio.h"
 #include "laminternal.h"
-#include "mpi.h"
-#include "mpisys.h"
 #include "ndi.h"
 #include "net.h"
 #include "portable.h"
@@ -70,37 +67,40 @@
 #endif
 #include <debug.h>
 
+
 /*
  * Leave this here because although PTY support has been added and
  * we'd like to make it the default, it's considered too "iffy" at the
  * moment.  But we may make it the default someday.
  */
-#define PTY_IS_DEFAULT 0
+#define PTY_IS_DEFAULT 1
+
 
 /*
- * private functions */
-static int		pwait();
-static int		set_mode();
-static int		set_stdio();
-static void		reset_stdio();
-static void		sigint_handler();
-static LIST		*build_app();
-static char		*locate_aschema();
-static void		node_ranges();
-static void		help();
-static int		get_mpi_world(int4, struct _gps *, struct _gps *);
-static void		error_cleanup(void);
+ * private functions 
+ */
+static int pwait(int4 nwait, int *childstat);
+static int set_mode(void);
+static int set_stdio(void);
+static void reset_stdio(void);
+static void sigint_handler(int sig);
+static LIST *build_app(int argc, char **argv, char **env);
+static char *locate_aschema(char *filename);
+static void node_ranges(char *buf, int4 initnode, int4 initindex);
+static int get_mpi_world(int4 world_n, struct _gps *world, 
+			 struct _gps *mpiworld);
+static void error_cleanup(void);
 #if LAM_WANT_IMPI
-static int              send_impi_params(struct _gps *);
+static int send_impi_params(struct _gps *);
 #endif
 
+
 /*
  * external variables
  */
 extern struct kio_t	_kio;			/* kernel I/O block */
 extern struct fclient	_ufd[FUMAX];		/* user file desc. */
 
-extern void		microsleep();
 
 /*
  * private variables
@@ -113,28 +113,31 @@ static int		fl_nprocs;		/* # procs specified */
 static int		fl_verbose;		/* verbose mode */
 static int		fl_wait = 1;		/* wait for completion */
 static int		fl_catch = 1;		/* catch signals */
-#if LAM_WANT_IMPI
-static int		fl_impi = 0;		/* IMPI job or not */
-#endif
+static int		fl_impi_client = 0;	/* IMPI client or not */
+static int		fl_impi_server = 0;	/* IMPI server or not */
 static int4		nprocs;			/* # procs */
 static int4		rtf;			/* runtime flags */
-static char		*wrkdir;		/* working dir */
-static char		fmtbuf[512];		/* formatting buffer */
+static char		*wrkdir = NULL;		/* working dir */
 static char		smallbuf[128];		/* small extra buffer */
 static OPT		*ad;			/* argument descriptor */
-
 static char		*syntaxerr =
 	"mpirun: application schema syntax error, line %d\n";
 
-static char		*usage =
-	"mpirun [options] [<app>] [[<nodes>] <prog> [<args>]]\n";
 
 int
-main(int argc, char **argv)
+main(int argc, char **argv, char **envp)
 {
-	LIST		*app;			/* application desc. */
-	int		status;			/* return status */
-	char		**env = 0;
+	LIST *app;
+	int status;
+	int errno_save;
+	char **env = 0;
+#if LAM_WANT_IMPI
+	char *impi_server = 0;
+	int impi_argc = 0;
+	char **impi_argv = 0;
+	LIST *impi_server_app;
+	struct _gps *impi_server_gps;
+#endif
 /*
  * Ensure that we are not root.
  */
@@ -152,6 +155,7 @@ main(int argc, char **argv)
 	}
 	ao_setopt1(ad, "fhtvDO", 0, 0, 0);
 	ao_setopt(ad, "client", 0, 2, 0);
+	ao_setopt(ad, "server", 0, 1, 0);
 	ao_setopt(ad, "s", 0, 1, 0);
 	ao_setopt(ad, "c", 0, 1, AOINT);
 	ao_setopt(ad, "np", "c", 1, AOINT);
@@ -173,23 +177,25 @@ main(int argc, char **argv)
 #endif
 
 	if (asc_compat(&argc, &argv)) {
+	        errno_save = errno;
 	        sfh_argv_free(argv);
 		ao_free(ad);
 		perror("mpirun");
-		exit(errno);
+		exit(errno_save);
 	}
 
 	if (ao_parse(ad, &argc, argv))	{
-		fprintf(stderr, usage);
+	        errno_save = errno;
+	        show_help("mpirun", "usage", NULL);
 	        sfh_argv_free(argv);
 		ao_free(ad);
-		exit(errno);
+		exit(errno_save);
 	}
 /*
  * Check for help request.
  */
 	if (ao_taken(ad, "h")) {
-		help();
+		show_help("mpirun", "usage", NULL);
 	        sfh_argv_free(argv);
 		ao_free(ad);
 		exit(0);
@@ -198,19 +204,20 @@ main(int argc, char **argv)
  * Set the operating mode.
  */
 	if (set_mode()) {
-		terror("mpirun (set_mode)");
+	        errno_save = errno;
 	        sfh_argv_free(argv);
 		ao_free(ad);
-		exit(errno);
+		exit(errno_save);
 	}
 /*
  * Attach to kernel.
  */
 	if (kinit(PRCMD)) {
-		terror("mpirun (kinit)");
-	        sfh_argv_free(argv);
-		ao_free(ad);
-		exit(errno);
+	  errno_save = errno;
+	  show_help(NULL, "no-lamd", "mpirun", NULL);
+	  sfh_argv_free(argv);
+	  ao_free(ad);
+	  exit(errno_save);
 	}
 /*
  * Set job identifier to be inherited by the application.
@@ -250,8 +257,9 @@ main(int argc, char **argv)
  */
 	if (ao_taken(ad, "lamd") && !ao_taken(ad, "nger")) {
 	  if (asc_ger(app, TRUE)) {
+	    errno_save = errno;
 	    ao_free(ad);
-	    kexit(errno);
+	    kexit(errno_save);
 	  }
 	}
 /*
@@ -264,10 +272,11 @@ main(int argc, char **argv)
  * Run the application.
  */
 	if (asc_run(app, 0, rtf, fl_verbose, TRUE, world)) {
+	    errno_save = errno;
 	    ao_free(ad);
 	    error_cleanup();
 	    reset_stdio();
-	    kexit(errno);
+	    kexit(errno_save);
 	}
 /*
  * Set signal handler to terminate the application.
@@ -281,11 +290,12 @@ main(int argc, char **argv)
  * Read pids and indices from MPI processes.
  */
 	if (get_mpi_world(world_n, world, mpiworld)) {
+	    errno_save = errno;
 	    ao_free(ad);
 	    app_doom(world_n, mpiworld, SIGUDIE);
 	    app_doom(world_n, world, -15);
 	    error_cleanup();
-	    kexit(errno);
+	    kexit(errno_save);
 	}
 /*
  * Send process table to all processes.
@@ -303,13 +313,63 @@ main(int argc, char **argv)
  * If this is an IMPI application, send the IMPI params to rank 0 so
  * that it can spawn the impid properly.
  */
-	if (fl_impi && send_impi_params(mpiworld) != 0) {
+	if (fl_impi_client && send_impi_params(mpiworld) != 0) {
+	  errno_save = errno;
 	  ao_free(ad);
 	  terror("mpirun (send_impi_params)");
 	  app_doom(world_n, mpiworld, SIGUDIE);
 	  app_doom(world_n, world, -15);
 	  error_cleanup();
-	  kexit(errno);
+	  kexit(errno_save);
+	}
+/*
+ * Start up the IMPI server; all the MPI ranks are now somewhere in
+ * MPI_Init, and probably blocking, waiting for the IMPI server to
+ * come up.  This flag will only be set if LAM_WANT_IMPI_SERVER, so we
+ * don't have to check for this here.
+ */
+	if (fl_impi_server) {
+	  impi_server = sfh_path_env_findv(LAM_IMPI_SERVER, R_OK, envp, 0);
+
+	  if (impi_server == NULL) {
+	    show_help("mpirun", "cant-find-impi-server", NULL);
+	    ao_free(ad);
+	    app_doom(world_n, mpiworld, SIGUDIE);
+	    app_doom(world_n, world, -15);
+	    error_cleanup();
+	    kexit(1);
+	  }
+
+/*
+ * Launch the impi server via the lamd on the localhost.  This allows
+ * the impi-server to be cleaned up via lamclean.
+ */
+	  impi_argc = 0;
+	  impi_argv = 0;
+	  sfh_argv_add(&impi_argc, &impi_argv, "bogus-ignored-arg");
+	  sfh_argv_add(&impi_argc, &impi_argv, "h");
+	  sfh_argv_add(&impi_argc, &impi_argv, impi_server);
+
+	  if ((impi_server_app = build_app(impi_argc, impi_argv, env)) == 0) {
+	    errno_save = errno;
+	    ao_free(ad);
+	    app_doom(world_n, mpiworld, SIGUDIE);
+	    app_doom(world_n, world, -15);
+	    error_cleanup();
+	    kexit(errno_save);
+	  }
+
+	  impi_server_gps = (struct _gps *) 
+	    malloc(world_n * sizeof(struct _gps));
+	  rtf &= ~(RTF_MPI | RTF_WAIT);
+	  if (asc_run(app, 0, rtf, fl_verbose, TRUE, impi_server_gps)) {
+	    errno_save = errno;
+	    ao_free(ad);
+	    app_doom(world_n, mpiworld, SIGUDIE);
+	    app_doom(world_n, world, -15);
+	    error_cleanup();
+	    kexit(errno_save);
+	  }
 	}
 #endif
 /*
@@ -321,6 +381,9 @@ main(int argc, char **argv)
 		if (pwait(world_n, &status)) {
 			app_doom(world_n, mpiworld, SIGUDIE);
 			app_doom(world_n, world, -15);
+#if LAM_WANT_IMPI
+			app_doom(world_n, impi_server_gps, -15);
+#endif
 			error_cleanup();
 		}
 
@@ -353,9 +416,11 @@ build_app(int argc, char **argv, char **env)
 	char		**argtailv;		/* argument tail vector */
 	char		*aschema;		/* application schema */
 	char		*qarg;			/* quoted argument */
+	char		*fmtbuf = malloc(512);	/* formatting buffer */
+	int              fmtbuf_len = 512;
 
 	if (nid_parse(&argc, argv) || (errno = (argc > 1) ? 0 : EUSAGE)) {
-		fprintf(stderr, usage);
+	        show_help("mpirun", "usage", NULL);
 		return(0);
 	}
 /*
@@ -368,7 +433,7 @@ build_app(int argc, char **argv, char **env)
  * Parse the app. schema.
  */
 		if ((argc != 2) || ao_taken(ad, "s")) {
-			fprintf(stderr, usage);
+		        show_help("mpirun", "usage", NULL);
 			kexit(EUSAGE);
 		}
 
@@ -415,12 +480,27 @@ build_app(int argc, char **argv, char **env)
 				terror("mpirun (sfh_argv_quote)");
 				return(0);
 			}
+
+			/* Oh for STL strings... */
+
+			if (strlen(fmtbuf) + strlen(qarg) + 1 > 
+			    fmtbuf_len) {
+			  fmtbuf_len *= 2;
+			  fmtbuf = realloc(fmtbuf, fmtbuf_len);
+			}
 			strcat(fmtbuf, qarg);
 			strcat(fmtbuf, " ");
 			free(qarg);
 		}
 
 		ao_tail(ad, &argtailc, &argtailv);
+
+		/* Oh for STL strings... */
+		
+		if (strlen(fmtbuf) + 3 > fmtbuf_len) {
+		  fmtbuf_len *= 2;
+		  fmtbuf = realloc(fmtbuf, fmtbuf_len);
+		}
 		if (argtailc > 0) strcat(fmtbuf, "-- ");
 
 		for ( ; argtailc > 0; --argtailc, ++argtailv) {
@@ -429,6 +509,14 @@ build_app(int argc, char **argv, char **env)
 				terror("mpirun (sfh_argv_quote)");
 				return(0);
 			}
+
+			/* Oh for STL strings... */
+
+			if (strlen(fmtbuf) + strlen(qarg) + 1 > 
+			    fmtbuf_len) {
+			  fmtbuf_len *= 2;
+			  fmtbuf = realloc(fmtbuf, fmtbuf_len);
+			}
 			strcat(fmtbuf, qarg);
 			strcat(fmtbuf, " ");
 			free(qarg);
@@ -439,6 +527,9 @@ build_app(int argc, char **argv, char **env)
 		app = asc_bufparse(fmtbuf, strlen(fmtbuf), &lineno, env);
 		lineno = 0;
 	}
+	free(fmtbuf);
+	fmtbuf = 0;
+	fmtbuf_len = 0;
 
 	if (app == 0) {
 		if (lineno > 0) {
@@ -500,10 +591,15 @@ pwait(int4 nwait, int *childstat)
 		}
 
 		if (status) {
-			printf("%d (n%d) exited with status %d\n",
-				pid, nodeid, status);
-			*childstat = status;
-			return(LAMERROR);
+		  char spid[32], snode[32], sstatus[32];
+		  snprintf(spid, 32, "%d", pid);
+		  snprintf(snode, 32, "%d", nodeid);
+		  snprintf(sstatus, 32, "%d", status);
+		  show_help("mpirun", "abnormal-exit", spid, snode, 
+			    sstatus, NULL);
+		  *childstat = status;
+		  errno = EINTR;
+		  return(LAMERROR);
 		}
 	}
 
@@ -570,6 +666,7 @@ set_mode(void)
 		rtf |= RTF_TTYOUT;
 	if (!fl_fdesc)
 		rtf |= RTF_IO;
+#if LAM_HAVE_PTYS
 #if PTY_IS_DEFAULT
 	if (!ao_taken(ad, "npty"))
 		rtf |= RTF_PTYS;
@@ -577,16 +674,30 @@ set_mode(void)
 	if (ao_taken(ad, "pty"))
 		rtf |= RTF_PTYS;
 #endif
-
-	if (ao_taken(ad, "client")) {
-#if !LAM_WANT_IMPI
-	  fprintf(stderr, "You selected \"-client\" on the command line for an IMP job,\n");
-	  fprintf(stderr, "but LAM was not compiled with IMPI support.  Ignored.\n");
 #else
-	  fl_impi = 1;
+	/* For those systems that do not have pty support */
+	if (ao_taken(ad, "pty"))
+	  fprintf(stderr, "Your system does not appear to include pty support.  -pty ignored.\n");
+	rtf &= ~RTF_PTYS;
+#endif
+
+	fl_impi_client = ao_taken(ad, "client");
+	fl_impi_server = ao_taken(ad, "server");
+	if (fl_impi_client || fl_impi_server) {
+#if !LAM_WANT_IMPI
+	  show_help("mpirun", "no-impi-support", NULL);
+#else
+#if !LAM_WANT_IMPI_SERVER
+	  if (fl_impi_server)
+	    show_help("mpirun", "no-impi-server", NULL);
+#else
+	  if (fl_impi_server && !fl_impi_client) {
+	    show_help("mpirun", "server-without-client", NULL);
+	    return LAMERROR;
+	  }
+#endif
 	  rtf |= RTF_IMPI;
 	  
-#if 0
 	  /* This seems to be overkill, but we'll leave it here on the
              off chance that we had a really good reason to have it
              here! */
@@ -596,7 +707,6 @@ set_mode(void)
 	    fprintf(stderr, "-O disabled.\n");
 	    rtf &= ~RTF_HOMOG;
 	  }
-#endif
 #endif
 	}
 	
@@ -671,9 +781,9 @@ locate_aschema(char *filename)
 		argvadd(&pathc, &pathv, appdir);
 	}
 	argvadd(&pathc, &pathv, "");
-	argvadd(&pathc, &pathv, "$LAMHOME/boot");
-	argvadd(&pathc, &pathv, "$TROLLIUSHOME/boot");
-	argvadd(&pathc, &pathv, DEFPSCHEMA);
+	argvadd(&pathc, &pathv, "$LAMHOME/etc");
+	argvadd(&pathc, &pathv, "$TROLLIUSHOME/etc");
+	argvadd(&pathc, &pathv, LAM_SYSCONFDIR);
 
 	fullpath = sfh_path_find(filename, pathv, R_OK);
 	argvfree(pathv);
@@ -817,8 +927,9 @@ get_mpi_world(int4 world_n, struct _gps *world, struct _gps *mpiworld)
 	}
 
 	if (msg.nh_type == 1) {
-	    fprintf(stderr, "mpirun: process terminated before completing "
-		"MPI_Init()\n"); 
+	    char node[32];
+	    snprintf(node, 32, "%d", msg.nh_node);
+	    show_help("mpirun", "no-init", node, NULL);
 	    return(LAMERROR);
 	}
 /*
@@ -867,61 +978,6 @@ error_cleanup(void)
     }
 }
 
-/*
- *	help
- *
- *	Function:	- prints helpful information on this command
- */
-static void
-help(void)
-{
-	printf("\nSynopsis:\tmpirun [options] [<app>] [[<nodes>] <program> "
-	    "[<program args>]]\n");
-	printf("\nDescription:\tStart an MPI application on LAM.\n");
-	printf("\nOptions:\t-h\t\tPrint this help message.\n");
-	printf("\t\t-c2c\t\tUse fast library (C2C) mode.\n");
-	printf("\t\t-lamd\t\tUse LAM daemon (LAMD) mode.\n");
-	printf("\t\t-f\t\tDo not open stdio descriptors.\n");
-	printf("\t\t-ger\t\tTurn on GER mode.\n");
-	printf("\t\t-nger\t\tTurn off GER mode.\n");
-	printf("\t\t-nsigs\t\tDon't catch signals.\n");
-	printf("\t\t-pty\t\tUse pty if stdout is a tty.\n");
-#if PTY_IS_DEFAULT
-	printf("\t\t-npty\t\tNever use ptys.\n");
-#endif
-	printf("\t\t-toff\t\tEnable tracing with generation initially off.\n");
-	printf("\t\t-ton, -t\tEnable tracing with generation initially on.\n");
-	printf("\t\t-v\t\tBe verbose.\n");
-	printf("\t\t-w\t\tWait for application to complete.\n");
-	printf("\t\t-nw\t\tDon't wait for application to complete.\n");
-	printf("\t\t-nx\t\tDon't export LAM_MPI_* env. vars.\n");
-	printf("\t\t-D\t\tChange current working directory of new\n");
-	printf("\t\t\t\tprocesses to the directory where the executable\n");
-	printf("\t\t\t\tresides.\n");
-	printf("\t\t-wd <dir>\tChange current working directory of new\n");
-	printf("\t\t\t\tprocesses to <dir>.\n");
-	printf("\t\t-O\t\tMulticomputer is homogeneous.\n");
-	printf("\t\t-c <num>\tRun <num> copies of <program>.\n");
-	printf("\t\t-np <num>\tRun <num> copies of <program>.\n");
-	printf("\t\t-s <nodeid>\tLoad <program> from this source node.\n");
-	printf("\t\t-x <envlist>\tExport environment vars in <envlist>.\n");
-	mnusage();
-	printf("\t\th (local), o (origin), N (all)\n");
-	printf("\nExamples:\tmpirun n0-7 prog1\n");
-	printf("\t\t\t\"Execute `prog1' on nodes 0 thru 7.\"\n");
-	printf("\n\t\tmpirun -lamd -x FOO=bar,DISPLAY N prog2\n");
-	printf("\t\t\t\"Execute `prog2' on all nodes using the lamd RPI.\n");
-	printf("\t\t\tIn the environment of each process set FOO to\n");
-	printf("\t\t\t'bar' and set DISPLAY to the current value.\"\n");
-#if LAM_WANT_IMPI
-	printf("\t\t-client <rank> <host>:<port>\n");
-	printf("\t\t\t\tRun IMPI job; connect to IMPI server <host>\n");
-	printf("\t\t\t\tat port <port> as IMPI client <rank>\n");
-#endif
-	printf("\nDefaults:\t-c2c -w -nger\n\n");
-}
-
-
 
 #if LAM_WANT_IMPI
 static int
