@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN/GDB/JRV/RBD
  *
- *	$Id: mpitask.c,v 6.6 1999/06/12 17:11:21 kmeyer1 Exp $
+ *	$Id: mpitask.c,v 6.9 2000/10/06 21:26:32 jsquyres Exp $
  * 
  *	Function:	- prints MPI task status information
  */
@@ -47,8 +46,7 @@
 #include <blktype.h>			/* for sync info */
 #include <events.h>                     /* for EVSTOP and EVPAUSE */
 #include <ksignal.h>			/* signal constants */
-#include <mpi.h>			/* needed by mpisys.h */
-#include <mpisys.h>			/* FYI structure */
+#include <mpisys.h>
 #include <mpitrace.h>			/* datatype constants */
 #include <net.h>			/* network constants */
 #include <preq.h>			/* kenya interface constants */
@@ -128,7 +126,10 @@ char			*argv[];
 /*
  * Attach to kernel.
  */
-	if (kinit(PRCMD)) lampanic("mpitask (kinit)");
+	if (kinit(PRCMD)) {
+	  show_help(NULL, "no-lamd", "mpitask", NULL);
+	  exit(LAM_EEXIT);
+	}
 
 	if (nid_parse(&argc, argv) || pid_parse(&argc, argv) ||
 			(errno = (argc == 1) ? 0 : EUSAGE)) {
@@ -833,7 +834,7 @@ help()
 	printf("\t\t-c  	Print communicator group(s).\n");
 	printf("\t\t-d  	Print datatype definition(s).\n");
 	printf("\t\t-gps  	Print using GPS.\n");
-	mnusage();
+	nid_usage();
 	printf("\t\th (local), o (origin), N (all)\n");
 	printf("\nProcesses:	p<list> (identifiers)\n");
 	printf("\t\t%%<list> (indices)\n");
