@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: state.c,v 6.5 1999/06/12 17:11:22 kmeyer1 Exp $
+ *	$Id: state.c,v 6.8 2000/10/12 00:21:40 jsquyres Exp $
  * 
  *	Function:	- prints Trollius process status information
  *			- processes can be selected by index or identifier
@@ -115,8 +114,8 @@ char   			*argv[];
  * Attach to kernel.
  */
 	if (kinit(PRCMD)) {
-		terror("state (kinit)");
-		exit(errno);
+	  show_help(NULL, "no-lamd", "state", NULL);
+	  exit(errno);
 	}
 
 	if (nid_parse(&argc, argv) || (pid_parse(&argc, argv)) ||
@@ -310,7 +309,8 @@ int			nodeid;
 		printf(" %-6d", state->ps_pid);
 		printf(" %-5d", state->ps_kernel.ks_priority);
 
-		if (state->ps_kernel.ks_event == NOTEVENT) {
+		if (state->ps_kernel.ks_event == NOTEVENT ||
+				state->ps_kernel.ks_state == KSREADY) {
 			sprintf(buffer, "%s",
 					kstates[state->ps_kernel.ks_state]);
 		}
@@ -380,7 +380,7 @@ help()
 	printf("\t\t-t	Select only system processes.\n");
 	printf("\nProcesses:	p<list> (identifiers)\n");
 	printf("\t\t%%<list> (indices)\n");
-	mnusage();
+	nid_usage();
 	printf("\t\th (local), o (origin), N (all)\n");
 	printf("\nExample:	state n3-9,11 %%1 %%2 p303\n");
 	printf("\t\t\t\"Get status information for PID 303 and\n");
