@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB/RBD
  *
- *	$Id: di_bootagent.c,v 6.6 1999/08/14 22:57:17 lamteam Exp $
+ *	$Id: di_bootagent.c,v 6.7 2000/03/06 21:26:25 jsquyres Exp $
  *
  *	Function:	- obtains link information from boot agent
  *	Accepts:	- link array (value returned)
@@ -80,19 +79,22 @@ static int		agent_port;
  *
  *	Function:	- obtains link information from boot agent
  *	Accepts:	- link array (value returned)
+ *			- num CPU array (value returned)
  *			- link array size (value returned)
  *	Returns:	- datalink input socket
  */
 int
-di_bootagent(pdilinks, pndil)
+di_bootagent(pdilinks, pncpus, pndil)
 
 struct dilink		**pdilinks;
+int4			**pncpus;
 int4			*pndil;
 
 {
 	int4		i;
 	int4		ngbr_link;	/* neighbour link # */
 	int4		ngbr_port;	/* neighbour port # */
+	int4		ngbr_ncpus;	/* neighbour num cpus # */
 	unsigned char	ngbr_haddr[4];	/* neighbour host address */
 	unsigned char	my_haddr[4];	/* my host address */
 	int		agent_sd;	/* connection to boot agent */
@@ -162,7 +164,11 @@ int4			*pndil;
  */
 	*pdilinks = (struct dilink *) malloc((unsigned) *pndil *
 			sizeof(struct dilink));
-	if (*pdilinks == 0) lampanic("dli_inet (malloc)");
+	if (*pdilinks == 0) 
+	  lampanic("dli_inet (malloc)");
+	*pncpus = (int *) malloc((unsigned) *pndil * sizeof(int));
+	if (*pncpus == 0)
+	  lampanic("dli_inet (malloc)");
 /*
  * Init all entries to invalid link.
  */
@@ -173,8 +179,10 @@ int4			*pndil;
 
 	for (i = 0; i < *pndil; ++i) {
 		if (readcltnbr(agent_sd, &ngbr_link, ngbr_haddr,
-				&ngbr_port)) lampanic("dli_inet (readcltnbr)");
+				&ngbr_port, &ngbr_ncpus)) 
+		  lampanic("dli_inet (readcltnbr)");
 		(*pdilinks)[i].dil_link = ngbr_link;
+		(*pncpus)[i] = ngbr_ncpus;
 		sfh_sock_fill_inet_addr(ngbr_haddr, (int) ngbr_port,
 				&((*pdilinks)[i].dil_addr));
 	}
