@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB/RBD
  *
- *	$Id: di_bootcmd.c,v 6.7 1999/08/14 22:57:17 lamteam Exp $
+ *	$Id: di_bootcmd.c,v 6.8 2000/03/06 21:27:09 jsquyres Exp $
  *
  *	Function:	- obtains link information from command line
  *	Accepts:	- link array (value returned)
@@ -61,9 +60,10 @@
 static char		my_hname[MAXHOSTNAMELEN + 1];
 
 int
-di_bootcmd(pdilinks, pndil, argc, argv)
+di_bootcmd(pdilinks, pncpus, pndil, argc, argv)
 
 struct dilink		**pdilinks;
+int4			**pncpus;
 int4			*pndil;
 int			argc;
 char			**argv;
@@ -73,6 +73,7 @@ char			**argv;
 	int		dli_sd;		/* datalink input socket */
 	int4		i;
 	int4		my_link;	/* my datalink # */
+	int4		my_ncpus;	/* my number of CPUs */
 	int4		ngbr_link;	/* neighbour link # */
 	unsigned char	ngbr_haddr[4];	/* neighbour host address */
 	unsigned char	my_haddr[4];	/* my host address */
@@ -108,6 +109,14 @@ char			**argv;
 	} else {
 		my_link = 0;
 	}
+/*
+ * Get my number of CPUs
+ */
+	if (opt_taken('c')) {
+		intparam('c', &my_ncpus);
+	} else {
+		my_ncpus = 1;
+	}
 /*
  * Get my host network address.
  */
@@ -132,7 +141,11 @@ char			**argv;
  */
 	*pdilinks = (struct dilink *) malloc((unsigned) *pndil *
 			sizeof(struct dilink));
-	if (*pdilinks == 0) lampanic("dli_inet (malloc)");
+	if (*pdilinks == 0) 
+	  lampanic("dli_inet (malloc)");
+	*pncpus = (int *) malloc((unsigned) *pndil * sizeof(int));
+	if (*pncpus == 0)
+	  lampanic("dli_inet (malloc)");
 /*
  * Init all entries to invalid link.
  */
@@ -156,11 +169,14 @@ char			**argv;
 		(*pdilinks)[ngbr_link].dil_link = ngbr_link;
 		sfh_sock_fill_inet_addr(ngbr_haddr, (int) dli_port,
 				&((*pdilinks)[ngbr_link].dil_addr));
+
+		(*pncpus)[ngbr_link] = atoi(*argv++);
 	}
 /*
  * Set my link.
  */
 	(*pdilinks)[my_link].dil_link = my_link;
+	(*pncpus)[my_link] = my_ncpus;
 	sfh_sock_fill_inet_addr(my_haddr, (int) dli_port,
 			&((*pdilinks)[my_link].dil_addr));
 
