@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB/RBD
  *
- *	$Id: dli_inet.c,v 6.4 1999/08/18 21:19:41 jsquyres Exp $
+ *	$Id: dli_inet.c,v 6.5 2000/03/06 21:27:59 jsquyres Exp $
  *
  *	Function:	- datalink input program for OTB-OTB link
  *			- reads network frames from a socket and forwards them
@@ -78,7 +77,7 @@ static int		initdlo();
 static void		di_ack();
 static void		diqsetlink();
 static void		diqremlink();
-static void		initrouter();
+static void		initrouter(int *ncpus);
 static void		getmessage();
 
 /*
@@ -111,20 +110,21 @@ int			argc;
 char			*argv[];
 
 {
+	int *ncpus = 0;
 	--argc;
 	++argv;
 /*
  * Boot from agent.  Get agent address and port from command line.
  */
 	if (opt_taken('H')) {
-		dli_sd = di_bootagent(&dilinks, &ndil);
+		dli_sd = di_bootagent(&dilinks, &ncpus, &ndil);
 	} else {
-		dli_sd = di_bootcmd(&dilinks, &ndil, argc, argv);
+		dli_sd = di_bootcmd(&dilinks, &ncpus, &ndil, argc, argv);
 	}
 /*
  * Build and send route information to router.
  */
-	initrouter();
+	initrouter(ncpus);
 /*
  * Send the link info to dlo.
  */
@@ -378,9 +378,11 @@ initdlo()
  *	Function:	- sends route information to router
  *			- LAM specific
  *			- assumes all nodes are neighbours
+ *	Accepts:	- array (of length ndil) specifying how many CPUs
+ *                      - on each node
  */
 static void
-initrouter()
+initrouter(int *ncpus)
 
 {
 	int4		i;		/* favourite index */
@@ -430,6 +432,7 @@ initrouter()
 
 		p->r_nodeid = pdil->dil_link;
 		p->r_nodetype = NT_TUBE | NT_DISK;
+		p->r_ncpus = ncpus[i];
 		p->r_link = pdil->dil_link;
 
 		if (p->r_nodeid == mynodeid) {
@@ -508,6 +511,8 @@ struct nmsg		*pnhq;
 	newroute.r_event = EVDL0;
 	newroute.r_link2 = ilink;
 	newroute.r_event2 = EVDL0;
+	/* JMS Don't know what to put here */
+	newroute.r_ncpus = 1;
 
 	if (rrsetrents(LOCAL, &newroute, 1)) lampanic("dli_inet (rrsetrents)");
 /*
