@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: dlo_inet.c,v 6.4 1999/09/10 05:16:34 jsquyres Exp $
+ *	$Id: dlo_inet.c,v 6.5 2000/08/17 15:56:53 jsquyres Exp $
  *
  *	Function:	- datalink output program for OTB-OTB socket link
  */
@@ -131,10 +130,10 @@ do_init()))()
 /*
  * Initialize the timeout periods.
  */
-	do_to_idle.tv_sec = TO_DLO_IDLE;
+	do_to_idle.tv_sec = LAM_TO_DLO_IDLE;
 	do_to_idle.tv_usec = 0;
-	do_to_ack.tv_sec = TO_DLO_ACK / 1000000;
-	do_to_ack.tv_usec = TO_DLO_ACK % 1000000;
+	do_to_ack.tv_sec = LAM_TO_DLO_ACK / 1000000;
+	do_to_ack.tv_usec = LAM_TO_DLO_ACK % 1000000;
 /*
  * Initialize the output link table.
  */
