@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	GDB
  *
- *	$Id: flatd.c,v 6.2 1999/06/12 17:11:31 kmeyer1 Exp $
+ *	$Id: flatd.c,v 6.4 2001/03/29 16:47:53 jsquyres Exp $
  * 
  *	Function:	- OTB flat memory server
  *			- provides symbolic access to memory
@@ -52,6 +51,7 @@
 #include <preq.h>
 #include <priority.h>
 #include <terror.h>
+#include <lamlog.h>
 
 /*
  * global functions
@@ -246,7 +246,7 @@ flqload()
 		free(buffer);
 
 		fd = open(fltable[i].fl_addr,
-			  O_WRONLY | O_CREAT | O_APPEND, 0775);
+			  O_WRONLY | O_CREAT | O_APPEND, 0700);
 
 		if (fd < 0) {
 			fltable[i].fl_addr = EMPTY;
@@ -263,7 +263,7 @@ flqload()
  * If we get this far, then it was an existing request which must be continued.
  */
 	if (fltable[i].fl_status == 0) {
-		fd = open(fltable[i].fl_addr, O_WRONLY | O_APPEND, 0775);
+		fd = open(fltable[i].fl_addr, O_WRONLY | O_APPEND, 0700);
 
 		if (fd < 0) {
 			reply->flr_reply = errno;
@@ -275,6 +275,8 @@ flqload()
 		else if (write(fd, buf, nhq.nh_length) < nhq.nh_length) {
 			fltable[i].fl_status = errno;
 			close(fd);
+			lamlog("flatd: flqload - calling unlink on \"%s\"\n", 
+			       fltable[i].fl_addr);
 			unlink(fltable[i].fl_addr);
 		}
 /*
@@ -341,6 +343,8 @@ flqclean()
 		reply->flr_reply = EBADTAG;
 	} else {
 		reply->flr_reply = 0;
+		lamlog("flatd: flqclean - calling unlink on \"%s\"\n", 
+		       fltable[i].fl_addr);
 		unlink(fltable[i].fl_addr);
 		fltable[i].fl_addr = EMPTY;
 	}
@@ -392,8 +396,9 @@ flwipe()
 	for (i = 0; i < FLMAX; ++i) {
 
 		if (fltable[i].fl_addr != EMPTY) {
-			unlink(fltable[i].fl_addr);
-			fltable[i].fl_addr = EMPTY;
+		  lamlog("flatd: flqwipe - calling unlink on \"%s\"\n", fltable[i].fl_addr);
+		  unlink(fltable[i].fl_addr);
+		  fltable[i].fl_addr = EMPTY;
 		}
 	}
 }
