@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	GDB
  *
- *	$Id: kenyad.c,v 6.4 1999/09/10 05:17:13 jsquyres Exp $
+ *	$Id: kenyad.c,v 6.6 2001/03/23 18:35:39 jsquyres Exp $
  * 
  *	Function:	- OTB process management server
  *			- higher level control and monitoring of processes
@@ -119,6 +118,9 @@ p_init()))()
     chldpipe_init();
     chld.sa_handler = childtrap;
     chld.sa_flags = SA_NOCLDSTOP;
+#if LAM_HAVE_SA_RESTART
+    chld.sa_flags |= SA_RESTART;
+#endif
     sigemptyset(&chld.sa_mask);
     sigaction(SIGCHLD, &chld, (struct sigaction *) 0);
 
@@ -224,7 +226,8 @@ int4			key_pid;	/* pid to be found */
 {
 	int		i;		/* favourite index */
 
-	for (i = 0; (i < PMAX) && (ptable[i].p_pid != key_pid); ++i);
+	for (i = 0; (i < PMAX) && (ptable[i].p_pid != key_pid); ++i)
+	  continue;
 
 	return((i < PMAX) ? i : ERROR);
 }
