@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: pqdetach.c,v 6.8 1999/09/21 03:00:31 jsquyres Exp $
+ *	$Id: pqdetach.c,v 6.11 2001/03/29 19:31:33 jsquyres Exp $
  * 
  *	Function:	- OTB kenyad
  *			- attaches and detaches kenya processes
@@ -53,6 +52,7 @@
 #include <preq.h>
 #include <terror.h>
 #include <typical.h>
+#include <lamlog.h>
 
 /*
  * external variables
@@ -74,7 +74,7 @@ extern int		pfind();
  */
 void			childdetach();
 void			childtrap();
-void			pdetachindex();
+void                    pdetachindex(int idetach);
 void			pqattach();
 void			pqdetach();
 
@@ -83,6 +83,7 @@ pqdetach()
 
 {
 	int		idetach;	/* descriptor index of target */
+	struct pprocess	*pdetach;	/* descriptor ptr of target */
 /*
  * Find the process descriptor for the given identifier.
  */
@@ -93,8 +94,25 @@ pqdetach()
  */
 	psendr((char *) &pr, sizeof(pr), 0);
 
+	/*
+	 * If the flatd created a temporary file for this process,
+	 * delay the deatch action because some OS's (cough cough
+	 * HP-UX cough cough) won't allow unlink()'ing of files while
+	 * they are running.  Specifically, we may have received this
+	 * message *while the program is still running*.  i.e., the
+	 * process did an nsend to send us this message, but it's
+	 * still running -- hence, trying to unlink it could result in
+	 * an "text file busy" error.  So defer detaching it for now,
+	 * and let the died catch it when it actually dies.
+	 */
+
 	if (pr.pr_reply == 0) {
-		pdetachindex(idetach);
+	  pdetach = ptable + idetach;
+	  if ((pdetach->p_rtf & RTF_FLAT) == 0) {
+	    lamlog("kenyad: did not start this process with the flatd; detaching now");
+	    pdetachindex(idetach);
+	  } else
+	    lamlog("kenyad: started this process with the flatd; deferring detaching until later");
 	}
 }
 
@@ -116,6 +134,7 @@ pdetachindex(int idetach)
 /*
  * Flush IO.
  */
+	lamlog("kenyad: in pdetachindex");
 	if (pdetach->p_rtf & RTF_IO) {
 		fflush(stderr);
 		fflush(stdout);
@@ -155,8 +174,10 @@ pdetachindex(int idetach)
 /*
  * Check to see if anybody else is using the load module.
  */
+	lamlog("kenyad: detatching, checking for RTF_FLAT (0x%x) in flags: 0x%x", RTF_FLAT, pdetach->p_rtf);
 	if (pdetach->p_rtf & RTF_FLAT) {
 
+	        lamlog("kenyad: detatching, found RTF_FLAT");
 		for (i = 0; (i < PMAX) && !found; ++i) {
 
 			if ((ptable[i].p_pid != NOTPROCESS) &&
@@ -172,7 +193,9 @@ pdetachindex(int idetach)
 /*
  * Remove the load module file and free the filename buffer.
  */
-			unlink(pdetach->p_loadpt);
+		  int ret = unlink(pdetach->p_loadpt);
+		  lamlog("kenyad: detach calling unlink on %s, ret %d, errno %d",
+			 pdetach->p_loadpt, ret, errno);
 		}
 	}
 
@@ -264,21 +287,29 @@ childtrap()
 	int		status;		/* child exit status */
 
 	while (1) {
-		pid = waitpid(-1, &status, WNOHANG);
+	  pid = waitpid(-1, &status, WNOHANG);
 		
-		if (pid <= 0) {
-			return;
-		}
+	  if (pid <= 0) {
+	    if (errno != ECHILD && errno != EINVAL)
+	      lamlog("kenyad: get error for waitpid(), errno %d", errno);
+	    return;
+	  }
+	  
+	  i = pfind((int4) pid);
+	  
+	  if (i >= 0) {
+	    ptable[i].p_status = (int4) (WIFEXITED(status) ?
+					 WEXITSTATUS(status) : 1);
+	    if (diesigfd >= 0)
+	      mwrite(diesigfd, (char *) &i, 1);
 
-		i = pfind((int4) pid);
-
-		if (i >= 0) {
-			ptable[i].p_status = (int4) (WIFEXITED(status) ?
-					WEXITSTATUS(status) : 1);
-			if (diesigfd >= 0) {
-				mwrite(diesigfd, (char *) &i, 1);
-			}
-		}
+	    if (WIFEXITED(status))
+	      lamlog("kenyad: child pid %d died with return code of %d",
+		     pid, WEXITSTATUS(status));
+	    else
+	      lamlog("kenyad: child pid %d died due to signal %d",
+		     pid, WTERMSIG(status));
+	  }
 	}
 }
 
@@ -374,6 +405,8 @@ detachindex(int idetach)
  * Remove the load module file and free the filename buffer.
  */
 		unlink(pdetach->p_loadpt);
+		lamlog("kenyad: removing load module \"%s\"", 
+		       pdetach->p_loadpt);
 	    }
 	}
 
@@ -392,10 +425,13 @@ childdeath(void)
 	int	i;
 
 	read(diedfd, &i, sizeof(i));
+	lamlog("died: caught child death; trying to detach");
 
 	for (i=0; i<PMAX; i++) {
 	    if (ptable[i].p_status != NOTSTATUS) {
-		detachindex(i);
+	      lamlog("died: detaching table entry %d", i);
+	      detachindex(i);
 	    }
 	}
+	lamlog("died: finished");
 }
