@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: kernelio.c,v 6.10 1999/08/30 21:38:17 jsquyres Exp $
+ *	$Id: kernelio.c,v 6.13 2000/12/06 14:35:21 jsquyres Exp $
  * 
  *	Function:	- receives kernel requests and send replies
  *			- moves messages between clients
@@ -40,16 +39,20 @@
 #include <sfh.h>
 
 #include <errno.h>
+#include <fcntl.h>
 #include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#if HAVE_STRINGS_H
 #include <strings.h>
+#endif
 #include <sys/types.h>
 #include <sys/time.h>
 #include <sys/socket.h>
 #include <sys/uio.h>
 #include <sys/un.h>
+#include <sys/stat.h>
 #include <unistd.h>
 
 #if LAM_NEED_SYS_SELECT_H
@@ -147,6 +150,7 @@ kio_init()
 	char		*f_kill;		/* kill filename */
 	char		*f_sock;		/* socket filename */
 	int		i;
+	mode_t          mode;
 /*
  * Initialize the interrupt fd->func table.
  */
@@ -170,6 +174,7 @@ kio_init()
 /*
  * Set up local address.
  */
+	mode = umask(0177);
 	kernel_un.sun_family = AF_UNIX;
 	f_sock = sockname();
 	memcpy((char *) kernel_un.sun_path, f_sock, strlen(f_sock));
@@ -213,6 +218,7 @@ kio_init()
 	FD_ZERO(&allfds);
 	FD_ZERO(&clientfds);
 	nfd_ready = 0;
+	umask(mode);
 }
 
 /*
@@ -295,7 +301,7 @@ kio_req()
 			fd_max = sd_new;
 		    }
 /*
- * Set send and receive buffer sizes.
+ * Set send/receive buffer sizes and close on exec.
  */
 		    if (sfh_sock_set_buf_size(sd_new, SFH_UNIX, SO_SNDBUF,
 			    	KPKTLEN + sizeof(struct nmsg))) {
@@ -306,6 +312,10 @@ kio_req()
 			    	KPKTLEN + sizeof(struct nmsg))) {
 			lampanic("kernel (sfh_sock_set_buf_size)");
 		    }
+
+		    if (fcntl(sd_new, F_SETFD, 1) == -1) {
+			lampanic("kernel (fcntl)");
+		    }
 		}
 	    }
 /*
