@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: kkill.c,v 6.4 1999/08/26 22:22:53 jsquyres Exp $
+ *	$Id: kkill.c,v 6.5 2000/09/14 22:45:59 jsquyres Exp $
  * 
  *	Function:	- supports client cleanup by the kernel and by tkill(1)
  *			- OTB specific code
@@ -119,7 +118,7 @@ kkillopen(f_kill)
 char			*f_kill;
 
 {
-	fd_kill = open(f_kill, O_WRONLY | O_CREAT | O_EXCL, 0200);
+	fd_kill = open(f_kill, O_WRONLY | O_CREAT | O_EXCL, 0600);
 
 	if (fd_kill < 0) {
 		return(LAMERROR);
@@ -137,9 +136,14 @@ char			*f_kill;
 		return(LAMERROR);
 	}
 
+#if 0
+	/* I'm not sure why this is here.  It doesn't seem harmful,
+           but it also just seems weird, in a security sense... Hence,
+           I'm commenting it out. */
 	if (chmod(f_kill, 0644)) {
 		return(LAMERROR);
 	}
+#endif
 
 	return(0);
 }
