@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: kouter.c,v 6.6 1999/09/10 05:17:46 jsquyres Exp $
+ *	$Id: kouter.c,v 6.13 2001/03/29 16:56:23 jsquyres Exp $
  * 
  *	Function:	- simple message rendez-vous server
  */
@@ -41,12 +40,18 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <sys/types.h>
+#include <unistd.h>
+#include <sys/stat.h>
 
 #include <debug.h>
 #include <kreq.h>
 #include <net.h>
 #include <terror.h>
 #include <typical.h>
+#include <args.h>
+#include <laminternal.h>
+#include <lamlog.h>
 
 /*
  * external functions
@@ -71,11 +76,11 @@ extern void		kqsync();
 /*
  * local functions
  */
-static void		kdump1();
-static void		kqattach();
-static void		kqdetach();
-static void		kqdump();
-static void		kqsurrender();
+static void kqattach(struct kproc *pclient, struct kreq *pkq);
+static void kqdetach(struct kreq *pkq);
+static void kqsurrender(struct kproc *pclient, struct kreq *pkq);
+static void kqdump();
+static void kdump1(struct kproc *p);
 
 /*
  * local variables
@@ -118,11 +123,7 @@ struct kproc		*kpfindport();
  *	main
  */
 int
-main(argc, argv)
-
-int			argc;
-char			*argv[];
-
+main(int argc, char *argv[])
 {
 	struct kproc	*pclient;	/* current customer */
 	struct kproc	*pnext;		/* next client in ready list */
@@ -131,6 +132,43 @@ char			*argv[];
 	int		go = 1;
 	int		i;
 
+	/* Ensure that we are not root */
+	if (getuid() == 0 || geteuid() == 0) {
+	  show_help(NULL, "deny-root", NULL);
+	  exit(EACCES);
+	}
+/*
+ * Be safe; blanket coverage
+ */
+	umask(077);
+/*
+ * Parse command line arguments.
+ */
+	validopts("xd");
+	followed("nopHPb");
+
+	if (do_args(&argc, argv)) {
+		terror("lamd (arguments)");
+		exit(errno);
+	}
+/*
+ * See if we're running under a batch system, and if so, set the unix
+ * socket name
+ */
+	if (opt_taken('b')) {
+	  set_killname(getparam('b'));
+	}
+/*
+ * If we were started with '-d', setup to do some syslog debugging messages
+ */
+	if (opt_taken('d')) {
+	  lamopenlog("lamd");
+	  lamlog("started (%s), uid %d, gid %d", LAM_VERSION,
+		 getuid(), getgid());
+	}
+/*
+ * Now setup our sockets and the like.  
+ */
 	kio_init();
 /*
  * Initialize process table.
@@ -225,17 +263,13 @@ char			*argv[];
  *			- client request
  */
 static void
-kqattach(pclient, pkq)
-
-struct kproc		*pclient;
-struct kreq		*pkq;
-
+kqattach(struct kproc *pclient, struct kreq *pkq)
 {
 	struct kreply	reply;
 	LAM_ZERO_ME(reply);
 
-	db(("kernel (kqattach): pid=%d pri=%d\n", pkq->kq_pid,
-			pkq->kq_priority));
+	lamlog("kouter: attached process pid=%d, pri=%d", 
+	       pkq->kq_pid, pkq->kq_priority);
 
 	if (pclient != 0) {
 		kpdelete(&pready, pclient, (struct kproc *) 0);
@@ -244,6 +278,7 @@ struct kreq		*pkq;
 	} else {
 
 		if (pfree == 0) {
+			lamlog("kouter: tried to attach, but we're out of descriptors");
 			reply.kr_reply = ENOKDESCRIPTORS;
 			kio_reply(&reply, kio_fd_ready());
 			kio_close(kio_fd_ready());
@@ -280,21 +315,21 @@ struct kreq		*pkq;
  *	Accepts:	- client request
  */
 static void
-kqdetach(pkq)
-
-struct kreq		*pkq;
-
+kqdetach(struct kreq *pkq)
 {
 	struct kproc	*p;
 
-	db(("kernel (kqdetach): pid=%d\n", pkq->kq_pid));
+	lamlog("kouter: kqdetach detached process pid=%d", pkq->kq_pid);
+
 	p = kpfind(pkq->kq_pid);
 	if (!p) return;
 
 	if (!(p->kp_flags & KIPROC)) {
+	  lamlog("kouter: kqdetach calling kio_close");
 		kio_close(p->kp_port);
 	}
 
+	lamlog("kouter: kqdetach calling knuke");
 	knuke(p);
 }
 
@@ -306,15 +341,11 @@ struct kreq		*pkq;
  *			- client request
  */
 static void
-kqsurrender(pclient, pkq)
-
-struct kproc		*pclient;
-struct kreq		*pkq;
-
+kqsurrender(struct kproc *pclient, struct kreq *pkq)
 {
 	struct kreply	reply;
 
-	db(("kernel (kqsurrender): pid=%d\n", pclient->kp_pid));
+	lamlog("kouter: surrendered process pid=%d", pkq->kq_pid);
 
 	pclient->kp_flags &= ~KSURRENDER;
 	reply.kr_reply = 0;
@@ -330,7 +361,6 @@ struct kreq		*pkq;
  */
 static void
 kqdump()
-
 {
 	struct kreply	reply;
 	struct kproc	*p;
@@ -357,10 +387,7 @@ kqdump()
  *	Accepts:	- process descriptor ptr
  */
 static void
-kdump1(p)
-
-struct kproc		*p;
-
+kdump1(struct kproc *p)
 {
 	char		buffer[32];
 	char		*format;
@@ -411,10 +438,7 @@ struct kproc		*p;
  *	Accepts:	- process desc.
  */
 void
-knuke(pkp)
-
-struct kproc		*pkp;
-
+knuke(struct kproc *pkp)
 {
 	if (!pkp) return;
 
@@ -437,10 +461,7 @@ struct kproc		*pkp;
  *			- sends it a signal to prompt a kernel call
  */
 void
-kpreempt(ploose)
-
-struct kproc		*ploose;
-
+kpreempt(struct kproc *ploose)
 {
 	if ( !(ploose->kp_flags & KSURRENDER)) {
 		ploose->kp_flags |= KSURRENDER;
@@ -463,11 +484,7 @@ struct kproc		*ploose;
  *	Returns:	- 0 or ERROR
  */
 int
-transfer(pfrom, pto)
-
-struct kproc		*pfrom;
-struct kproc		*pto;
-
+transfer(struct kproc *pfrom, struct kproc *pto)
 {
 	char		*ptomsg;
 	char		*pfrmsg;
@@ -553,10 +570,7 @@ struct kproc		*pto;
  *	Returns:	- process descriptor ptr
  */
 struct kproc *
-kpfind(pid)
-
-int4			pid;
-
+kpfind(int4 pid)
 {
 	int		i;
 
@@ -579,10 +593,7 @@ int4			pid;
  *	Returns:	- process descriptor ptr
  */
 struct kproc *
-kpfindport(port)
-
-int4			port;
-
+kpfindport(int4 port)
 {
 	int		i;
 
