@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: kiproc.c,v 6.4 1999/06/12 17:11:36 kmeyer1 Exp $
+ *	$Id: kiproc.c,v 6.7 2000/02/25 19:06:53 jsquyres Exp $
  * 
  *	Function:	- simple message rendez-vous server
  */
@@ -76,6 +75,7 @@ extern void		(*r_init())();
 extern void		(*tr_init())();
 extern void		(*io_init())();
 extern void		(*die_init())();
+extern void		(*h_init())();
 
 extern void		flwipe();
 extern void		kpinsert();
@@ -103,6 +103,7 @@ static struct {
 	{ tr_init, PRDAEMON },
 	{ io_init, PRDAEMON },
 	{ die_init, PRDIED },
+	{ h_init, PRHALTD },
 	{ (void (*((*)()))()) 0, 0 }
 };
 
@@ -120,17 +121,6 @@ char			*argv[];
 {
 	int		i = 0;
 	struct kproc	*pclient;
-/*
- * Parse command line arguments.
- */
-	validopts("x");
-	followed("nopHP");
-
-	if (do_args(argc, argv)) {
-		terror("lamd (arguments)");
-		exit(errno);
-	}
-
 	_lam_signal(SIGHUP, kbbail);
 
 	while (kboottbl[i].kb_run != 0) {
