@@ -1,59 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1995 The Ohio State University
  *	GDB
  *
- *	$Log: loadd.c,v $
- *	Revision 6.2  1999/06/12 17:11:38  kmeyer1
- *	added copyright
- *	
- *	Revision 6.1  1996/11/23 19:26:22  nevin
- *	Ohio Release
- *	
- * Revision 6.0  96/02/29  13:33:16  gdburns
- * Ohio Release
- * 
- * Revision 5.2.1.2  96/02/24  14:40:38  gdburns
- * general modernization
- * 
- * Revision 5.2.1.1  94/09/20  14:02:15  gdburns
- * Remove extraneous sys/file.h.
- * 
- * Revision 5.2  94/08/22  13:52:20  gdburns
- * Ohio Release
- * 
- * Revision 5.1  94/05/18  10:43:18  gdburns
- * Ohio Release
- * 
- * Revision 2.3  94/04/22  12:30:06  gdburns
- * Ohio Release
+ *	$Id: loadd.c,v 6.4 2000/11/02 07:20:52 jsquyres Exp $
  *
  *	Function	- load daemon
  *			- loads local file onto remote node
@@ -77,17 +53,13 @@
 #include <priority.h>
 #include <rreq.h>
 #include <terror.h>
+#include <sfh.h>
 
 /*
  * global functions
  */
 void			(*(l_init()))();
 
-/*
- * external functions
- */
-char			*_path_env_find();
-
 /*
  * local variables
  */
@@ -161,7 +133,7 @@ loadd()))()
 /*
  * Locate the file.
  */
-	fullname = _path_env_find(fname, R_OK | X_OK);
+	fullname = sfh_path_env_find(fname, R_OK | X_OK);
 
 	if (fullname == 0) {
 		lr->lr_reply = errno;
@@ -189,7 +161,7 @@ loadd()))()
 /*
  * Open file to be loaded.
  */
-	if ((fdesc = open(fullname, O_RDONLY)) < 0) {
+	if ((fdesc = open(fullname, O_RDONLY, 0600)) < 0) {
 		lr->lr_reply = EINVAL;
 		lsendr();
 		free(fullname);
