@@ -1,42 +1,42 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB/AKP
  *
- *	$Id: tping.c,v 6.5 1999/06/12 17:11:39 kmeyer1 Exp $
+ *	$Id: tping.c,v 6.13 2000/10/17 14:15:16 jsquyres Exp $
  *
  *	Function:	- bounces a message off the echo daemon
  */
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <signal.h>
 #include <sys/time.h>
 #include <sys/types.h>
@@ -49,6 +49,7 @@
 #include <priority.h>
 #include <terror.h>
 #include <typical.h>
+#include <dl_inet.h>
 
 #define plural(n)	((n != 1) ? "s" : "")
 
@@ -62,31 +63,26 @@ static int		fl_verbose;		/* verbose flag */
 static int4		msglen;			/* message length */
 static int4		nmesg;			/* # messages to send */
 
-static char		*usage=
-	"tping [-vh] [-c <count>] [-d <delay>] [-l <length>] <nodes>\n";
-
 /*
  * local functions
  */
-static int		setdefaults();
-static void		help();
-static void		trap();
+static int		setdefaults(void);
+static void		trap(int);
 
 
 int
-main(argc, argv)
-
-int			argc;
-char			*argv[];
-
+main(int argc, char *argv[])
 {
+	int		i;
 	int		decr;			/* loop decrement (0 or 1) */
 	int		n_index;		/* node index */
+	int		first_index;		/* first node index */
 	int		n_flags;		/* node flags */
 	int4		ret;			/* recho() return value */
 	int4		nsent;			/* # messages sent */
 	int4		nbytes;			/* # bytes sent */
-	int4		nnodes;			/* # target nodes */
+	int4		nnodes;			/* # remote target nodes */
+	int4		localnodes;		/* # local target nodes */
 	int4		nodeid;			/* target node ID */
 	int4		prevnode;		/* previous node ID */
 	char		*outbuf = 0;		/* outgoing message buffer */
@@ -96,6 +92,10 @@ char			*argv[];
 	double		tmax;			/* max timing */
 	double		ttotal;			/* total timing */
 	double		ttrip;			/* message trip timing */
+	int		*indices;		/* array of indices */
+	int		*nodes;			/* array of nodes */
+	int4		nlinks;                 /* total number of links */
+	struct dolink	*links;                 /* from ldogetlinks */
 
 	/* Ensure that we are not root */
 
@@ -111,15 +111,15 @@ char			*argv[];
 	followed("cdl");
 
 	if (do_args(&argc, argv)) {
-		fprintf(stderr, usage);
-		exit(errno);
+	  show_help("tping", "usage", NULL);
+	  exit(errno);
 	}
 /*
  * Check for help request.
  */
-	if (opt_taken('h')) {
-		help();
-		exit(0);
+	if (opt_taken('h')) {	
+	  show_help("tping", "usage", NULL);
+	  exit(0);
 	}
 /*
  * Set the defaults.
@@ -163,37 +163,73 @@ char			*argv[];
  * Attach to the Trollius kernel.
  */
 	if (kinit(PRCMD)) {
-		terror("tping (kinit)");
-		exit(errno);
+	  show_help(NULL, "no-lamd", "tping", NULL);
+	  exit(errno);
 	}
 
 	if (nid_parse(&argc, argv) || (errno = (argc == 1) ? 0 : EUSAGE)) {
-		fprintf(stderr, usage);
-		kexit(errno);
+	  show_help("tping", "usage", NULL);
+	  kexit(errno);
 	}
 /*
  * Get the first node identifier.
  */
 	nid_get(&n_index, &nodeid, &n_flags);
+	first_index = n_index;
 
 	if (n_index < 0) {
-		fprintf(stderr, "usage: %s\n", usage);
-		errno = EUSAGE;
-		kexit(errno);
+	  show_help("tping", "usage", NULL);
+	  errno = EUSAGE;
+	  kexit(errno);
 	}
+	/*
+	 * Get the max number of links so that we can size some arrays
+	 * below
+	 */
+	if (ldogetlinks(&links, &nlinks))
+	  lamfail("lamhalt (ldogetlinks)");
+/*
+ * Use that as an upper bound to malloc the nodes array
+ */
+	nodes = (int*) malloc(sizeof(int) * nlinks);
+	if (nodes == 0)
+	  kexit(errno);
+	indices = (int*) malloc(sizeof(int) * nlinks);
+	if (indices == 0) {
+	  free(nodes);
+	  kexit(errno);
+	}
+	for (i = 0; i < nlinks; i++)
+	  nodes[i] = indices[i] = -1;
+/*
+ * Now fill the indices array with the indices of unique nodes
+ */
+	localnodes = 0;
+	do {
+	  if (nodes[nodeid] == -1)
+	    indices[n_index] = 1;
+	  nodes[nodeid] = 1;
+
+	  if (nodeid == getnodeid())
+	    localnodes = 1;
+
+	  nid_get(&n_index, &nodeid, &n_flags);
+	} while (n_index != first_index);
 /*
  * Loop over the # of messages.
  */
+	prevnode = nodeid;
 	for (nsent = 0; (nmesg > 0) && (!fl_intr); ++nsent, nmesg -= decr) {
 		ttrip = ttime();
 /*
  * Loop through all specified nodes.
  */
 		nnodes = 0;
-
 		do {
+		  if (indices[n_index] == 1) {
 			prevnode = nodeid;
-			++nnodes;
+			if (nodeid != getnodeid())
+			  ++nnodes;
 /*
  * Ping the node.
  */
@@ -210,9 +246,10 @@ char			*argv[];
 
 				kexit(errno);
 			}
+		  }
 
-			nid_get(&n_index, &nodeid, &n_flags);
-		} while(n_index);
+		  nid_get(&n_index, &nodeid, &n_flags);
+		} while (n_index != first_index);
 /*
  * Compute timing statistics.
  */
@@ -225,51 +262,58 @@ char			*argv[];
 			tmax = ttrip;
 		}
 
-		if (nnodes == 1) {
-			VERBOSE("%3d byte%s from %s: %3.3f secs\n", msglen,
-				plural(msglen), mnemonic(prevnode), ttrip);
-		} else {
-			VERBOSE("%3d byte%s from %d nodes: %3.3f secs\n",
-				msglen, plural(msglen), nnodes, ttrip);
-		}
+		if (nnodes + localnodes == 1) {
+		  VERBOSE("%3d byte%s from %s: %3.3f secs\n", msglen,
+			  plural(msglen), nid_fmt(prevnode), ttrip);
+  		} else {
+  		  VERBOSE("%3d byte%s from ", msglen, plural(msglen));
+  		  if (nnodes > 0)
+  		    VERBOSE("%d remote node%s", nnodes, plural(nnodes));
+  		  if (nnodes > 0 && localnodes > 0)
+  		    VERBOSE(" and ");
+  		  if (localnodes > 0)
+  		    VERBOSE("1 local node");
+  		  VERBOSE(": %3.3f secs\n", ttrip);
+  		}
 /*
  * Wait for a while.
  */
-		if (delay > 0) {
-			sleep((unsigned) delay);
-		}
-	}
+  		if (delay > 0) {
+  			sleep((unsigned) delay);
+  		}
+  	}
 /*
  * Free the buffers.
  */
-	if (outbuf) {
-		free(outbuf);
-	}
+  	if (outbuf) {
+  		free(outbuf);
+  	}
 
-	if (inbuf) {
-		free(inbuf);
-	}
+  	if (inbuf) {
+  		free(inbuf);
+  	}
+  	free(nodes);
+  	free(indices);
 /*
  * Print out the final statistics.
  */
-	if (nsent <= 0) {
-		fprintf(stderr, "tping: sent %d messages!\n", nsent);
-		kexit(1);
-	}
+  	if (nsent <= 0) {
+  		fprintf(stderr, "tping: sent %d messages!\n", nsent);
+  		kexit(1);
+  	}
+  	nbytes = msglen * nsent;
+  	tave = ttotal / nsent;
 
-	nbytes = msglen * nsent;
-	tave = ttotal / nsent;
+  	printf("\n%d message%s, %d byte%s (%4.3fK), %4.3f secs (%4.3fK/sec)\n",
+ 		nsent, plural(nsent), nbytes, plural(nbytes),
+  		((double) nbytes) / 1024, ttotal,
+  		((double) 2 * nbytes) / ttotal / 1024);
 
-	printf("\n%d message%s, %d byte%s (%4.3fK), %4.3f secs (%4.3fK/sec)\n",
-		nsent, plural(nsent), nbytes, plural(nbytes),
-		((double) nbytes) / 1024, ttotal,
-		((double) 2 * nbytes) / ttotal / 1024);
+  	printf("roundtrip min/avg/max: %3.3f/%3.3f/%3.3f\n", tmin, tave, tmax);
 
-	printf("roundtrip min/avg/max: %3.3f/%3.3f/%3.3f\n", tmin, tave, tmax);
-
-	kexit(0);
-	return(0);
-}
+  	kexit(0);
+  	return(0);
+  }
 
 /*
  *	trap
@@ -278,10 +322,9 @@ char			*argv[];
  *			- set interrupt flag in order to exit the loop
  */
 static void
-trap()
-
+trap(int sig)
 {
-	fl_intr = TRUE;
+  	fl_intr = TRUE;
 }
 
 /*
@@ -291,60 +334,59 @@ trap()
  *	Returns:	- 0 or ERROR
  */
 static int
-setdefaults()
-
+setdefaults(void)
 {
 /*
  * Get the # of messages to send.
  */
-	if (opt_taken('c')) {
-		fl_inf = FALSE;
-		intparam('c', &nmesg);
-	} else {
-		fl_inf = TRUE;
-		nmesg = 1;
-	}
+  	if (opt_taken('c')) {
+  		fl_inf = FALSE;
+ 		intparam('c', &nmesg);
+  	} else {
+  		fl_inf = TRUE;
+  		nmesg = 1;
+  	}
 
-	if (nmesg < 0) {
-		fprintf(stderr, "tping: count (%d) must be >= 0\n", nmesg);
-		errno = EUSAGE;
-		return(LAMERROR);
-	} else if (nmesg == 0) {
-		fl_inf = TRUE;
-		nmesg = 1;
-	}
+  	if (nmesg < 0) {
+  		fprintf(stderr, "tping: count (%d) must be >= 0\n", nmesg);
+  		errno = EUSAGE;
+  		return(LAMERROR);
+  	} else if (nmesg == 0) {
+  		fl_inf = TRUE;
+  		nmesg = 1;
+  	}
 /*
  * Get the delay between messages.
  */
-	if (opt_taken('d')) {
-		intparam('d', &delay);
-	} else {
-		delay = 1;
-	}
+  	if (opt_taken('d')) {
+  		intparam('d', &delay);
+  	} else {
+  		delay = 1;
+  	}
 
-	if (delay < 0) {
-		fprintf(stderr, "tping: delay (%d) must be >= 0\n", delay);
-		errno = EUSAGE;
-		return(LAMERROR);
-	}
+  	if (delay < 0) {
+  		fprintf(stderr, "tping: delay (%d) must be >= 0\n", delay);
+  		errno = EUSAGE;
+  		return(LAMERROR);
+  	}
 /*
  * Set the verbose flag.
  */
-	fl_verbose = ! opt_taken('v');
+  	fl_verbose = ! opt_taken('v');
 /*
  * Set the message length.
  */
-	if (opt_taken('l')) {
-		intparam('l', &msglen);
-	} else {
-		msglen = 1;
-	}
+  	if (opt_taken('l')) {
+ 		intparam('l', &msglen);
+  	} else {
+  		msglen = 1;
+  	}
 
-	if (msglen < 0) {
-		fprintf(stderr, "tping: length (%d) must be >= 0\n", msglen);
-		errno = EUSAGE;
-		return(LAMERROR);
-	}
+  	if (msglen < 0) {
+  		fprintf(stderr, "tping: length (%d) must be >= 0\n", msglen);
+  		errno = EUSAGE; 
+  		return(LAMERROR); 
+  	} 
 	else if (msglen > MAXNMSGLEN) {
 		fprintf(stderr, "tping: using max length (%d)\n", MAXNMSGLEN);
 		msglen = MAXNMSGLEN;
@@ -353,25 +395,3 @@ setdefaults()
 	return(0);
 }
 
-/*
- *	help
- *
- *	Function:	- prints helpful information on this command
- */
-static void
-help()
-
-{
-	printf("\nSynopsis:       tping [options] <nodes>\n");
-	printf("\nOptions:        -h	Print this help message.\n");
-	printf("\t\t-v      Turn off verbose mode.\n");
-	printf("\t\t-c <#>  Echo <#> messages.\n");
-	printf("\t\t-l <#>  Use <#> bytes per message.\n");
-	printf("\t\t-d <#>  Delay <#> seconds between messages.\n");
-	printf("\nDescription:    Echo messages to Trollius nodes.\n");
-	mnusage();
-	printf("\t\th\t(local), o (origin), N (all)\n");
-	printf("\nExample:        tping n10 -c 100 -l 1024 -d 0\n");
-	printf("\t\t\t\"Echo 100 messages of length 1024 to node 10\n");
-	printf("\t\t\t without pausing between messages.\"\n");
-}
