@@ -1,12 +1,12 @@
 /* 
- *   $Id: ad_nfs_seek.c,v 1.1.1.1 1999/03/17 18:52:47 jsquyres Exp $    
+ *   $Id: ad_nfs_seek.c,v 1.1.1.1 2000/09/06 20:01:56 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
  */
 
 #include "ad_nfs.h"
-#ifdef __PROFILE
+#ifdef PROFILE
 #include "mpe.h"
 #endif
 
