@@ -1,11 +1,27 @@
 /* 
- *   $Id: file_f2c.c,v 1.1.1.1 1999/03/17 18:52:54 jsquyres Exp $    
+ *   $Id: file_f2c.c,v 1.1.1.1 2000/09/06 20:01:53 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
  */
 
 #include "mpioimpl.h"
+
+#ifdef HAVE_WEAK_SYMBOLS
+
+#if defined(HAVE_PRAGMA_WEAK)
+#pragma weak MPI_File_f2c = PMPI_File_f2c
+#elif defined(HAVE_PRAGMA_HP_SEC_DEF)
+#pragma _HP_SECONDARY_DEF PMPI_File_f2c MPI_File_f2c
+#elif defined(HAVE_PRAGMA_CRI_DUP)
+#pragma _CRI duplicate MPI_File_f2c as PMPI_File_f2c
+/* end of weak pragmas */
+#endif
+
+/* Include mapping from MPI->PMPI */
+#define MPIO_BUILD_PROFILING
+#include "mpioprof.h"
+#endif
 #include "adio_extern.h"
 
 /*@
@@ -19,8 +35,7 @@ Return Value:
 @*/
 MPI_File MPI_File_f2c(MPI_Fint fh)
 {
-
-#ifndef __INT_LT_POINTER
+#ifndef INT_LT_POINTER
     return (MPI_File) ((void *) fh);  
     /* the extra cast is to get rid of a compiler warning on Exemplar.
        The warning is because MPI_File points to a structure containing
@@ -29,7 +44,7 @@ MPI_File MPI_File_f2c(MPI_Fint fh)
 #else
     if (!fh) return MPI_FILE_NULL;
     if ((fh < 0) || (fh > ADIOI_Ftable_ptr)) {
-	printf("MPI_File_f2c: Invalid file handle\n");
+	FPRINTF(stderr, "MPI_File_f2c: Invalid file handle\n");
 	MPI_Abort(MPI_COMM_WORLD, 1);
     }
     return ADIOI_Ftable[fh];
