@@ -1,5 +1,5 @@
 /* 
- *   $Id: info_getvln.c,v 1.1.1.1 1999/03/17 18:53:03 jsquyres Exp $    
+ *   $Id: info_getvln.c,v 1.1.1.1 2000/09/06 20:01:52 jsquyres Exp $    
  *
  *   Copyright (C) 1997 University of Chicago. 
  *   See COPYRIGHT notice in top-level directory.
@@ -7,6 +7,22 @@
 
 #include "mpioimpl.h"
 
+#ifdef HAVE_WEAK_SYMBOLS
+
+#if defined(HAVE_PRAGMA_WEAK)
+#pragma weak MPI_Info_get_valuelen = PMPI_Info_get_valuelen
+#elif defined(HAVE_PRAGMA_HP_SEC_DEF)
+#pragma _HP_SECONDARY_DEF PMPI_Info_get_valuelen MPI_Info_get_valuelen
+#elif defined(HAVE_PRAGMA_CRI_DUP)
+#pragma _CRI duplicate MPI_Info_get_valuelen as PMPI_Info_get_valuelen
+/* end of weak pragmas */
+#endif
+
+/* Include mapping from MPI->PMPI */
+#define MPIO_BUILD_PROFILING
+#include "mpioprof.h"
+#endif
+
 /*@
     MPI_Info_get_valuelen - Retrieves the length of the value associated with a key
 
@@ -25,22 +41,22 @@ int MPI_Info_get_valuelen(MPI_Info info, char *key, int *valuelen, int *flag)
     MPI_Info curr;
 
     if ((info <= (MPI_Info) 0) || (info->cookie != MPIR_INFO_COOKIE)) {
-        printf("MPI_Info_get_valuelen: Invalid info object\n");
+        FPRINTF(stderr, "MPI_Info_get_valuelen: Invalid info object\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
     if (key <= (char *) 0) {
-	printf("MPI_Info_get_valuelen: key is an invalid address\n");
+	FPRINTF(stderr, "MPI_Info_get_valuelen: key is an invalid address\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
     if (strlen(key) > MPI_MAX_INFO_KEY) {
-	printf("MPI_Info_get_valuelen: key is longer than MPI_MAX_INFO_KEY\n");
+	FPRINTF(stderr, "MPI_Info_get_valuelen: key is longer than MPI_MAX_INFO_KEY\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
     if (!strlen(key)) {
-	printf("MPI_Info_get_valuelen: key is a null string\n");
+	FPRINTF(stderr, "MPI_Info_get_valuelen: key is a null string\n");
         MPI_Abort(MPI_COMM_WORLD, 1);
     }
 
