@@ -1,31 +1,30 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Software for Humanity
  *	GDB/RBD
  *
@@ -33,7 +32,7 @@
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
  *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  *
- *	$Id: all_argv.c,v 6.5 1999/07/29 12:41:10 lamteam Exp $
+ *	$Id: all_argv.c,v 6.7 2000/08/17 14:48:31 jsquyres Exp $
  *
  *	Function:	- argument vector library
  */
@@ -45,18 +44,6 @@
 
 #define ARGSIZE		128
 
-/*
- * global functions
- */
-int			sfh_argv_add();
-int			sfh_argv_count();
-unint			sfh_argv_len();
-void			sfh_argv_free();
-char			**sfh_argv_break();
-char			**sfh_argv_dup();
-char			*sfh_argv_glue();
-char			**sfh_argv_break_quoted();
-char			*sfh_argv_unquote();
 
 /*
  *	sfh_argv_add
@@ -68,7 +55,7 @@ char			*sfh_argv_unquote();
  *	Returns:	- 0 or -1 (error)
  */
 int
-sfh_argv_add(int *argc, char ***argv, CONST char *arg)
+sfh_argv_add(int *argc, char ***argv, char *arg)
 {
 /*
  * Create new argv.
@@ -88,7 +75,7 @@ sfh_argv_add(int *argc, char ***argv, CONST char *arg)
 		if (*argv == 0) return(-1);
 	}
 
-	(*argv)[*argc] = malloc((unsigned) strlen(arg) + 1);
+	(*argv)[*argc] = (char*) malloc((unsigned) strlen(arg) + 1);
 	if ((*argv)[*argc] == 0) return(-1);
 
 	strcpy((*argv)[*argc], arg);
@@ -128,11 +115,11 @@ sfh_argv_free(char **argv)
  *	Returns:	- argv or NULL (error)
  */
 char **
-sfh_argv_break(CONST char *args, int delim)
+sfh_argv_break(char *args, int delim)
 {
 	char		arg[ARGSIZE];	/* single argument */
 	char		**argv = 0;	/* argument structure ptr */
-	CONST char	*p;		/* walk through args */
+	char	*p;		/* walk through args */
 	char		*argtemp;	/* temporary single argument */
 	int		argc = 0;	/* # arguments */
 	unint		arglen;		/* single argument length */
@@ -162,7 +149,7 @@ sfh_argv_break(CONST char *args, int delim)
  * long argument, malloc buffer, copy and add
  */
 		else if (arglen > (ARGSIZE - 1)) {
-			argtemp = malloc((unsigned) (arglen + 1));
+			argtemp = (char*) malloc((unsigned) (arglen + 1));
 			if (argtemp == 0) return(0);
 
 			strncpy(argtemp, args, arglen);
@@ -245,7 +232,7 @@ sfh_argv_glue(char **argv, int delim, unint maxlen)
 /*
  * Allocate the string.
  */
-	if ((str = malloc((unsigned) str_len)) == 0) return(0);
+	if ((str = (char*) malloc((unsigned) str_len)) == 0) return(0);
 /*
  * Loop filling in the string.
  */
@@ -451,7 +438,7 @@ sfh_argv_break_quoted(char *args, int delim, char quotes[])
  * long argument, malloc buffer, copy and add
  */
 		else if (arglen > (ARGSIZE - 1)) {
-			argtemp = malloc((unsigned) (arglen + 1));
+			argtemp = (char*) malloc((unsigned) (arglen + 1));
 			if (argtemp == 0) return(0);
 
 			unquote(argtemp, args, p, quotes);
@@ -487,7 +474,7 @@ sfh_argv_break_quoted(char *args, int delim, char quotes[])
  *	Returns:	- quoted string or NULL (error)
  */
 char *
-sfh_argv_quote(CONST char *s, char quotes[])
+sfh_argv_quote(char *s, char quotes[])
 {
 	char        	*qs;
 	int         	len = strlen(s);
@@ -501,7 +488,7 @@ sfh_argv_quote(CONST char *s, char quotes[])
 		}
 	}
 
-	qs = malloc(len+nq+3);
+	qs = (char*) malloc(len+nq+3);
 	qs[0] = DQ;
 
 	for (j = 1, i = 0; i < len; i++) {
