@@ -1,44 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1995 The Ohio State University
  *	RBD
  *
- *	$Log: all_opt.c,v $
- *	Revision 6.2  1999/05/23 19:22:15  kmeyer1
- *	added copyright
- *	
- *	Revision 6.1  1996/11/23 19:55:26  nevin
- *	Ohio Release
- *	
- * Revision 6.0  96/02/29  13:36:24  gdburns
- * Ohio Release
+ *	$Id: all_opt.c,v 6.4 2000/10/11 19:09:27 jsquyres Exp $
  * 
  *	Function:	- generic option parsing package
  *			- uses malloc()
@@ -55,11 +46,12 @@
 /*
  * local functions
  */
-static int		addinst();
-static int		countparam();
-static int		mutexchk();
-static int		strtonum();
-static struct ao_opt	*findopt();
+static int addinst(struct ao_opt *opt, int nparam, char **params);
+static int countparam(OPT *aod, struct ao_opt *opt, char **argv);
+static int mutexchk(struct ao_opt *opt);
+static int strtonum(char *str, int *pnum);
+static struct ao_opt *findopt(OPT *desc, char *optstr);
+
 
 /*
  *	ao_init
@@ -69,7 +61,6 @@ static struct ao_opt	*findopt();
  */
 OPT *
 ao_init()
-
 {
 	OPT		*aod;			/* ptr option desc. */
 
@@ -94,10 +85,7 @@ ao_init()
  *	Accepts:	- ptr option desc.
  */
 void
-ao_free(aod)
-
-OPT			*aod;
-
+ao_free(OPT *aod)
 {
 	struct ao_inst	*pinst;			/* ptr instance */
 	struct ao_opt	*p;			/* favourite pointer */
@@ -133,10 +121,7 @@ OPT			*aod;
  *	Returns:	- # taken options
  */
 int
-ao_ntaken(aod)
-
-OPT			*aod;
-
+ao_ntaken(OPT *aod)
 {
 	return((aod) ? aod->ao_ntaken : 0);
 }
@@ -150,11 +135,7 @@ OPT			*aod;
  *	Returns:	- TRUE or FALSE
  */
 int
-ao_taken(aod, opt)
-
-OPT			*aod;
-CONST char		*opt;
-
+ao_taken(OPT *aod, char *opt)
 {
 	struct ao_opt	*p;			/* favourite pointer */
 
@@ -176,11 +157,7 @@ CONST char		*opt;
  *	Returns:	- chosen/taken option or NULL
  */
 char *
-ao_chosen(aod, opt)
-
-OPT			*aod;
-CONST char		*opt;
-
+ao_chosen(OPT *aod, char *opt)
 {
 	struct ao_opt	*p;			/* favourite pointer */
 
@@ -214,11 +191,7 @@ CONST char		*opt;
  *	Returns:	- # instances
  */
 int
-ao_ninsts(aod, opt)
-
-OPT			*aod;
-CONST char		*opt;
-
+ao_ninsts(OPT *aod, char *opt)
 {
 	struct ao_opt	*p;			/* favourite pointer */
 
@@ -237,12 +210,7 @@ CONST char		*opt;
  *	Returns:	- # parameters
  */
 int
-ao_nparams(aod, opt, inst)
-
-OPT			*aod;
-CONST char		*opt;
-int			inst;
-
+ao_nparams(OPT *aod, char *opt, int inst)
 {
 	struct ao_opt	*p;			/* favourite pointer */
 	int		ret = 0;		/* returned value */
@@ -270,13 +238,7 @@ int			inst;
  *	Returns:	- parameter string or NULL
  */
 char *
-ao_param(aod, opt, inst, idx)
-
-OPT			*aod;
-CONST char		*opt;
-int			inst;
-int			idx;
-
+ao_param(OPT *aod, char *opt, int inst, int idx)
 {
 	struct ao_opt	*p = 0;			/* favourite pointer */
 	struct ao_inst	*pinst;			/* ptr instance */
@@ -309,14 +271,7 @@ int			idx;
  *	Returns:	- 0 or LAMERROR
  */
 int
-ao_intparam(aod, opt, inst, idx, pparam)
-
-OPT			*aod;
-CONST char		*opt;
-int			inst;
-int			idx;
-int			*pparam;
-
+ao_intparam(OPT *aod, char *opt, int inst, int idx, int *pparam)
 {
 	struct ao_opt	*p = 0;			/* favourite pointer */
 	struct ao_inst	*pinst;			/* ptr instance */
@@ -349,12 +304,7 @@ int			*pparam;
  *	Returns:	- 0 or LAMERROR
  */
 int
-ao_tail(aod, tailc, tailv)
-
-OPT			*aod;
-int			*tailc;
-char			***tailv;
-
+ao_tail(OPT *aod, int *tailc, char ***tailv)
 {
 	int		ret = LAMERROR;		/* returned value */
 
@@ -380,14 +330,8 @@ char			***tailv;
  *	Returns:	- 0 or LAMERROR
  */
 int
-ao_setopt(aod, opt, mutex, nparams, flags)
-
-OPT			*aod;
-CONST char		*opt;
-CONST char		*mutex;
-int			nparams;
-int			flags;
-
+ao_setopt(OPT *aod, char *opt, char *mutex, int nparams,
+	  int flags)
 {
 	struct ao_opt	*p;			/* favourite pointer */
 	struct ao_opt	*mtx;			/* ptr mutex option */
@@ -463,16 +407,10 @@ int			flags;
  *	Returns:	- 0 or LAMERROR
  */
 int
-ao_setopt1(aod, opt, mutex, nparams, flags)
-
-OPT			*aod;
-CONST char		*opt;
-CONST char		*mutex;
-int			nparams;
-int			flags;
-
+ao_setopt1(OPT *aod, char *opt, char *mutex, int nparams,
+	   int flags)
 {
-	CONST char	*p;
+	char	*p;
 	char		opt1[2];
 
 	opt1[1] = '\0';
@@ -502,12 +440,7 @@ int			flags;
  *	Returns:	- 0 or LAMERROR
  */
 int
-ao_parse(aod, pcmdc, cmdv)
-
-OPT			*aod;
-int			*pcmdc;
-char			**cmdv;
-
+ao_parse(OPT *aod, int *pcmdc, char **cmdv)
 {
 	int		num;			/* parsed number */
 	int		fl_onelet;		/* one-letter options? */
@@ -706,11 +639,7 @@ char			**cmdv;
  *	Returns:	- ptr option or NULL
  */
 static struct ao_opt *
-findopt(desc, optstr)
-
-OPT			*desc;
-char			*optstr;
-
+findopt(OPT *desc, char *optstr)
 {
 	struct ao_opt	*p;			/* favourite pointer */
 /*
@@ -746,11 +675,7 @@ char			*optstr;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-strtonum(str, pnum)
-
-char			*str;
-int			*pnum;
-
+strtonum(char *str, int *pnum)
 {
 	char		*endstr;		/* end of parsed string */
 
@@ -773,10 +698,7 @@ int			*pnum;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-mutexchk(opt)
-
-struct ao_opt		*opt;
-
+mutexchk(struct ao_opt *opt)
 {
 	struct ao_opt	*p;			/* favourite pointer */
 
@@ -798,12 +720,7 @@ struct ao_opt		*opt;
  *	Returns:	- # parameters or LAMERROR
  */
 static int
-countparam(aod, opt, argv)
-
-OPT			*aod;
-struct ao_opt		*opt;
-char			**argv;
-
+countparam(OPT *aod, struct ao_opt *opt, char **argv)
 {
 	int		n;			/* counter */
 	int		num;			/* junk number */
@@ -845,12 +762,7 @@ char			**argv;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-addinst(opt, nparam, params)
-
-struct ao_opt		*opt;
-int			nparam;
-char			**params;
-
+addinst(struct ao_opt *opt, int nparam, char **params)
 {
 	int		fl_int;			/* integer parameters */
 	int		num;			/* parsed number */
@@ -869,7 +781,7 @@ char			**params;
  */
 	size = (fl_int) ? sizeof(int) : sizeof(char *);
 
-	parmbuf = malloc(size * nparam);
+	parmbuf = (char*) malloc(size * nparam);
 
 	if (parmbuf == 0) return(LAMERROR);
 /*
