@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: ndi_parse.c,v 6.6 1999/08/27 22:32:56 jsquyres Exp $
+ *	$Id: ndi_parse.c,v 6.8 2000/10/05 23:41:02 jsquyres Exp $
  *
  *	Function:	- node identifier parsing package
  *			- id_range() based in part on Trollius 2.0,
@@ -46,6 +45,7 @@
 #include "all_list.h"
 #include "args.h"
 #include "ndi.h"
+#include "rreq.h"
 #include "lam.h"
 
 #define NEW		1
@@ -63,7 +63,8 @@ void			ndi_usage();
 /*
  * local functions
  */
-static int		id_range();	/* parse a range of identifiers */
+static int id_range(char *s, int4 flags, int *ixp, int is_node, LIST *lp);
+static int resolve_cpu(int cpuid);
 
 /*
  *	ndi_parse
@@ -75,12 +76,7 @@ static int		id_range();	/* parse a range of identifiers */
  *	Returns:	- node list or null
  */
 LIST *
-ndi_parse(argc, argv, othersv)
-
-int			argc;
-char **			argv;
-char ***		othersv;
-
+ndi_parse(int argc, char **argv, char ***othersv)
 {
 	int		index = 0;		/* current index */
 	int		othersc;		/* leftover count */
@@ -115,7 +111,18 @@ char ***		othersv;
  */
 		if ((**argv == 'n') && isdigit((int) *((*argv + 1)))) {
 
-			if (id_range(*argv + 1, 0, &index, nodelist)) {
+			if (id_range(*argv + 1, 0, &index, 1, nodelist)) {
+				al_free(nodelist);
+				if (othersv) argvfree(*othersv);
+				return(0);
+			}
+		}
+/*
+ * Is it a generic CPU identifier?
+ */
+		else if ((**argv == 'c') && isdigit((int) *((*argv + 1)))) {
+
+			if (id_range(*argv + 1, 0, &index, 0, nodelist)) {
 				al_free(nodelist);
 				if (othersv) argvfree(*othersv);
 				return(0);
@@ -139,6 +146,12 @@ char ***		othersv;
 /*
  * Is it a multicast destination?
  */
+/*
+ * The "O" notation is not in any of the current documentation, and is
+ * based on the old OTB stuff, so we're not going to support it
+ * anymore.  JMS 6 March 2000.
+ */
+#if 0
 		else if ((**argv == 'O') && (*(*argv + 1) == '\0')) {
 			newndi.ndi_node = HOST2OTB;
 			newndi.ndi_flags = NT_CAST;
@@ -151,7 +164,11 @@ char ***		othersv;
 				return(0);
 			}
 		}
-
+#endif
+/*
+ * The "C" notation has been redfined from its original OTB definition
+ * -- it now means "one per CPU".
+ */
 		else if ((**argv == 'C') && (*(*argv + 1) == '\0')) {
 			newndi.ndi_node = HOST2COMP;
 			newndi.ndi_flags = NT_CAST;
@@ -204,20 +221,27 @@ char ***		othersv;
  *			- string buffer
  */
 void
-ndi_fmt(node, fmt_str)
-
-int4			node;
-char			*fmt_str;
-
+ndi_fmt(int4 node, char *fmt_str)
 {
 	if (node == NOTNODEID) {
 		strcpy(fmt_str, "?");
 	} else if (node == LOCAL) {
 		strcpy(fmt_str, "local");
+/*
+ * The "O" notation is not in any of the current documentation, and is
+ * based on the old OTB stuff, so we're not going to support it
+ * anymore.  JMS 6 March 2000.
+ */
+#if 0
 	} else if (node == HOST2OTB) {
 		strcpy(fmt_str, "O");
+#endif
 	} else if (node == HOST2ALL) {
 		strcpy(fmt_str, "N");
+/*
+ * The "C" notation has been redfined from its original OTB definition
+ * -- it now means "one per CPU".
+ */
 	} else if (node == HOST2COMP) {
 		strcpy(fmt_str, "C");
 	} else {
@@ -233,10 +257,7 @@ char			*fmt_str;
  *	Returns:	- node identifier
  */
 int4
-ndi_parse1(s)
-
-char			*s;
-
+ndi_parse1(char *s)
 {
 	int4		node;
 
@@ -244,10 +265,21 @@ char			*s;
 		node = LOCAL;
 	} else if (strcmp(s, "local") == 0) {
 		node = LOCAL;
+/*
+ * The "O" notation is not in any of the current documentation, and is
+ * based on the old OTB stuff, so we're not going to support it
+ * anymore.  JMS 6 March 2000.
+ */
+#if 0
 	} else if (strcmp(s, "O") == 0) {
 		node = HOST2OTB;
+#endif
 	} else if (strcmp(s, "N") == 0) {
 		node = HOST2ALL;
+/*
+ * The "C" notation has been redfined from its original OTB definition
+ * -- it now means "one per CPU".
+ */
 	} else if (strcmp(s, "C") == 0) {
 		node = HOST2COMP;
 	}
@@ -255,6 +287,9 @@ char			*s;
 	else if (sscanf(s, " n%d", &node) == 1) {
 	}
 
+	else if (sscanf(s, " c%d", &node) == 1) {
+	}
+
 	else {
 		node = NOTNODEID;
 	}
@@ -269,9 +304,9 @@ char			*s;
  */
 void
 ndi_usage()
-
 {
 	printf("\nNodes:		n<list>, eg., n0-3,5,0xa,12-15\n");
+	printf("\nCPUs:			c<list>, eg., c0-3,5,0xa,12-15\n");
 }
 
 /*
@@ -282,17 +317,12 @@ ndi_usage()
  *	Accepts:	- range string
  *			- flags to use with every value found
  *			- current index ptr
+ *			- flag specifying nodes or CPUs
  *			- list descriptor ptr
  *	Returns:	- 0 or ERROR
  */
 static int
-id_range(s, flags, ixp, lp)
-
-char			*s;
-int4			flags;
-int			*ixp;
-LIST			*lp;
-
+id_range(char *s, int4 flags, int *ixp, int is_node, LIST *lp)
 {
 	int		c;			/* current character */
 	int4		id;			/* current identifier */
@@ -338,12 +368,16 @@ LIST			*lp;
 			s = t;
 
 			if (mode == NEW) {
-				newndi.ndi_node = id;
+				if (is_node)
+				  newndi.ndi_node = id;
+				else
+				  newndi.ndi_node = resolve_cpu(id);
 				newndi.ndi_flags = flags;
 				newndi.ndi_count = 1;
 				newndi.ndi_index = (*ixp)++;
 
-				if (al_append(lp, &newndi) == 0) return(LAMERROR);
+				if (al_append(lp, &newndi) == 0) 
+				  return(LAMERROR);
 
 				oldid = id;
 				mode = ONE;
@@ -357,7 +391,10 @@ LIST			*lp;
 				}
 
 				while (++oldid <= id) {
-					newndi.ndi_node = oldid;
+					if (is_node)
+					  newndi.ndi_node = oldid;
+					else
+					  newndi.ndi_node = resolve_cpu(oldid);
 					newndi.ndi_flags = flags;
 					newndi.ndi_count = 1;
 					newndi.ndi_index = (*ixp)++;
@@ -376,3 +413,57 @@ LIST			*lp;
 
 	return (0);
 }
+
+
+/*
+ *	resolve_cpu
+ *
+ *	Function:	- resolves a CPU id to a node ID
+ *	Accepts:	- cpu ID
+ *	Returns:	- nid or LAMERROR
+ */
+static int 
+resolve_cpu(int cpuid)
+{
+  int i, ncpus;
+  int nnodes;
+  int *nodes;
+  struct route *r;
+
+/*  
+ * Find out how many CPUs we have
+ */
+  nnodes = getntype(0, NT_CAST);
+  nodes = (int *) malloc(sizeof(int) * nnodes);
+  if (nodes == NULL)
+    return (LAMERROR);
+
+  r = (struct route*) malloc(sizeof(struct route) * nnodes);
+  if (r == NULL)
+    return (LAMERROR);
+  getnodes(nodes, nnodes, 0, NT_CAST);
+  for (ncpus = i = 0; i < nnodes; i++) {
+    r[i].r_nodeid = nodes[i];
+    getrent(&r[i]);
+    ncpus += r[i].r_ncpus;
+  }
+
+  if (cpuid < 0 || cpuid >= ncpus) {
+    free(r);
+    free(nodes);
+    return (LAMERROR);
+  }
+/*  
+ * Map the CPU id to an nid
+ */
+  for (ncpus = i = 0; i < nnodes; i++) {
+    if (cpuid < (ncpus + r[i].r_ncpus))
+      break;
+    ncpus += r[i].r_ncpus;
+  }
+
+  free(r);
+  free(nodes);
+
+  return i;
+}
