@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	GDB
  *
- *	$Id: ndi_resolve.c,v 6.3 1999/07/23 03:55:27 jsquyres Exp $
+ *	$Id: ndi_resolve.c,v 6.4 2000/03/06 21:07:21 jsquyres Exp $
  *
  *	Function:	- node identifier resolution
  */
@@ -42,11 +41,13 @@
 #include <net.h>
 #include <portable.h>
 #include <typical.h>
+#include <rreq.h>
 
 /*
  * local functions
  */
-static int		ndi_cast();
+static int
+ndi_cast(LIST *nodelist, int4 type, int4 mask, int is_node, int *ixp);
 
 /*
  *	ndi_resolve
@@ -80,6 +81,12 @@ LIST *			nodelist;
 
 	while (p) {
 
+/*
+ * The "O" notation is not in any of the current documentation, and is
+ * based on the old OTB stuff, so we're not going to support it
+ * anymore.  JMS 6 March 2000.
+ */
+#if 0
 		if (p->ndi_node == HOST2OTB) {
 
 			if (ndi_cast(newnodelist, 0, NT_ITB | NT_CAST,
@@ -87,15 +94,22 @@ LIST *			nodelist;
 				al_free(newnodelist);
 				return(0);
 			}
-		} else if (p->ndi_node == HOST2ALL) {
+		} else 
+#endif
+		if (p->ndi_node == HOST2ALL) {
 
-			if (ndi_cast(newnodelist, 0, NT_CAST, &index)) {
+			if (ndi_cast(newnodelist, 0, NT_CAST, 1, &index)) {
 				al_free(newnodelist);
 				return(0);
 			}
-		} else if (p->ndi_node == HOST2COMP) {
+		} 
+/*
+ * The "C" notation has been redfined from its original OTB definition
+ * -- it now means "one per CPU".
+ */
+		else if (p->ndi_node == HOST2COMP) {
 
-			if (ndi_cast(newnodelist, 0, NT_WASTE | NT_CAST,
+			if (ndi_cast(newnodelist, 0, NT_WASTE | NT_CAST, 0,
 					&index)) {
 				al_free(newnodelist);
 				return(0);
@@ -124,22 +138,18 @@ LIST *			nodelist;
  *	Function:	- expands a cast of nodes
  *	Accepts:	- node type
  *			- node mask
+ *			- whether CPUs or nodes
  *			- current index ptr
  *	Returns:	- 0 or ERROR
  */
 static int
-ndi_cast(nodelist, type, mask, ixp)
-
-LIST *			nodelist;
-int4			type;
-int4			mask;
-int			*ixp;
-
+ndi_cast(LIST *nodelist, int4 type, int4 mask, int is_node, int *ixp)
 {
 	int4		nnodes;			/* node array size */
 	int4		*pnodes;		/* node array */
-	int		i;
+	int		i, j;
 	struct ndi	newnode;		/* new list element */	
+	struct route	r;			/* route entry */
 
 	nnodes = getntype(type, mask);
 	if (nnodes < 0) return(LAMERROR);
@@ -154,15 +164,25 @@ int			*ixp;
 	}
 
 	for (i = 0; i < nnodes; ++i) {
-		newnode.ndi_node = pnodes[i];
-		newnode.ndi_flags = 0;
-		newnode.ndi_count = 1;
-		newnode.ndi_index = (*ixp)++;
-
-		if (al_append(nodelist, &newnode) == 0) {
-		  free((char *) pnodes);
-		  return(LAMERROR);
-		}
+	  newnode.ndi_node = pnodes[i];
+	  newnode.ndi_flags = 0;
+	  newnode.ndi_count = 1;
+	  newnode.ndi_index = (*ixp)++;
+	  if (al_append(nodelist, &newnode) == 0) {
+	    free((char *) pnodes);
+	    return(LAMERROR);
+	  }
+	  if (!is_node) {
+	    r.r_nodeid = pnodes[i];
+	    getrent(&r);
+	    for (j = 1; j < r.r_ncpus; j++) {
+	      if (al_append(nodelist, &newnode) == 0) {
+		free((char *) pnodes);
+		return(LAMERROR);
+	      }
+	    }
+	  }
+	  
 	}
 
 	free((char *) pnodes);
