@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1995 The Ohio State University
  *	GDB
  *
- *	$Id: parse_id.c,v 6.5 1999/08/27 22:33:03 jsquyres Exp $
+ *	$Id: parse_id.c,v 6.9 2000/10/05 23:47:20 jsquyres Exp $
  *
  *	Function:	- identifier parsing package
  *			- id_range() based in part on Trollius 2.0,
@@ -47,32 +46,15 @@
 #include <net.h>
 #include <portable.h>
 #include <preq.h>
+#include <rreq.h>
 #include <terror.h>
 #include <typical.h>
+#include <args.h>
 
 #define NEW		1
 #define ONE		2
 #define MANY		3
 
-/*
- * global functions
- */
-int			nid_parse();
-int			pid_parse();
-void			nid_free();
-void			pid_free();
-void			nid_get();
-void			pid_get();
-char			*nid_fmt();
-int4			nid_count();
-int4			nid_parse1();
-void			nid_usage();
-
-/*
- * external functions
- */
-extern int		xtoi();
-
 /*
  * local variables
  */
@@ -90,9 +72,10 @@ struct id {
 /*
  * local functions
  */
-static int		nid_cast();	/* establish a cast of nodes */
-static int		id_range();	/* parse a range of identifiers */
-static void		id_get();	/* get next ID from list */
+static int nid_cast(int4 type, int4 mask, int is_node, int *ixp);
+static int id_range(char *s, int4 flags, int is_node, int *ixp, LIST *lp);
+static void id_get (int4 *ixp, int4 *idp, int4* flp, LIST *lp);
+static int resolve_cpu(int cpuid);
 
 /*
  *	nid_parse
@@ -104,11 +87,7 @@ static void		id_get();	/* get next ID from list */
  *	Returns:	- 0 or ERROR
  */
 int
-nid_parse(argc, argv)
-
-int			*argc;
-char			**argv;
-
+nid_parse(int *argc, char **argv)
 {
 	int		index = 0;		/* current index */
 	int		othersc;		/* left over count */
@@ -137,9 +116,18 @@ char			**argv;
  */
 		if ((**argv == 'n') && isdigit((int) *(*argv + 1))) {
 
-			if (id_range(*argv + 1, 0, &index, nodelist))
+			if (id_range(*argv + 1, 0, 1, &index, nodelist))
 					return(LAMERROR);
 		}
+/*
+ * Is it a generic CPU identifier?
+ */
+		else if ((**argv == 'c') && isdigit((int) *((*argv + 1)))) {
+
+			if (id_range(*argv + 1, 0, 0, &index, nodelist)) {
+					return(LAMERROR);
+			}
+		}
 /*
  * Is it the local host identifier (h)?
  */
@@ -165,21 +153,32 @@ char			**argv;
 /*
  * Is it a multicast destination?
  */
+/*
+ * The "O" notation is not in any of the current documentation, and is
+ * based on the old OTB stuff, so we're not going to support it
+ * anymore.  JMS 6 March 2000.
+ */
+#if 0
 		else if ((**argv == 'O') && (*(*argv + 1) == '\0')) {
 
 			if (nid_cast(0, NT_ITB | NT_CAST, &index))
 					return(LAMERROR);
 		}
-
+#endif
+/*
+ * The "C" notation has been redfined from its original OTB definition
+ * -- it now means "one per CPU".
+ */
 		else if ((**argv == 'C') && (*(*argv + 1) == '\0')) {
 
-			if (nid_cast(0, NT_WASTE | NT_CAST, &index))
+			if (nid_cast(0, NT_WASTE | NT_CAST, 0, &index))
 					return(LAMERROR);
 		}
 
 		else if ((**argv == 'N') && (*(*argv + 1) == '\0')) {
 
-			if (nid_cast(0, NT_CAST, &index)) return(LAMERROR);
+			if (nid_cast(0, NT_CAST, 1, &index)) 
+			  return(LAMERROR);
 		}
 /*
  * Bump the non-nodeid pointer and counter.
@@ -207,11 +206,7 @@ char			**argv;
  *	Returns:	- 0 or ERROR
  */
 int
-pid_parse(argc, argv)
-
-int			*argc;
-char			**argv;
-
+pid_parse(int *argc, char **argv)
 {
 	int		index = 0;		/* current index */
 	int		othersc;		/* left over count */
@@ -239,7 +234,8 @@ char			**argv;
  */
 		if ((**argv == 'p') && isdigit((int) *(*argv + 1))) {
 
-			if (id_range(*argv + 1, SELECT_PID, &index, proclist))
+			if (id_range(*argv + 1, SELECT_PID, 1, &index, 
+				     proclist))
 					return(LAMERROR);
 		}
 /*
@@ -248,7 +244,7 @@ char			**argv;
 		else if (((**argv == '%') || (**argv == 'i')) &&
 				isdigit((int) *(argv[0] + 1))) {
 
-			if (id_range(*argv + 1, SELECT_INDEX, &index,
+			if (id_range(*argv + 1, SELECT_INDEX, 1, &index,
 					proclist)) return(LAMERROR);
 		}
 /*
@@ -274,7 +270,6 @@ char			**argv;
  */
 void
 nid_free()
-
 {
 	if (!nodelist) return;
 
@@ -289,7 +284,6 @@ nid_free()
  */
 void
 pid_free()
-
 {
 	if (!proclist) return;
 
@@ -307,12 +301,7 @@ pid_free()
  *			- value returned flags ptr
  */
 void
-nid_get (ixp, idp, flp)
-
-int4			*ixp;
-int4			*idp;
-int4			*flp;
-
+nid_get (int4 *ixp, int4 *idp, int4 *flp)
 {
 	id_get(ixp, idp, flp, nodelist);
 }
@@ -327,12 +316,7 @@ int4			*flp;
  *			- value returned flags ptr
  */
 void
-pid_get (ixp, idp, flp)
-
-int4			*ixp;
-int4			*idp;
-int4			*flp;
-
+pid_get (int4 *ixp, int4 *idp, int4 *flp)
 {
 	id_get(ixp, idp, flp, proclist);
 }
@@ -344,14 +328,13 @@ int4			*flp;
  */
 int4
 nid_count()
-
 {
 	struct id	*p;
 
 	if (nodelist == 0) {
 		return(0);
 	} else {
-		p = al_top(nodelist);
+		p = (struct id *) al_top(nodelist);
 		return(p ? p->id_count : 0);
 	}
 }
@@ -364,19 +347,27 @@ nid_count()
  *	Returns:	- mnemonic string
  */
 char *
-nid_fmt(node)
-
-int4			node;
-
+nid_fmt(int4 node)
 {
 	if (node == NOTNODEID) {
 		strcpy(fmt_str, "?");
 	} else if (node == LOCAL) {
 		strcpy(fmt_str, "local");
+/*
+ * The "O" notation is not in any of the current documentation, and is
+ * based on the old OTB stuff, so we're not going to support it
+ * anymore.  JMS 6 March 2000.
+ */
+#if 0
 	} else if (node == HOST2OTB) {
 		strcpy(fmt_str, "O");
+#endif
 	} else if (node == HOST2ALL) {
 		strcpy(fmt_str, "N");
+/*
+ * The "C" notation has been redfined from its original OTB definition
+ * -- it now means "one per CPU".
+ */
 	} else if (node == HOST2COMP) {
 		strcpy(fmt_str, "C");
 	} else if (node == getorigin()) {
@@ -396,10 +387,7 @@ int4			node;
  *	Returns:	- node identifier
  */
 int4
-nid_parse1(s)
-
-char			*s;
-
+nid_parse1(char *s)
 {
 	int4		node;
 
@@ -409,10 +397,21 @@ char			*s;
 		node = getorigin();
 	} else if (strcmp(s, "local") == 0) {
 		node = LOCAL;
+/*
+ * The "O" notation is not in any of the current documentation, and is
+ * based on the old OTB stuff, so we're not going to support it
+ * anymore.  JMS 6 March 2000.
+ */
+#if 0
 	} else if (strcmp(s, "O") == 0) {
 		node = HOST2OTB;
+#endif
 	} else if (strcmp(s, "N") == 0) {
 		node = HOST2ALL;
+/*
+ * The "C" notation has been redfined from its original OTB definition
+ * -- it now means "one per CPU".
+ */
 	} else if (strcmp(s, "C") == 0) {
 		node = HOST2COMP;
 	}
@@ -420,6 +419,9 @@ char			*s;
 	else if (sscanf(s, " n%d", &node) == 1) {
 	}
 
+	else if (sscanf(s, " c%d", &node) == 1) {
+	}
+
 	else {
 		node = NOTNODEID;
 	}
@@ -434,9 +436,9 @@ char			*s;
  */
 void
 nid_usage()
-
 {
 	printf("\nNodes:		n<list>, eg., n0-3,5,0xa,12-15\n");
+	printf("\nCPUs:			c<list>, eg., c0-3,5,0xa,12-15\n");
 }
 
 /*
@@ -447,21 +449,18 @@ nid_usage()
  *			- Trollius version registers with castd
  *	Accepts:	- node type
  *			- node mask
+ *			- whether CPUs or nodes
  *			- current index ptr
  *	Returns:	- 0 or ERROR
  */
 static int
-nid_cast(type, mask, ixp)
-
-int4			type;
-int4			mask;
-int			*ixp;
-
+nid_cast(int4 type, int4 mask, int is_node, int *ixp)
 {
 	int4		nnodes;			/* node array size */
 	int4		*pnodes;		/* node array */
-	int		i;
+	int		i, j;
 	struct id	newid;			/* new list element */	
+	struct route	r;			/* route entry */
 
 	nnodes = getntype(type, mask);
 	if (nnodes < 0) return(LAMERROR);
@@ -477,8 +476,17 @@ int			*ixp;
 		newid.id_flags = 0;
 		newid.id_count = 1;
 		newid.id_index = (*ixp)++;
-
-		if (al_append(nodelist, &newid) == 0) return(LAMERROR);
+		if (al_append(nodelist, &newid) == 0) 
+		  return(LAMERROR);
+		if (!is_node) {
+		  r.r_nodeid = pnodes[i];
+		  getrent(&r);
+		  for (j = 1; j < r.r_ncpus; j++) {
+		    newid.id_index = (*ixp)++;
+		    if (al_append(nodelist, &newid) == 0) 
+		      return(LAMERROR);
+		  }
+		}
 	}
 
 	return(0);
@@ -496,13 +504,7 @@ int			*ixp;
  *			- list descriptor ptr
  */
 static void
-id_get (ixp, idp, flp, lp)
-
-int4			*ixp;
-int4			*idp;
-int4			*flp;
-LIST			*lp;
-
+id_get (int4 *ixp, int4 *idp, int4* flp, LIST *lp)
 {
 	struct id	*p;
 	struct id	newid;
@@ -537,14 +539,8 @@ LIST			*lp;
  *			- list descriptor ptr
  *	Returns:	- 0 or ERROR
  */
-static int
-id_range(s, flags, ixp, lp)
-
-char			*s;
-int4			flags;
-int			*ixp;
-LIST			*lp;
-
+static int 
+id_range(char *s, int4 flags, int is_node, int *ixp, LIST *lp)
 {
 	int		c;			/* current character */
 	int4		id;			/* current identifier */
@@ -590,12 +586,16 @@ LIST			*lp;
 			}
 
 			if (mode == NEW) {
-				newid.id_value = id;
+				if (is_node)
+				  newid.id_value = id;
+				else
+				  newid.id_value = resolve_cpu(id);
 				newid.id_flags = flags;
 				newid.id_count = 1;
 				newid.id_index = (*ixp)++;
 
-				if (al_append(lp, &newid) == 0) return(LAMERROR);
+				if (al_append(lp, &newid) == 0) 
+				  return(LAMERROR);
 
 				oldid = id;
 				mode = ONE;
@@ -609,7 +609,10 @@ LIST			*lp;
 				}
 
 				while (++oldid <= id) {
-					newid.id_value = oldid;
+					if (is_node)
+					  newid.id_value = oldid;
+					else
+					  newid.id_value = resolve_cpu(oldid);
 					newid.id_flags = flags;
 					newid.id_count = 1;
 					newid.id_index = (*ixp)++;
@@ -629,13 +632,69 @@ LIST			*lp;
 	return (0);
 }
 
+/*
+ *	resolve_cpu
+ *
+ *	Function:	- resolves a CPU id to a node ID
+ *	Accepts:	- cpu ID
+ *	Returns:	- nid or LAMERROR
+ */
+static int 
+resolve_cpu(int cpuid)
+{
+  int i, ncpus;
+  int nnodes;
+  int *nodes;
+  struct route *r;
+
+/*  
+ * Find out how many CPUs we have
+ */
+  nnodes = getntype(0, NT_CAST);
+  nodes = (int *) malloc(sizeof(int) * nnodes);
+  if (nodes == NULL)
+    return (LAMERROR);
+
+  r = (struct route*) malloc(sizeof(struct route) * nnodes);
+  if (r == NULL)
+    return (LAMERROR);
+  getnodes(nodes, nnodes, 0, NT_CAST);
+  for (ncpus = i = 0; i < nnodes; i++) {
+    r[i].r_nodeid = nodes[i];
+    getrent(&r[i]);
+    ncpus += r[i].r_ncpus;
+  }
+
+  if (cpuid < 0 || cpuid >= ncpus) {
+    free(r);
+    free(nodes);
+    return (LAMERROR);
+  }
+/*  
+ * Map the CPU id to an nid
+ */
+  for (ncpus = i = 0; i < nnodes; i++) {
+    if (cpuid < (ncpus + r[i].r_ncpus))
+      break;
+    ncpus += r[i].r_ncpus;
+  }
+
+  free(r);
+  free(nodes);
+
+  return i;
+}
+
+#if 0
 /*
  * backwards compatibility
  */
-int parse_nodes(ac, av) int *ac; char **av; { return(nid_parse(ac, av)); }
+/* Down with internal backwards compatability... */
+int parse_nodes(int *ac, char **av) { return(nid_parse(ac, av)); }
 int parse_procs(ac, av) int *ac; char **av; { return(pid_parse(ac, av)); }
 void getnode(ixp, idp, flp) int4 *ixp, *idp, *flp; { nid_get(ixp, idp, flp); }
 void getproc(ixp, idp, flp) int4 *ixp, *idp, *flp; { pid_get(ixp, idp, flp); }
 char *mnemonic(node) int4 node; { return(nid_fmt(node)); }
 int mnnodeid(s) char *s; { return(nid_parse1(s)); }
 void mnusage() { nid_usage(); }
+#endif
