@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	GDB
  *
- *	$Id: pdi_parse.c,v 6.5 1999/08/27 22:33:10 jsquyres Exp $
+ *	$Id: pdi_parse.c,v 6.7 2000/10/05 23:48:54 jsquyres Exp $
  *
  *	Function:	- node identifier parsing package
  *			- id_range() based in part on Trollius 2.0,
@@ -56,15 +55,10 @@
 #define ONE		2
 #define MANY		3
 
-/*
- * global functions
- */
-LIST *			pdi_parse();
-
 /*
  * local functions
  */
-static int		id_range();	/* parse a range of identifiers */
+static int id_range(char *s, int4 flags, int *ixp, LIST *lp);
 
 /*
  *	pdi_parse
@@ -76,12 +70,7 @@ static int		id_range();	/* parse a range of identifiers */
  *	Returns:	- process list or null
  */
 LIST *
-pdi_parse(argc, argv, othersv)
-
-int			argc;
-char **			argv;
-char ***		othersv;
-
+pdi_parse(int argc, char **argv, char ***othersv)
 {
 	int		index = 0;		/* current index */
 	int		othersc;		/* leftover count */
@@ -165,13 +154,7 @@ char ***		othersv;
  *	Returns:	- 0 or ERROR
  */
 static int
-id_range(s, flags, ixp, lp)
-
-char			*s;
-int4			flags;
-int			*ixp;
-LIST			*lp;
-
+id_range(char *s, int4 flags, int *ixp, LIST *lp)
 {
 	int		c;			/* current character */
 	int4		id;			/* current identifier */
