@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: asc_parse.c,v 6.16 1999/09/04 21:59:38 jsquyres Exp $
+ *	$Id: asc_parse.c,v 6.22 2001/01/23 22:11:59 jsquyres Exp $
  *
  *	Function:	- application schema parsing
  */
@@ -220,6 +219,7 @@ parseline(LIST *appd, char *buf, int bufsize, char **env)
 	char **		argtailv;		/* args after "--" */
 	char *		cmdline;		/* command line buffer */
 	char **		cmdv;			/* command line argv */
+	char **		cmdv_bak;		/* command line argv */
 	char **		othersv;		/* line w/o options */
 	char *		lenv = 0;		/* line environment */
 	char *		wrkdir = 0;		/* working dir */
@@ -256,11 +256,20 @@ parseline(LIST *appd, char *buf, int bufsize, char **env)
 
 	if (cmdv == 0) return(LAMERROR);
 
+	cmdv_bak = cmdv;
 	cmdc = sfh_argv_count(cmdv);
 	if (asc_compat(&cmdc, &cmdv)) {
 	    sfh_argv_free(cmdv);
 	    return(LAMERROR);
 	}
+	/* Ok, I fully admit I don't completely understand this.  But
+           it seems that *sometimes* asc_compat() will replace cmdv
+           without freeing the original.  Since this is the only place
+           in LAM where asc_compat() is called, I feel safe in putting
+           this here instead of fixing asc_compat() itself (I've got
+           more fish to fry...).  Arrrgh!! */
+	if (cmdv_bak != cmdv)
+	  sfh_argv_free(cmdv_bak);
 /*
  * Parse the -c, -s, -x and -wd options and establish argtail.
  * We could use all_opt but we do not want to pull it in.
@@ -277,6 +286,7 @@ parseline(LIST *appd, char *buf, int bufsize, char **env)
 	proc.asc_errno = 0;
 	proc.asc_proc_cnt = -1;
 	proc.asc_srcnode = -1;
+	proc.asc_node = -1;
 	pv1 = cmdv + 1;
 
 	while (*pv1 && strcmp(*pv1, "--")) {
@@ -655,7 +665,7 @@ asc_compat(int *uargc, char ***uargv)
  *	Returns:	- 0 or LAMERROR
  */
 int
-asc_environment(int export, char *varlist, char ***env)
+asc_environment(int exportme, char *varlist, char ***env)
 {
 	extern char	**environ;		/* current environment */
 	char		**p;
@@ -664,19 +674,38 @@ asc_environment(int export, char *varlist, char ***env)
 
 	nenv = sfh_argv_count(*env);
 
-	if (export)
+	if (exportme)
 /*
- * Export all environment variables of form LAM_MPI_* or LAM_IMPI_*.
+ * Export all environment variables of form LAM_MPI_* or LAM_IMPI_* or 
+ * IMPI_*.
  */
 		for (p = environ; p && *p; p++) {
-			if (strncmp(*p, "LAM_MPI_", 8) == 0)
-				if (sfh_argv_add(&nenv, env, *p))
-					return LAMERROR;
+		  if (strncmp(*p, "LAM_MPI_", 8) == 0) {
+		    if (sfh_argv_add(&nenv, env, *p))
+		      return LAMERROR;
+		  }
 #if LAM_WANT_IMPI
-			if (strncmp(*p, "LAM_IMPI_", 8) == 0)
-				if (sfh_argv_add(&nenv, env, *p))
-					return LAMERROR;
+		  else if (strncmp(*p, "LAM_IMPI_", 8) == 0) {
+		    if (sfh_argv_add(&nenv, env, *p))
+		      return LAMERROR;
+		  }
+		  else if (strncmp(*p, "IMPI_", 5) == 0) {
+		    if (sfh_argv_add(&nenv, env, *p))
+		      return LAMERROR;
+		  }
 #endif
+/*
+ * Also export the PBS_ENVIRONMENT and PBS_JOBID vars, if they exist.
+ * This allows us to use the right unix socket names on the other side.
+ */
+		  else if (strncmp(*p, "PBS_ENVIRONMENT=", 16) == 0) {
+		    if (sfh_argv_add(&nenv, env, *p))
+		      return LAMERROR;
+		  }
+		  else if (strncmp(*p, "PBS_JOBID=", 10) == 0) {
+		    if (sfh_argv_add(&nenv, env, *p))
+		      return LAMERROR;
+		  }
 		}
 /*
  * Export explicitly specified variables.
