@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: asc_run.c,v 6.9 1999/07/29 21:09:12 jsquyres Exp $
+ *	$Id: asc_run.c,v 6.12 2000/10/06 21:03:12 jsquyres Exp $
  *
  *	Function:	- application execution
  */
@@ -54,12 +53,6 @@
 #include <terror.h>
 #include <typical.h>
 
-/*
- * global functions
- */
-int			asc_ger();
-int			asc_run();
-
 /*
  * external variables
  */
@@ -68,8 +61,8 @@ extern struct kio_t	_kio;			/* kernel I/O block */
 /*
  * local functions
  */
-static void		fdincr();
-static void		starterror();
+static void fdincr(int4 incr);
+static void starterror(char *file, int nodeid, int prerror);
 
 /*
  *	asc_ger
@@ -79,11 +72,7 @@ static void		starterror();
  *			- error printing flag
  */
 int
-asc_ger(appd, flag_print)
-
-LIST			*appd;
-int			flag_print;
-
+asc_ger(LIST *appd, int flag_print)
 {
 	int4		anode;			/* LOCAL filtered out */
 	int4		nnodes;			/* # nodes in session */
@@ -126,7 +115,7 @@ int			flag_print;
 
 			if (flag_print) {
 				fprintf(stderr, "mpirun: %s: ",
-						mnemonic(p->asc_node));
+						nid_fmt(p->asc_node));
 				terror("");
 			}
 
@@ -174,7 +163,7 @@ int			flag_print;
 				fprintf(stderr,
 			    "mpirun: cannot allocate GER (%d bytes) on %s: ",
 						bfp.bfp_maxspace,
-						mnemonic(nodes[i]));
+						nid_fmt(nodes[i]));
 				terror("");
 			}
 
@@ -202,15 +191,8 @@ int			flag_print;
  *	Returns:	- 0 or LAMERROR
  */
 int
-asc_run(appd, nparent, rtf, verbose, prerror, pgps)
-
-LIST			*appd;
-int			nparent;
-int4			rtf;
-int			verbose;
-int			prerror;
-struct _gps		*pgps;
-
+asc_run(LIST *appd, int nparent, int4 rtf, int verbose, int prerror,
+	struct _gps *pgps)
 {
     struct aschema 	*pp;			/* ptr process entry */
     int4		world_save;		/* saved ki_world */
@@ -292,7 +274,7 @@ struct _gps		*pgps;
 
 	temp_rtf = rtf & ~(RTF_PFDIO | RTF_TRYCWD);
 	if (rploadgov(pp->asc_srcnode, pp->asc_node,
-		pp->asc_args->apa_argv[0], temp_rtf|pfdio|trycwd,
+		pp->asc_args->apa_argv[0], (temp_rtf | pfdio | trycwd),
 	        pp->asc_args->apa_argv, &env, &pid, &idx)) {
 
 	    pp->asc_errno = errno;
@@ -311,7 +293,7 @@ struct _gps		*pgps;
 
 	if (verbose) {
 	    printf("%d %s running on %s\n", pid, pp->asc_args->apa_argv[0],
-		mnemonic(pp->asc_node));
+		nid_fmt(pp->asc_node));
 	    fflush(stdout);
 	}
     }
@@ -366,7 +348,7 @@ starterror(char *file, int nodeid, int prerror)
 {
     if (prerror) {
 	fprintf(stderr, "mpirun: cannot start %s on %s: ",
-				file, mnemonic(nodeid));
+		file, nid_fmt(nodeid));
 	terror("");
     }
 }
