@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	GDB
  *
- *	$Id: lambootagent.c,v 6.7 1999/08/14 22:57:18 lamteam Exp $
+ *	$Id: lambootagent.c,v 6.16 2001/04/01 22:45:48 jsquyres Exp $
  * 
  *	Function:	- LAM boot agent
  *	Accepts:	- link array
@@ -47,6 +46,7 @@
 #include <string.h>
 #include <unistd.h>
 
+#include <laminternal.h>
 #include <args.h>
 #include <debug.h>
 #include <lamnet.h>
@@ -54,44 +54,21 @@
 #include <portable.h>
 #include <terror.h>
 #include <typical.h>
-
-/*
- * connection default timeout value
- */
-#ifndef TO_BOOT
-#define TO_BOOT	60
-#endif
+#include <sfh.h>
+#include <boot.h>
+#include <etc_misc.h>
 
 /*
  * local variables
  */
-static int		fl_debug;		/* debug mode */
-static int		fl_verbose;		/* verbose mode */
-static char		buf[128];
-
-/*
- * external functions
- */
-extern int		sfh_sock_open_srv_inet_stm();
-extern int		sfh_sock_open_clt_inet_stm();
-extern int		sfh_sock_accept_tmout();
-extern int		_lam_few();
-extern int		inetexec();
-extern int		readcltcoord();
-extern int		writecltnbr();
-extern int		writesockint4();
-extern void		nodespin_end();
-extern void		nodespin_init();
-extern void		nodespin_next();
+static int fl_debug;		/* debug mode */
+static int fl_verbose;		/* verbose mode */
+static int fl_fast;		/* check for .profile or not */
+static int fl_close;		/* close local lamd stdout/stderr? */
+static char buf[256];
 
 int
-lambootagent(lamnet, nlamnet, nboot, nrun)
-
-struct lamnode		*lamnet;
-int			nlamnet;
-int			*nboot;
-int			*nrun;
-
+lambootagent(struct lamnode *lamnet, int nlamnet, int *nboot, int *nrun)
 {
 	int		agent_port;	/* port number for replies */
 	int		agent_sd;	/* socket for replies */
@@ -103,6 +80,7 @@ int			*nrun;
 	int4		local;		/* local node ID */
 	int4		origin;		/* origin node ID */
 	char		**cmdv;		/* command vector */
+	char		*batchid;	/* batch job ID */
 	unsigned char	*p;
 
 	*nboot = 0;
@@ -116,6 +94,8 @@ int			*nrun;
  */
 	fl_debug = opt_taken('d');
 	fl_verbose = opt_taken('v');
+	fl_fast = opt_taken('b');
+	fl_close = opt_taken('s');
 /*
  * Allocate a server socket and port.
  */
@@ -182,7 +162,7 @@ int			*nrun;
 		argvadd(&cmdc, &cmdv, DEFTHBOOT);
 		argvadd(&cmdc, &cmdv, "-t");
 		argvadd(&cmdc, &cmdv, "-c");
-		argvadd(&cmdc, &cmdv, "conf.lam");
+		argvadd(&cmdc, &cmdv, "lam-conf.lam");
 
 		if (fl_debug) {
 			argvadd(&cmdc, &cmdv, "-d");
@@ -191,17 +171,29 @@ int			*nrun;
 			argvadd(&cmdc, &cmdv, "-v");
 		}
 /*
- * If remote node, close stdio of processes.
+ * If remote node, close stdio of processes, unless forced by the
+ * command line with -s (see fl_close, above) -- this is useful, for
+ * example, in "rsh somenode lamboot hostfile", because we need the
+ * hboot/lamd on somenode to close their stdio so that rsh can finish.
  */
-		if (i != local) {
+		if (i != local || fl_close) {
 			argvadd(&cmdc, &cmdv, "-s");
 		}
+/*
+ * If this is under a batch system, pass the -b to both hboot and to
+ * the $inet_topo varaible
+ */
+		batchid = get_batchid();
+		if (strlen(batchid) > 0) {
+		  argvadd(&cmdc, &cmdv, "-b");
+		  argvadd(&cmdc, &cmdv, batchid); 
+		}
 /*
  * Override the $inet_topo variable.
  */
 		p = (unsigned char *) &lamnet[local].lnd_addr.sin_addr;
 		argvadd(&cmdc, &cmdv, "-I");
-		sprintf(buf, "%c%s-H %u.%u.%u.%u -P %d -n %d -o %d%c",
+		sprintf(buf, "%c%s-H %u.%u.%u.%u -P %d -n %d -o %d %s %s%c",
 			i == local ? ' ' : '"',
 			opt_taken('x') ? "-x " : "",
 			(unsigned) p[0], (unsigned) p[1],
@@ -209,11 +201,15 @@ int			*nrun;
 			agent_port,
 			i,
 			origin,
+			(strlen(batchid) == 0 ? " " : "-b"),
+			(strlen(batchid) == 0 ? " " : batchid),
 			i == local ? ' ' : '"');
 		argvadd(&cmdc, &cmdv, buf);
 
-		VERBOSE("Executing %s on n%d (%s)...\n", DEFTHBOOT, i, 
-			lamnet[i].lnd_hname);
+		VERBOSE("Executing %s on n%d (%s - %d CPU%s)...\n", 
+			DEFTHBOOT, i, lamnet[i].lnd_hname,
+			lamnet[i].lnd_ncpus, 
+			(lamnet[i].lnd_ncpus > 1) ? "s" : "");
 
 		(*nboot)++;
 
@@ -221,16 +217,16 @@ int			*nrun;
 		        if (fl_debug) {
 			  int j;
 			  
-			  fprintf(stderr, "lamboot: attempting to execute \"");
+			  printf("lamboot: attempting to execute \"");
 			  for (j = 0; j < cmdc; j++) {
 			    if (j > 0)
-			      fprintf(stderr, " ");
+			      printf(" ");
 			    if (strchr(cmdv[j], ' ') != NULL)
-			      fprintf(stderr, "\"%s\"", cmdv[j]);
+			      printf("\"%s\"", cmdv[j]);
 			    else
-			      fprintf(stderr, "%s", cmdv[j]);
+			      printf("%s", cmdv[j]);
 			  }
-			  fprintf(stderr, "\"\n");
+			  printf("\"\n");
 			}
 			r = _lam_few(cmdv);
 
@@ -243,7 +239,8 @@ int			*nrun;
 			}
 		} else {
 			r = inetexec(lamnet[i].lnd_hname, lamnet[i].lnd_uname,
-				     cmdv, (fl_debug ? "lamboot" : NULL));
+				     cmdv, (fl_debug ? "lamboot" : NULL),
+				     fl_fast);
 
 			if (r) {
 				(*nboot)--;
@@ -256,7 +253,7 @@ int			*nrun;
 /*
  * Accept a connection from the new host.
  */
-		boot_sd = sfh_sock_accept_tmout(agent_sd, TO_BOOT);
+		boot_sd = sfh_sock_accept_tmout(agent_sd, LAM_TO_BOOT);
 		if (boot_sd < 0) return(LAMERROR);
 /*
  * Read the new host port numbers.
@@ -309,8 +306,11 @@ int			*nrun;
 			if (writecltnbr(boot_sd,
 					(lamnet[j].lnd_nodeid == NOTNODEID) ?
 					NOTLINKID : j,
-					&lamnet[j].lnd_addr.sin_addr, (int)
-					ntohs(lamnet[j].lnd_addr.sin_port)))
+					(unsigned char*) 
+					&lamnet[j].lnd_addr.sin_addr,
+					(int)
+					ntohs(lamnet[j].lnd_addr.sin_port),
+					lamnet[j].lnd_ncpus))
 					return(LAMERROR);
 		}
 
