@@ -1,44 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1995 The Ohio State University
  *	GDB
  *
- *	$Log: proc_schema.c,v $
- *	Revision 6.2  1999/05/23 19:28:25  kmeyer1
- *	added copyrights
- *	
- *	Revision 6.1  1996/11/24 00:44:58  nevin
- *	Ohio Release
- *	
- * Revision 6.0  96/02/29  13:41:26  gdburns
- * Ohio Release
+ *      $Id: proc_schema.c,v 6.5 2000/11/02 07:21:10 jsquyres Exp $
  * 
  *	Function:	- process schema operations
  */
@@ -46,35 +37,25 @@
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
+#include <stdlib.h>
 
 #include <all_list.h>
 #include <args.h>
 #include <proc_schema.h>
 #include <typical.h>
-
-/*
- * public functions
- */
-int			psc_parse();
-struct psc		*psc_find();
-int			cnfexec();
-
-/*
- * external functions
- */
-extern char		*_path_env_find();
-extern int		_lam_few();
+#include <etc_misc.h>
+#include <sfh.h>
 
 /*
  * private functions
  */
-static void		var_substitute();
+static void var_substitute(struct psc *ppsc, char *var, char **argv_var);
 
 /*
  * private variables
  */
-static char		line[PSC_MAXLINE];
-static char		*seps = " 	,=\n";
+static char line[PSC_MAXLINE];
+static char *seps = " 	,=\n";
 
 /*
  *	psc_parse
@@ -85,12 +66,7 @@ static char		*seps = " 	,=\n";
  *			- substitution variables
  */
 int
-psc_parse(fp, list_psc, argv_var)
-
-FILE			*fp;
-LIST			**list_psc;
-char			**argv_var;
-
+psc_parse(FILE *fp, LIST **list_psc, char **argv_var)
 {
 	char		*r;
 	char		*token;
@@ -152,10 +128,7 @@ char			**argv_var;
  *	Returns:	- 0 or ptr to program that can't be located
  */
 struct psc *
-psc_find(list_psc)
-
-LIST			*list_psc;
-
+psc_find(LIST *list_psc)
 {
 	char		*full;		/* full pathname */
 	struct psc	*p;
@@ -168,7 +141,7 @@ LIST			*list_psc;
 
 		if (p->psc_argv == 0) continue;
 
-		full = _path_env_find(p->psc_argv[0], R_OK | X_OK);
+		full = sfh_path_env_find(p->psc_argv[0], R_OK | X_OK);
 
 		if (! full) {
 			return(p);
@@ -188,10 +161,7 @@ LIST			*list_psc;
  *	Returns:	- status code or ERROR
  */
 int
-cnfexec(argv)
-
-char			*argv[];
-
+cnfexec(char *argv[])
 {
 	return(_lam_few(argv));
 }
@@ -206,30 +176,24 @@ char			*argv[];
  *			- substitution variable vector
  */
 static void
-var_substitute(ppsc, var, argv_var)
-
-struct psc		*ppsc;
-char			*var;
-char			**argv_var;
-
+var_substitute(struct psc *ppsc, char *var, char **argv_var)
 {
-	char		**p;
-	char		*token;
+  char **p;
+  char **args;
+  
+  if (argv_var == 0) 
+    return;
+  
+  for (p = argv_var; *p; p++)
+    if (!strncmp(*p, var, strlen(var))) 
+      break;
 
-	if (argv_var == 0) return;
-
-	for (p = argv_var; *p; p++) {
-
-		if (! strncmp(*p, var, strlen(var))) break;
-	}
-
-	if (*p) {
-		token = strtok(*p, seps);
-		token = strtok((char *) 0, seps);
-
-		while (token) {
-			argvadd(&ppsc->psc_argc, &ppsc->psc_argv, token);
-			token = strtok((char *) 0, seps);
-		}
-	}
+  /* We can't nest the use of strtok here */
+  if (*p) {
+    args = sfh_argv_break(*p, ' ');
+    for (p = args + 1; *p != NULL; p++) {
+      sfh_argv_add(&ppsc->psc_argc, &ppsc->psc_argv, *p);
+    }
+    free(args);
+  }
 }
