@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: blktype.c,v 6.4 1999/08/05 00:10:18 jsquyres Exp $
+ *	$Id: blktype.c,v 6.8 2000/10/16 01:21:28 jsquyres Exp $
  *
  *	Function:	- get description of blocking request type code
  *	Accepts:	- request type code
@@ -361,14 +360,22 @@ static CONST char	*blkdesc[] = {
 
 		"mpirun",                       /* BLKMPIRUN */
 
+		"XMPI_Buoy",                    /* BLKXMPIBUOY */
+		"XMPI_Coloron",                 /* BLKXMPICOLORON */
+		"XMPI_Coloroff",                /* BLKXMPICOLOROFF */
+
 		"LAM_IMPI_router_daemon",       /* BLKIMPIDAEMON */
+
+		"IMPI_Barrier",                 /* BLKIMPIBARRIER */
+		"IMPI_Bcast",                   /* BLKIMPIBCAST */
+		"IMPI_Gather",                  /* BLKIMPIGATHER */
+		"IMPI_Allgather"                /* BLKIMPIALLGATHER */
+		"IMPI_Reduce",                  /* BLKIMPIREDUCE */
+		"IMPI_Allreduce"                /* BLKIMPIALLREDUCE */
 		};
 
 char *
-blktype(type)
-
-int4			type;
-
+blktype(int4 type)
 {
 	char	*p;
 
