@@ -1,69 +1,36 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1994 The Ohio State University
  *	RBD
  *
- *	$Log: bootsockio.c,v $
- *	Revision 6.2  1999/05/24 16:56:48  kmeyer1
- *	added $copyright$
- *	
- *	Revision 6.1  1996/11/23 19:57:52  nevin
- *	Ohio Release
- *	
- * Revision 6.0  96/02/29  13:46:29  gdburns
- * Ohio Release
- * 
- * Revision 5.2  94/08/22  13:56:59  gdburns
- * Ohio Release
- * 
- * Revision 5.1  94/05/18  10:56:40  gdburns
- * Ohio Release
- * 
- * Revision 2.3  94/04/22  12:34:56  gdburns
- * Ohio Release
- * 
- * Revision 2.2.1.4  94/01/12  13:58:21  raja
- * Exclude nodeid from coordinate exchange.
- * 
- * Revision 2.2.1.3  93/10/15  14:03:35  raja
- * Add support for dl_inet UDP port.
- * 
- * Revision 2.2.1.2  93/07/20  16:44:27  raja
- * Change host address to 4 unsigned bytes.
- * 
- * Revision 2.2.1.1  93/07/09  15:43:42  raja
- * Modify to support host network address, not hostname.
- * 
- * Revision 2.2  93/05/04  14:35:27  raja
- * pre-release to 2.3
- * 
+ *	$Id: bootsockio.c,v 6.3 2000/03/06 21:13:23 jsquyres Exp $
+ *
  *	Function:	- OTB booting socket I/O functions
  *				- readsockint4(): read an int4 from a socket
  *				- writesockint4(): read an int4 to a socket
@@ -216,20 +183,23 @@ int4			udpport;
 /*
  *	readcltnbr
  *
- *	Function:	- read client neighbour <link index, hostaddr, port>
+ *	Function:	- read client neighbour <link index, hostaddr, port,
+ *                                               ncpus>
  *	Accepts:	- socket
  *			- ptr link index
  *			- ptr host address (4 bytes, in network byte order)
  *			- ptr port number
+ *			- ptr num cpus
  *	Returns:	- 0 or ERROR
  */
 int
-readcltnbr(sock, plink, phostaddr, pport)
+readcltnbr(sock, plink, phostaddr, pport, pnum_cpus)
 
 int			sock;
 int4			*plink;
 unsigned char		*phostaddr;
 int4			*pport;
+int4			*pnum_cpus;
 
 {
 	int		ret;
@@ -248,27 +218,34 @@ int4			*pport;
 		return(ERROR);
 	}
 
+	if (readsockint4(sock, pnum_cpus)) {
+		return(ERROR);
+	}
+
 	return(0);
 }
 
 /*
  *	writecltnbr
  *
- *	Function:	- write client neighbour <link index, hostaddr, port>
+ *	Function:	- write client neighbour <link index, hostaddr, port, 
+ *                                                ncpus>
  *			- called by the booting server
  *	Accepts:	- socket
  *			- link index
  *			- host address (4 bytes, in network byte order)
  *			- port number
+ *			- num cpus
  *	Returns:	- 0 or ERROR
  */
 int
-writecltnbr(sock, link, hostaddr, port)
+writecltnbr(sock, link, hostaddr, port, num_cpus)
 
 int			sock;
 int4			link;
 unsigned char		*hostaddr;
 int4			port;
+int4			num_cpus;
 
 {
 	int		ret;
@@ -287,5 +264,9 @@ int4			port;
 		return(ERROR);
 	}
 
+	if (writesockint4(sock, num_cpus)) {
+		return(ERROR);
+	}
+
 	return(0);
 }
