@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB/RBD
  *
- *	$Id: mrw.c,v 6.5 1999/08/27 22:33:34 jsquyres Exp $
+ *	$Id: mrw.c,v 6.6 2000/10/17 17:49:55 jsquyres Exp $
  * 
  *	Function:	- atomic reads and writes
  *			- continues through partial transfers and interrupts
@@ -53,12 +52,7 @@
  *	Returns:	- #bytes read or ERROR
  */
 int4
-mread(fd, buf, nbytes)
-
-int			fd;
-char			*buf;
-int4			nbytes;
-
+mread(int fd, char *buf, int4 nbytes)
 {
 	int		nread;		/* # of bytes read */
 	int		r;
@@ -93,12 +87,7 @@ int4			nbytes;
  *	Returns:	- #bytes read or ERROR
  */
 int4
-mreadv(fd, iov, iovcnt)
-
-int			fd;
-struct iovec		*iov;
-int			iovcnt;
-
+mreadv(int fd, struct iovec *iov, int iovcnt)
 {
 	int		nread;		/* # of bytes read */
 	int		r;
@@ -181,12 +170,7 @@ int			iovcnt;
  *	Returns:	- #bytes written or ERROR
  */
 int4
-mwrite(fd, buf, nbytes)
-
-int			fd;
-CONST char		*buf;
-int			nbytes;
-
+mwrite(int fd, CONST char *buf, int nbytes)
 {
 	int		nwritten;	/* # of bytes written */
 	int		r;
@@ -221,12 +205,7 @@ int			nbytes;
  *	Returns:	- #bytes written or ERROR
  */
 int4
-mwritev(fd, iov, iovcnt)
-
-int			fd;
-struct iovec		*iov;
-int			iovcnt;
-
+mwritev(int fd, struct iovec *iov, int iovcnt)
 {
 	int		nwritten;	/* # of bytes written */
 	int		r;
