@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State Universtiy
  *	GDB
  *
- *	$Id: terror.c,v 6.6 1999/08/31 01:11:39 jsquyres Exp $
+ *	$Id: terror.c,v 6.9 2001/01/16 20:45:35 arodrig6 Exp $
  *
  *	Function:	- Trollius error messages
  */
@@ -111,6 +110,8 @@ static CONST char	*lam_emsg[] = {
 		"name is not published",	/* ENOTPUBLISHED */
 		"ptys not supported",		/* ENOPTYSUPPORT */
 		"passing of file descriptors not supported", /* ENOPFDSUPPORT */
+		"MPI already finalized",        /* EMPIALREADYFINALIZE */
+		"dynamic memory allocation failed", /* EMPIMEMERROR */ 
 			};
 
 static char		*baderror = "error code ";
@@ -130,11 +131,7 @@ extern char		*sys_errlist[];
  *			- buffer length
  */
 void
-lam_errorstr(emsgbuf, emsgbuflen)
-
-char			*emsgbuf;
-unint			emsgbuflen;
-
+lam_errorstr(char *emsgbuf, unint emsgbuflen)
 {
 	int		ecode;			/* errno code */
 	int		found = 0;
@@ -146,26 +143,31 @@ unint			emsgbuflen;
 	*emsgbuf = '\0';
 	emsgbuflen--;
 	ecode = LAMGetLastError();
+/*
+ * Look for LAM error message.
+ *
+ * Do this before calling strerror(), because Linux will return
+ * "Unknown error X" for any errno that it does not recognize rather
+ * than NULL or "".
+ */
+	if ((ecode >= ELOW) && (ecode <= EHIGH)) {
+		strncat(emsgbuf, lam_emsg[ecode - ELOW], emsgbuflen);
+		found = 1;
+	}
 /*
  * Look for C runtime error message (errno).
  */
 #ifdef WIN32
-	if ((ecode >= LAM_ERRNO_BASE) &&
+	else if ((ecode >= LAM_ERRNO_BASE) &&
 			(ecode < (LAM_ERRNO_BASE + sys_nerr))) {
 		strncat(emsgbuf, sys_errlist[ecode], emsgbuflen);
 	}
 #else
-	if ((syserrmsg = strerror(ecode))) {
+	else if ((syserrmsg = strerror(ecode)) != NULL &&
+	    strlen(syserrmsg) > 0) {
 		strncat(emsgbuf, syserrmsg, emsgbuflen);
 	}
 #endif
-/*
- * Look for LAM error message.
- */
-	else if ((ecode >= ELOW) && (ecode <= EHIGH)) {
-		strncat(emsgbuf, lam_emsg[ecode - ELOW], emsgbuflen);
-		found = 1;
-	}
 /*
  * Error code is obtained from the system.
  */
@@ -199,10 +201,7 @@ unint			emsgbuflen;
  *	Accepts:	- user's error message
  */
 void
-lam_perror(umsg)
-
-CONST char		*umsg;
-
+lam_perror(CONST char *umsg)
 {
 	char		emsgbuf[LAM_EMSGBUFLEN];
 	unint		l;
