@@ -1,66 +1,41 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1994 The Ohio State University
  *	GDB
  *
- *	$Log: rf77.c,v $
- *	Revision 6.2  1999/05/25 17:44:41  kmeyer1
- *	added copyright
- *	
- *	Revision 6.1  1996/11/23 19:58:46  nevin
- *	Ohio Release
- *	
- * Revision 6.0  96/02/29  13:50:05  gdburns
- * Ohio Release
- * 
- * Revision 5.2  94/08/22  13:59:11  gdburns
- * Ohio Release
- * 
- * Revision 5.1  94/05/18  10:58:07  gdburns
- * Ohio Release
- * 
- * Revision 2.3  94/04/22  12:38:23  gdburns
- * Ohio Release
- * 
- * Revision 2.2.1.1  94/02/21  17:57:40  raja
- * Remove backward compatibility functions.
- * 
- * Revision 2.2  92/04/30  14:41:27  trillium
- * Ohio Release
- *
- * Revision 2.1  91/02/24  20:56:17  gdburns
- * Ohio Release
+ *	$Id: rf77.c,v 6.3 2000/04/06 21:38:32 jsquyres Exp $
  *
  *	Function:	- functions to support F77 I/O
  */
 
+#include <unistd.h>
+
 #include <events.h>
 #include <freq.h>
 #include <ksignal.h>
