@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	GDB
  *
- *	$Id: rfstate.c,v 6.3 1999/05/25 17:44:43 kmeyer1 Exp $
+ *	$Id: rfstate.c,v 6.5 2000/10/19 19:14:55 jsquyres Exp $
  * 
  *	Function:	- gathers state from a remote filed
  *			- receives file descriptors from
@@ -50,7 +49,6 @@
 #include <freq.h>
 #include <ksignal.h>
 #include <net.h>
-#include <string.h>
 #include <terror.h>
 #include <typical.h>
 #include <t_types.h>
@@ -60,13 +58,9 @@
  */
 static char		hole[MAXNMSGLEN];
 
+
 int
-lam_rfstate(nodeid, ftbl, maxcount)
-
-int			nodeid;		/* target node ID */
-int			maxcount;	/* count of descriptor table */
-struct fstate		ftbl[];		/* ptr to descriptor table */
-
+lam_rfstate(int nodeid, struct fstate ftbl[], int maxcount)
 {
 	struct nmsg	nhead;		/* network message desc. */
 	struct freq  	*request;	/* filed request */
@@ -149,8 +143,11 @@ struct fstate		ftbl[];		/* ptr to descriptor table */
 	}
 }
 
+#if 0
+/* Down with backwards compatability! */
 /*
  * backwards compatibility
  */
 int rfstate(nodeid, ftbl, maxcount) int nodeid, maxcount; struct fstate ftbl[];
 	{ return(lam_rfstate(nodeid, ftbl, maxcount)); }
+#endif
