@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: ksignal.c,v 6.4 1999/07/28 00:31:58 jsquyres Exp $
+ *	$Id: ksignal.c,v 6.6 2000/10/30 16:15:09 jsquyres Exp $
  *
  *	Function:	- signal package
  *			- Any kernel request may return one or more signals.
@@ -57,15 +56,21 @@
 /*
  * external variables
  */
-extern struct kio_t	_kio;			/* Kernel Input/Output block */
+extern struct kio_t _kio;			/* Kernel Input/Output block */
 
 /*
  * local functions
  */
-static void		sigign();		/* ignore signal */
-static void		sigexit();		/* terminate process */
-static void		sigflush();		/* flush route cache */
-static void		sigstop();		/* stop process */
+static void sigign(void);		/* ignore signal */
+static void sigexit(void);		/* terminate process */
+static void sigflush(void);		/* flush route cache */
+static void sigstop(int sig);		/* stop process */
+
+/*
+ * local typedef for clean code
+ */
+typedef void (*lam_void_func)();
+
 
 /*
  *	_ksig_follow
@@ -73,8 +78,7 @@ static void		sigstop();		/* stop process */
  *	Function:	- follows signals that may be set in signal word
  */
 void
-_ksig_follow()
-
+_ksig_follow(void)
 {
 	int		i;		/* favourite index variable */
 	int4		sigbit;		/* signal bit */
@@ -112,14 +116,10 @@ _ksig_follow()
  *			- handler function
  *	Returns:	- previous handler function
  */
-void
-(*(ksignal(signo, sigfunc)))()
-
-int			signo;
-void			(*sigfunc)();
-
+lam_void_func 
+ksignal(int signo, lam_void_func sigfunc)
 {
-	void		(*oldsigfunc)();
+	lam_void_func oldsigfunc;
 
 	if ((signo < 1) || (signo > TNSIG)) {
 		errno = EINVAL;
@@ -151,8 +151,7 @@ void			(*sigfunc)();
  *	Function:	- initializes signal handling table
  */
 void
-_ksig_init()
-
+_ksig_init(void)
 {
 	int		i;			/* favourite index variable */
 /*
@@ -160,7 +159,7 @@ _ksig_init()
  * Don't block any signals.
  * No signals are currently pending.
  */
-	_kio.ki_sigretry = ~(sigmask(SIGRELEASE));
+	_kio.ki_sigretry = (int4) ~(sigmask(SIGRELEASE));
 	_kio.ki_sigmask = 0;
 	_kio.ki_signal = 0;
 /*
@@ -189,8 +188,7 @@ _ksig_init()
  *	Function:	- flushes the route cache
  */
 static void
-sigflush()
-
+sigflush(void)
 {
 	int		i;
 
@@ -207,7 +205,9 @@ sigflush()
  *	Function:	- ignores a signal
  */
 static void
-sigign() {}
+sigign(void) 
+{
+}
 
 /*
  *	sigexit
@@ -215,8 +215,7 @@ sigign() {}
  *	Function:	- terminates the process
  */
 static void
-sigexit()
-
+sigexit(void)
 {
 	kexit(1);
 }
@@ -230,10 +229,7 @@ sigexit()
  *	Accepts:	- signal that caused sigstop to be called
  */
 static void
-sigstop(sig)
-
-int			sig;
-
+sigstop(int sig)
 {
 	struct kmsg	forever;		/* local message descriptor */
 
@@ -254,8 +250,7 @@ int			sig;
  *	Returns:	- ERROR
  */
 int
-kpause()
-
+kpause(void)
 {
 	int		save_retry;
 
@@ -278,10 +273,7 @@ kpause()
  *	Returns:	- old value of mask or flags
  */
 int
-ksigsetmask(mask)
-
-int			mask;
-
+ksigsetmask(int mask)
 {
 	int		oldmask;		/* previous signal mask */
 
@@ -299,10 +291,7 @@ int			mask;
 }
 
 int
-ksigblock(mask)
-
-int			mask;
-
+ksigblock(int mask)
 {
 	int		oldmask;		/* previous signal mask */
 
@@ -313,10 +302,7 @@ int			mask;
 }
 
 int
-ksigsetretry(flags)
-
-int			flags;
-
+ksigsetretry(int flags)
 {
 	int		oldflags;		/* previous retry flags */
 
@@ -327,10 +313,7 @@ int			flags;
 }
 
 int
-ksigretry(flags)
-
-int			flags;			/* new retry flags */
-
+ksigretry(int flags)
 {
 	int		oldflags;		/* previous retry flags */
 
@@ -349,7 +332,8 @@ int			flags;			/* new retry flags */
  *	
  *	Function:	- de-rigeur wrappers
  */
-void (*(lam_ksignal(signo, sigfunc)))() int signo; void (*sigfunc)();
+lam_void_func
+lam_ksignal(int signo, lam_void_func sigfunc)
 { return(ksignal(signo, sigfunc)); }
 
 int lam_kpause() { return(kpause()); }
