@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	JRV/RBD
  *
- *	$Id: allreduce.c,v 6.3 1999/08/04 21:43:48 kmeyer1 Exp $
+ *	$Id: allreduce.c,v 6.5 2000/10/13 17:57:32 jsquyres Exp $
  *
  *	Function:	- reduce and return data to all processes
  *	Accepts:	- send buffer
@@ -47,16 +46,40 @@
 #include <mpi.h>
 #include <mpisys.h>
 
-int
-MPI_Allreduce(sbuf, rbuf, count, dtype, op, comm)
+/*@
 
-void			*sbuf;
-void			*rbuf;
-int			count;
-MPI_Datatype		dtype;
-MPI_Op			op;
-MPI_Comm		comm;
+MPI_Allreduce - Combines values from all processes and distribute the result
+                back to all processes
 
+Input Parameters:
++ sbuf - starting address of send buffer (choice) 
+. count - number of elements in send buffer (integer) 
+. dtype - data type of elements of send buffer (handle) 
+. op - operation (handle) 
+- comm - communicator (handle) 
+
+Output Parameter:
+. rbuf - starting address of receive buffer (choice) 
+
+.N IMPI_YES
+
+.N fortran
+
+.N collops
+
+.N Errors
+.N MPI_ERR_COMM
+.N MPI_ERR_INTERCOMM
+.N MPI_ERR_IMPI
+.N MPI_ERR_BUFFER
+.N MPI_ERR_COUNT
+.N MPI_ERR_TYPE
+.N MPI_ERR_OP
+
+.N ACK
+@*/
+int MPI_Allreduce(void *sbuf, void *rbuf, int count, 
+		  MPI_Datatype dtype, MPI_Op op, MPI_Comm comm)
 {
 	int		err;			/* error code */
 
@@ -75,17 +98,6 @@ MPI_Comm		comm;
 				lam_mkerr(MPI_ERR_TYPE, 0)));
 	}
 
-
-#if LAM_WANT_IMPI
-
-	/* Remove this when IMPI collectives are implemented */
-
-        if (LAM_IS_IMPI(comm)) {
-	  return lam_err_comm(comm, MPI_ERR_COMM, 0, 
-			      "Collectives not yet implemented on IMPI communicators");
-	}
-#endif
-
 	LAM_TRACE(lam_tr_cffstart(BLKMPIALLREDUCE));
 /*
  * Reduce to 0 and broadcast.
