@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD
  *
- *	$Id: alltoall.c,v 6.4 1999/08/04 21:43:48 kmeyer1 Exp $
+ *	$Id: alltoall.c,v 6.5 1999/12/31 21:27:15 jsquyres Exp $
  *
  *	Function:	- send/recv data from each node to all nodes
  *	Accepts:	- send buffer
@@ -58,17 +57,48 @@ static int		c2c_alltoall();
 static int		lamd_alltoall();
 
 
-int
-MPI_Alltoall(sbuf, scount, sdtype, rbuf, rcount, rdtype, comm)
+/*@
 
-void			*sbuf;
-int			scount;
-MPI_Datatype		sdtype;
-void			*rbuf;
-int			rcount;
-MPI_Datatype		rdtype;
-MPI_Comm		comm;
+MPI_Alltoall - Sends data from all to all processes
 
+Input Parameters:
++ sbuf - starting address of send buffer (choice) 
+. scount - number of elements to send to each process (integer) 
+. sdtype - data type of send buffer elements (handle) 
+. rcount - number of elements received from any process (integer) 
+. rdtype - data type of receive buffer elements (handle) 
+- comm - communicator (handle) 
+
+Output Parameter:
+. rbuf - address of receive buffer (choice) 
+
+Notes:
+
+The 'rcount' parameter is the value to be expected from `each`
+process, not the total that is expected from `all` processes.  The
+receive buffer 'rbuf', however, needs to be large enough to hold the
+data that will be received from `all` processes, however.
+
+For example, 'scount' and 'sdtype' and typically the same as 'rcount'
+and 'rdtype'.
+
+.N IMPI
+
+.N fortran
+
+.N Errors
+.N MPI_ERR_COMM
+.N MPI_ERR_INTERCOMM
+.N MPI_ERR_IMPI
+.N MPI_ERR_COUNT
+.N MPI_ERR_TYPE
+.N MPI_ERR_BUFFER
+
+.N ACK
+@*/
+int MPI_Alltoall(void *sbuf, int scount, MPI_Datatype sdtype, 
+		 void* rbuf, int rcount, MPI_Datatype rdtype, 
+		 MPI_Comm comm)
 {
 	lam_initerr();
 	lam_setfunc(BLKMPIALLTOALL);
