@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD
  *
- *	$Id: alltoallv.c,v 6.4 1999/08/04 21:43:49 kmeyer1 Exp $
+ *	$Id: alltoallv.c,v 6.5 1999/12/31 21:27:15 jsquyres Exp $
  *
  *	Function:	- send/recv var. len. data from each node to all nodes
  *	Accepts:	- send buffer
@@ -60,20 +59,53 @@ static int		c2c_alltoallv();
 static int		lamd_alltoallv();
 
 
-int
-MPI_Alltoallv(sbuf, scounts, sdisps, sdtype,
-		rbuf, rcounts, rdisps, rdtype, comm)
+/*@
 
-void			*sbuf;
-int			*scounts;
-int			*sdisps;
-MPI_Datatype		sdtype;
-void			*rbuf;
-int			*rcounts;
-int			*rdisps;
-MPI_Datatype		rdtype;
-MPI_Comm		comm;
+MPI_Alltoallv - Sends data from all to all processes, with a displacement
 
+Input Parameters:
++ sbuf - starting address of send buffer (choice) 
+. scounts - integer array equal to the group size 
+specifying the number of elements to send to each processor 
+. sdisps - integer array (of length group size). Entry 
+ 'j'  specifies the displacement (relative to sendbuf  from
+which to take the outgoing data destined for process  'j'  
+. sdtype - data type of send buffer elements (handle) 
+. rcounts - integer array equal to the group size 
+specifying the maximum number of elements that can be received from
+each processor 
+. rdisps - integer array (of length group size). Entry 
+ 'i'  specifies the displacement (relative to recvbuf  at
+which to place the incoming data from process  'i'  
+. rdtype - data type of receive buffer elements (handle) 
+- comm - communicator (handle) 
+
+Output Parameter:
+. rbuf - address of receive buffer (choice) 
+
+Notes:
+
+The receive buffer 'rbuf' needs to be large enough to hold the data
+that will be received from `all` processes.
+
+.N IMPI
+
+.N fortran
+
+.N Errors
+.N MPI_ERR_COMM
+.N MPI_ERR_INTERCOMM
+.N MPI_ERR_IMPI
+.N MPI_ERR_COUNT
+.N MPI_ERR_TYPE
+.N MPI_ERR_BUFFER
+
+.N ACK
+@*/
+int MPI_Alltoallv(void *sbuf, int *scounts, int *sdisps, 
+		  MPI_Datatype sdtype, void *rbuf, int *rcounts, 
+		  int *rdisps, MPI_Datatype rdtype, 
+		  MPI_Comm comm)
 {
 /*
  * Check for invalid arguments.
