@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD
  *
- *	$Id: barrier.c,v 6.3 1999/08/04 21:42:46 kmeyer1 Exp $
+ *	$Id: barrier.c,v 6.5 2000/10/13 04:21:28 jsquyres Exp $
  *
  *	Function:	- barrier synchronization
  *	Accepts:	- communicator
@@ -50,11 +49,40 @@
 static int		barrier_lin();
 static int		barrier_log();
 
-int
-MPI_Barrier(comm)
+/*@
 
-MPI_Comm		comm;
+MPI_Barrier - Blocks until all process have reached this routine.
 
+Input Parameters:
+. comm - communicator (handle) 
+
+Notes:
+
+Blocks the caller until all group members have called it; the call
+returns at any process only after all group members have entered the
+call.
+
+.N IMPI_YES
+
+Algorithm:  
+
+For 4 or less ranks, a linear algorithm is used, where rank 0
+first receives synchronization message from each other rank.  Rank 0
+then sends out a synchronization message to each other rank.
+
+If more than 4 ranks are involved, a tree-based algorithm is used to
+receive and then send the synchronization messages to and from rank 0.
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_INTERCOMM
+
+.N ACK
+@*/
+int MPI_Barrier(MPI_Comm comm)
 {
 	int		size;			/* group size */
 /*
@@ -81,9 +109,11 @@ MPI_Comm		comm;
  */
 
 #if LAM_WANT_IMPI
-	if (LAM_IS_IMPI(comm))
-	  return(IMPI_Barrier(comm));
-	else {
+	if (LAM_IS_IMPI(comm)) {
+	  int ret = IMPI_Barrier(comm);
+	  lam_resetfunc(BLKMPIBARRIER);
+	  return ret;
+	} else {
 	  MPI_Comm_size(comm, &size);
 	  if (size <= LAM_COLLMAXLIN) {
 	    return(barrier_lin(comm));
