@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN/RBD
  *
- *	$Id: bcast.c,v 6.4 1999/08/04 18:43:03 jsquyres Exp $
+ *	$Id: bcast.c,v 6.7 2000/10/17 11:48:46 jsquyres Exp $
  *
  *	Function:	- broadcast info to all nodes SIMD-style
  *	Accepts:	- buffer
@@ -41,12 +40,17 @@
  *	Returns:	- MPI_SUCCESS or an MPI error code
  */
 
+#include <lam_config.h>
+
 #include <app_mgmt.h>
 #include <blktype.h>
 #include <mpi.h>
 #include <mpisys.h>
 #include <mpitrace.h>
 #include <rpisys.h>
+#if LAM_WANT_IMPI
+#include <impi.h>
+#endif
 
 /*
  * local functions
@@ -56,15 +60,43 @@ static int		bcast_log();
 static int		bcast_lin_lamd();
 static int		bcast_log_lamd();
 
-int
-MPI_Bcast(buff, count, datatype, root, comm)
+/*@
 
-void			*buff;
-int			count;
-MPI_Datatype		datatype;
-int			root;
-MPI_Comm		comm;
+MPI_Bcast - Broadcasts a message from the process with rank "root" to
+            all other processes of the group. 
 
+Input/output Parameters:
++ buff - starting address of buffer (choice) 
+. count - number of entries in buffer (integer) 
+. datatype - data type of buffer (handle) 
+. root - rank of broadcast root (integer) 
+- comm - communicator (handle) 
+
+.N IMPI_YES
+
+Algorithm:  
+
+For 4 or less ranks, a linear algorithm is used, where rank 0
+loops over sending the message to each other rank.
+
+If more than 4 ranks are involved, a tree-based algorithm is used to
+send the messages from rank 0.
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_INTERCOMM
+.N MPI_ERR_COUNT
+.N MPI_ERR_TYPE
+.N MPI_ERR_BUFFER
+.N MPI_ERR_ROOT
+
+.N ACK
+@*/
+int MPI_Bcast(void *buff, int count, MPI_Datatype datatype, 
+	      int root, MPI_Comm comm)
 {
     int			size;			/* group size */
     struct _gps		*p;			/* favourite pointer */
@@ -92,12 +124,6 @@ MPI_Comm		comm;
 	return(lam_errfunc(comm, BLKMPIBCAST, lam_mkerr(MPI_ERR_ROOT, 0)));
     }
 
-#if LAM_WANT_IMPI
-    if (LAM_IS_IMPI(comm)) {
-      return lam_err_comm(comm, MPI_ERR_COMM, 0, "Collectives not yet implemented on IMPI communicators");
-    }
-#endif
-
     LAM_TRACE(lam_tr_cffstart(BLKMPIBCAST));
 /*
  * Set debugging parameters.
@@ -121,6 +147,11 @@ MPI_Comm		comm;
 	lam_resetfunc(BLKMPIBCAST);
 	return(MPI_SUCCESS);
     }
+#if LAM_WANT_IMPI
+    else if (LAM_IS_IMPI(comm)) {
+      return IMPI_Bcast(buff, count, datatype, root, comm);
+    } 
+#endif
     else if (size <= LAM_COLLMAXLIN) {
 	return(RPI_SPLIT(bcast_lin_lamd, bcast_lin,
 	    		(buff, count, datatype, root, comm)));
