@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: cancel.c,v 6.3 1999/05/25 22:07:44 kmeyer1 Exp $
+ *	$Id: cancel.c,v 6.4 1999/12/31 21:27:17 jsquyres Exp $
  *
  *	Function:	- marks immediate request for cancellation
  *	Accepts:	- ptr request
@@ -42,11 +41,39 @@
 #include <mpisys.h>
 #include <rpisys.h>
 
-int
-MPI_Cancel(preq)
+/*@
+    MPI_Cancel - Cancels a communication request
 
-MPI_Request		*preq;
+Input Parameter:
+. preq - communication request (handle) 
 
+Notes:
+
+Cancel has only been implemented for receive requests; it is a no-op
+for send requests.  The primary expected use of MPI_Cancel is in
+multi-buffering schemes, where speculative 'MPI_Irecv' calls are made.
+When the computation completes, some of these receive requests may
+remain; using 'MPI_Cancel' allows the user to cancel these unsatisfied
+requests.
+
+Cancelling a send operation is `much` more difficult, in large part
+because the send will usually be at least partially complete (the
+information on the tag, size, and source are usually sent immediately
+to the destination).  As such, LAM/MPI has not implemented the
+canceling of send operations.
+
+.N NULL
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_REQUEST
+.N MPI_ERR_ARG
+
+.N ACK
+@*/
+int MPI_Cancel(MPI_Request *preq)
 {
 	MPI_Request	req;
 
@@ -57,12 +84,12 @@ MPI_Request		*preq;
  */
 	if (preq == 0) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICANCEL, lam_mkerr(MPI_ERR_REQUEST, 0)));
+			BLKMPICANCEL, lam_mkerr(MPI_ERR_ARG, 0)));
 	}
 
 	if ((req = *preq) == MPI_REQUEST_NULL) {
 		return(lam_errfunc(MPI_COMM_WORLD,
-			BLKMPICANCEL, lam_mkerr(MPI_ERR_REQUEST, 0)));
+			BLKMPICANCEL, lam_mkerr(MPI_ERR_ARG, 0)));
 	}
 
 	if (req->rq_state == LAM_RQSINIT) {
