@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD
  *
- *	$Id: cartcoords.c,v 6.3 1999/05/25 22:07:44 kmeyer1 Exp $
+ *	$Id: cartcoords.c,v 6.4 1999/12/31 21:27:17 jsquyres Exp $
  *
  *	Function:	- translate rank to coordinates
  *	Accepts:	- communicator
@@ -44,14 +43,34 @@
 #include <mpi.h>
 #include <mpisys.h>
 
-int
-MPI_Cart_coords(comm, rank, maxdims, coords)
+/*@
 
-MPI_Comm		comm;
-int			rank;
-int			maxdims;
-int			*coords;
+MPI_Cart_coords - Determines process coords in cartesian topology given
+                  rank in group
 
+Input Parameters:
++ comm - communicator with cartesian structure (handle) 
+. rank - rank of a process within group of 'comm' (integer) 
+- maxdims - length of vector 'coords' in the calling program (integer) 
+
+Output Parameter:
+. coords - integer array (of size 'ndims') containing the cartesian
+coordinates of specified process (integer)
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_TOPOLOGY
+.N MPI_ERR_RANK
+.N MPI_ERR_DIMS
+.N MPI_ERR_ARG
+
+.N ACK
+@*/
+int MPI_Cart_coords(MPI_Comm comm, int rank, int maxdims, 
+		    int *coords)
 {
 	int		dim;
 	int		remprocs;
