@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD
  *
- *	$Id: cartsub.c,v 6.3 1999/09/14 21:50:51 jsquyres Exp $
+ *	$Id: cartsub.c,v 6.4 1999/12/31 21:27:18 jsquyres Exp $
  *
  *	Function:	- divide cartesian communicator into sub-grids
  *	Accepts:	- old communicator
@@ -46,13 +45,32 @@
 #include <mpisys.h>
 #include <terror.h>
 
-int
-MPI_Cart_sub(comm, remdims, pnewcomm)
+/*@
 
-MPI_Comm		comm;
-int			*remdims;
-MPI_Comm		*pnewcomm;
+MPI_Cart_sub - Partitions a communicator into subgroups which 
+               form lower-dimensional cartesian subgrids
 
+Input Parameters:
++ comm - communicator with cartesian structure (handle) 
+- remdims - the 'i'th entry of 'remdims' specifies whether the 'i'th
+dimension is kept in the subgrid (true) or is dropped (false) (logical
+vector)
+
+Output Parameter:
+. pnewcomm - communicator containing the subgrid that includes the
+calling process (handle)
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_TOPOLOGY
+.N MPI_ERR_COMM
+.N MPI_ERR_ARG
+
+.N ACK
+@*/
+int MPI_Cart_sub(MPI_Comm comm, int *remdims, MPI_Comm *pnewcomm)
 {
 	MPI_Comm	newcomm;
 	int		errcode;
