@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: ccreate.c,v 6.3 1999/08/04 21:43:49 kmeyer1 Exp $
+ *	$Id: ccreate.c,v 6.4 1999/12/31 21:27:19 jsquyres Exp $
  *
  *	Function:	- create a new communicator
  *	Accepts:	- old communicator
@@ -53,13 +52,37 @@
 extern int		lam_cubedim();
 extern int		lam_tr_comm();
 
-int
-MPI_Comm_create(comm, group, newcomm)
+/*@
 
-MPI_Comm		comm;
-MPI_Group		group;
-MPI_Comm		*newcomm;
+MPI_Comm_create - Creates a new communicator
 
+Input Parameters:
++ comm - communicator (handle) 
+- group - group, which is a subset of the group of 'comm'  (handle) 
+
+Output Parameter:
+. newcomm - new communicator (handle) 
+
+Notes:
+
+When a communicator is no longer being used, it should be freed with
+'MPI_Comm_free'.
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_GROUP
+.N MPI_ERR_EXHAUSTED
+.N MPI_ERR_INTERN
+
+.seealso: MPI_Comm_free
+
+.N ACK
+@*/
+int MPI_Comm_create(MPI_Comm comm, MPI_Group group, 
+		    MPI_Comm *newcomm)
 {
 	int		mycid;			/* local max context ID */
 	int		cid;			/* global max context ID */
