@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB/NJN
  *
- *	$Id: cdup.c,v 6.5 1999/08/04 21:43:49 kmeyer1 Exp $
+ *	$Id: cdup.c,v 6.6 1999/12/31 21:27:19 jsquyres Exp $
  *
  *	Function:	- duplicate a communicator
  *	Accepts:	- old communicator
@@ -50,12 +49,35 @@
 #include <rpisys.h>
 
 
-int
-MPI_Comm_dup(comm, newcomm)
+/*@
 
-MPI_Comm		comm;
-MPI_Comm		*newcomm;
+MPI_Comm_dup - Duplicates an existing communicator with all its cached
+               information
 
+Input Parameter:
+. comm - communicator (handle) 
+
+Output Parameter:
+. newcomm - copy of 'comm' (handle) 
+
+Notes:
+
+As per standard, this is a collective call over all processes in 'comm'.
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_ARG
+.N MPI_ERR_INTERN
+.N MPI_ERR_EXHAUSTED
+
+.seealso: MPI_Comm_free
+
+.N ACK
+@*/
+int MPI_Comm_dup(MPI_Comm comm, MPI_Comm* newcomm)
 {
 	MPI_Request	req;			
 	MPI_Status	stat;
