@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: connect.c,v 6.7 1999/09/21 02:07:58 jsquyres Exp $
+ *	$Id: connect.c,v 6.8 2001/01/22 17:35:37 jsquyres Exp $
  *
  *	Function:	- connect to an MPI port
  *	Accepts:	- port name
@@ -62,19 +61,54 @@
 /*
  * private functions
  */
-static int		connect_to_port();
-static void		fill_fyi();
+static int connect_to_port(char *port_name, MPI_Comm comm, int cid, 
+			   int *svrcid, int *svrsize, struct _gps **svrgps);
+static void fill_fyi(MPI_Comm comm);
 
 
+/*@
+   MPI_Comm_connect - Make a connection to another MPI process
+
+Input Parameters:
++ port_name - port name (only used at root)
+. info - extra information handle (only used at root)
+. root - rank in comm of root node
+- comm - intracommunicator over which the call is collective
+
+Output Parameter:
++ newcomm - intercommunicator with server as remote group
+
+Description:
+
+The 'MPI_Comm_accept' and 'MPI_Comm_connect' calls simulate the
+well-understood 'accept()'/'connect()' semantics of standard socket
+programming -- a client "connects" to a server.
+
+LAM/MPI allows for previously-unrelated MPI programs to join into a
+MPI program with these calls.  Both MPI programs must be running by
+the same user in the same LAM universe (i.e., in the scope of a single
+lamboot).
+
+.N fortran
+
+.N IMPI_MPI2
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_ROOT
+.N MPI_ERR_ARG
+.N MPI_ERR_INTERN
+.N MPI_ERR_OTHER
+.N MPI_ERR_FLAGS
+
+.seealso MPI_Close_port(3), MPI_Comm_accept(3), MPI_Open_port(3)
+
+.N WEB
+@*/
 int
-MPI_Comm_connect(port_name, info, root, comm, newcomm)
-
-char			*port_name;
-MPI_Info		info;
-int			root;
-MPI_Comm		comm;
-MPI_Comm		*newcomm;
-
+MPI_Comm_connect(char *port_name, MPI_Info info, int root, MPI_Comm comm,
+		 MPI_Comm *newcomm)
 {
 	struct _proc	**p;
 	struct _gps	*g;
@@ -282,15 +316,8 @@ MPI_Comm		*newcomm;
  *	Returns:	- MPI_SUCCESS or error code
  */
 static int
-connect_to_port(port_name, comm, cid, svrcid, svrsize, svrgps)
-
-char 			*port_name;
-MPI_Comm		comm;
-int			cid;
-int			*svrcid;
-int			*svrsize;
-struct _gps		**svrgps;
-
+connect_to_port(char *port_name, MPI_Comm comm, int cid, int *svrcid, 
+		int *svrsize, struct _gps **svrgps)
 {
 	struct nmsg	inmsg;			/* incoming message header */
 	struct nmsg	outmsg;			/* outgoing message header */
@@ -415,10 +442,7 @@ struct _gps		**svrgps;
  *	Accepts:	- communicator
  */
 static void
-fill_fyi(comm)
-
-MPI_Comm		comm;
-
+fill_fyi(MPI_Comm comm)
 {
 	struct _fyiproc *fyi;                   /* FYI space in KIO */
 
