@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD
  *
- *	$Id: dimscreate.c,v 6.2 1999/05/25 22:07:51 kmeyer1 Exp $
+ *	$Id: dimscreate.c,v 6.3 1999/12/31 21:27:21 jsquyres Exp $
  *
  *	Function:	- select "best" grid dimensions
  *			- "Greed is good, greed works!" (Gecko)
@@ -55,13 +54,29 @@ static int		assignprocs();
 static int		getfactors();
 static int		getprimes();
 
-int
-MPI_Dims_create(nprocs, ndims, dims)
+/*@
 
-int			nprocs;
-int			ndims;
-int			*dims;
+MPI_Dims_create - Creates a division of processors in a cartesian grid
 
+Input Parameters:
++ nprocs - number of nodes in a grid (integer) 
+- ndims - number of cartesian dimensions (integer) 
+
+In/Out Parameter:   
+. dims - integer array of size 'ndims' specifying the number of nodes
+in each dimension
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_DIMS
+.N MPI_ERR_ARG
+.N MPI_ERR_EXHAUSTED
+
+.N ACK
+@*/
+int MPI_Dims_create(int nprocs, int ndims, int *dims)
 {
 	int		i;
 	int		freeprocs;
