@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: errstring.c,v 6.3 1999/05/25 22:07:52 kmeyer1 Exp $
+ *	$Id: errstring.c,v 6.7 2001/02/26 04:55:27 jsquyres Exp $
  *
  *	Function:	- return the MPI error message
  *	Accepts:	- error code
@@ -89,16 +88,39 @@ static CONST char	*mpierrmsg[] = {
 	"operation not supported on type",	/* MPI_ERR_TYPENOTSUP */
 	"invalid info key",			/* MPI_ERR_INFO_KEY */
 	"invalid info value",			/* MPI_ERR_INFO_VALUE */
+	"could not allocate memory",		/* MPI_ERR_NOMEM */
+	"invalid base argument",		/* MPI_ERR_BASE */
 	"last error code (huh?)",		/* MPI_ERR_LASTCODE */
 	};
 
-int
-MPI_Error_string(errcode, msg, plen)
+/*@
+   MPI_Error_string - Return a string for a given error code
 
-int			errcode;
-char			*msg;
-int			*plen;
+Input Parameters:
+. errcode - Error code returned by an MPI routine or an MPI error
+class
 
+Output Parameter:
++ msg - Text that corresponds to the errorcode 
+- plen - Length of string 
+
+Notes:  
+
+Error codes are the values return by MPI routines (in C) or in the
+'ierr' argument (in Fortran).  These can be converted into error
+classes with the routine 'MPI_Error_class'.
+
+These messages are provided in English (En_US - English/United
+States).  If there is an interest in providing messages in different
+languages, please submit requests to the LAM mailing list (see
+'http://www.lam-mpi.org/contact.php').
+
+.N fortran
+
+.N ACK
+@*/
+int MPI_Error_string(int errcode, char *msg, 
+		     int *plen)
 {
 	int		class;			/* error class */
 	int		funct;			/* error function */
