@@ -1,37 +1,36 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: finalize.c,v 6.11 1999/11/12 05:19:29 jsquyres Exp $
+ *	$Id: finalize.c,v 6.15 2000/08/17 14:50:14 jsquyres Exp $
  *
  *	Function:	- terminate the MPI session
  *	Returns:	- MPI_SUCCESS or error code
@@ -50,6 +49,7 @@
 #include <trreq.h>
 #include <typical.h>
 #include <t_types.h>
+#include <lamthreads.h>
 #if LAM_WANT_IMPI
 #include <impi.h>
 #endif
@@ -72,14 +72,47 @@ static void		free_f77();
 static void		free_op();
 static void		free_rdtype();
 
-int
-MPI_Finalize()
+/*@
+   MPI_Finalize - Terminates MPI execution environment
 
+Notes:
+
+All processes must call this routine before exiting.  The number of
+processes running `after` this routine is called is undefined; it is
+best not to perform much more than a 'return rc' after calling
+'MPI_Finalize'.
+
+MPI mandates that the same thread invoke 'MPI_Init' (or
+'MPI_Init_thread') and 'MPI_Finalize'; if a different thread invokes
+'MPI_Finalize', 'MPI_ERR_OTHER' will be returned, and MPI will not be
+finalized.
+
+.N fortran
+
+.N Errors
+.N MPI_ERR_INTERN
+. MPI_ERR_OTHER - Returned if a different thread attempts to finalize
+MPI than the thread that initialized MPI.
+
+.seealso MPI_Init, MPI_Init_thread
+
+.N ACK
+@*/
+int MPI_Finalize(void)
 {
 	int		err;			/* error code */
 	
 	lam_initerr();
 	lam_setfunc(BLKMPIFINAL);
+/*
+ * Ensure that if we started with MPI_Init_thread that this is the
+ * same thread that invoked MPI_Init_thread.
+ */
+	if (lam_thread_level > MPI_THREAD_SINGLE && 
+	    !lam_thread_compare(lam_thread_self(), lam_main_thread)) {
+		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIFINAL, 
+				   lam_mkerr(MPI_ERR_ARG, 0)));
+	}
 
 	LAM_TRACE(lam_tr_cffstart(BLKMPIFINAL));
 /*
@@ -130,13 +163,16 @@ MPI_Finalize()
 		lam_mpi_reset_sighandlers();
 	}
 
-	lam_flinit = 0;
 	lam_flfinal = 1;
 	lam_kexit(0);
 
 	lam_resetfunc(BLKMPIFINAL);
 	lam_nukefunc();
 
+	if (lam_thread_level > MPI_THREAD_SINGLE) {
+	  lam_thread_finalize();
+	}
+
 	return(MPI_SUCCESS);
 }
 
