@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD/JRV
  *
- *	$Id: gatherv.c,v 6.3 1999/08/04 21:43:50 kmeyer1 Exp $
+ *	$Id: gatherv.c,v 6.4 1999/12/31 21:27:24 jsquyres Exp $
  *
  *	Function:	- gather vectored buffers at root in process rank order
  *	Accepts:	- send buffer
@@ -52,20 +51,48 @@
 #include <mpisys.h>
 #include <rpisys.h>
 
-int
-MPI_Gatherv(sbuf, scount, sdtype,
-			rbuf, rcounts, disps, rdtype, root, comm)
+/*@
 
-void			*sbuf;
-int			scount;
-MPI_Datatype		sdtype;
-void			*rbuf;
-int			*rcounts;
-int			*disps;
-MPI_Datatype		rdtype;
-int			root;
-MPI_Comm		comm;
+MPI_Gatherv - Gathers into specified locations from all processes in a group
 
+Input Parameters:
++ sendbuf - starting address of send buffer (choice) 
+. sendcount - number of elements in send buffer (integer) 
+. sendtype - data type of send buffer elements (handle) 
+. recvcounts - integer array (of length group size) 
+containing the number of elements that are received from each process
+(significant only at 'root') 
+. displs - integer array (of length group size). Entry 
+ 'i'  specifies the displacement relative to recvbuf  at
+which to place the incoming data from process  'i'  (significant only
+at root) 
+. recvtype - data type of recv buffer elements 
+(significant only at 'root') (handle) 
+. root - rank of receiving process (integer) 
+- comm - communicator (handle) 
+
+Output Parameter:
+. recvbuf - address of receive buffer (choice, significant only at 'root') 
+
+.N IMPI
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_INTERCOMM
+.N MPI_ERR_IMPI
+.N MPI_ERR_TYPE
+.N MPI_ERR_BUFFER
+.N MPI_ERR_ROOT
+.N MPI_ERR_ARG
+
+.N ACK
+@*/
+int MPI_Gatherv(void *sbuf, int scount, MPI_Datatype sdtype,
+		void *rbuf, int *rcounts, int *disps, 
+		MPI_Datatype rdtype, int root, MPI_Comm comm)
 {
 	int		i;			/* favourite index */
 	int		rank;			/* my rank */
