@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD
  *
- *	$Id: gcmp.c,v 6.3 1999/05/25 22:07:53 kmeyer1 Exp $
+ *	$Id: gcmp.c,v 6.5 1999/12/31 23:16:42 jsquyres Exp $
  *
  *	Function:	- compare two groups
  *	Accepts:	- first group
@@ -52,13 +51,31 @@
  */
 static int		proccmp();
 
-int
-MPI_Group_compare(g1, g2, pres)
+/*@
 
-MPI_Group		g1;
-MPI_Group		g2;
-int			*pres;
+MPI_Group_compare - Compares two groups
 
+Input Parameters:
++ g1 - group1 (handle) 
+- g2 - group2 (handle) 
+
+Output Parameter:
+. pres - integer which is 'MPI_IDENT' if the order and members of the
+two groups are the same, 'MPI_SIMILAR' if only the members are the
+same, and 'MPI_UNEQUAL' otherwise
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_GROUP
+.N MPI_ERR_ARG
+.N MPI_ERR_EXHAUSTED
+
+.N ACK
+@*/
+int MPI_Group_compare(MPI_Group g1, MPI_Group g2, 
+		      int *pres)
 {
 	int		i;			/* favourite index */
 	struct _proc	**p1, **p2;		/* favourite pointers */
