@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: getelem.c,v 6.4 1999/05/25 22:07:54 kmeyer1 Exp $
+ *	$Id: getelem.c,v 6.5 1999/12/31 21:27:25 jsquyres Exp $
  *
  *	Function:	- get # bottom-level elements
  *	Accepts:	- status
@@ -49,13 +48,36 @@
 static int		subcount();
 
 
-int
-MPI_Get_elements(stat, dtype, count)
+/*@
+  MPI_Get_elements - Returns the number of basic elements
+                     in a datatype
 
-MPI_Status		*stat;
-MPI_Datatype		dtype;
-int			*count;
+Input Parameters:
++ stat - return status of receive operation (Status) 
+- dtype - datatype used by receive operation (handle) 
 
+Output Parameter:
+. count - number of received basic elements (integer) 
+
+Notes:
+
+It is `not` legal to pass 'MPI_STATUS_IGNORE' as 'stat' to this
+function.
+
+'count' will be set to 'MPI_UNDEFINED' if the size of the datatype is
+zero.
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_ARG
+.N MPI_ERR_TYPE
+
+.N ACK
+@*/
+int MPI_Get_elements(MPI_Status *stat, MPI_Datatype dtype, 
+		     int *count)
 {
 	int		elts;			/* # basic elements */
 	int		integral;		/* # integral dtype copies */
