@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: graphcreate.c,v 6.3 1999/05/25 22:07:56 kmeyer1 Exp $
+ *	$Id: graphcreate.c,v 6.4 1999/12/31 21:27:27 jsquyres Exp $
  *
  *	Function:	- create a communicator with graph mapping
  *	Accepts:	- old communicator
@@ -49,16 +48,36 @@
 #include <mpisys.h>
 #include <terror.h>
 
-int
-MPI_Graph_create(comm, nnodes, index, edges, reorder, newcomm)
+/*@
 
-MPI_Comm		comm;
-int			nnodes;
-int			*index;
-int			*edges;
-int			reorder;
-MPI_Comm		*newcomm;
+MPI_Graph_create - Makes a new communicator to which topology information
+                 has been attached
 
+Input Parameters:
++ comm - input communicator without topology (handle) 
+. nnodes - number of nodes in graph (integer) 
+. index - array of integers describing node degrees (see below) 
+. edges - array of integers describing graph edges (see below) 
+- reorder - ranking may be reordered (true) or not (false) (logical) 
+
+Output Parameter:
+. newcomm - communicator with graph topology added (handle) 
+
+Algorithm:
+
+LAM/MPI currently ignores the 'reorder' flag.
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_ARG
+
+.N ACK
+@*/
+int MPI_Graph_create(MPI_Comm comm, int nnodes, int *index, 
+		     int *edges, int reorder, MPI_Comm *newcomm)
 {
 	MPI_Group	newgroup;
 	int		nedges;
