@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: grincl.c,v 6.3 1999/05/25 22:07:57 kmeyer1 Exp $
+ *	$Id: grincl.c,v 6.4 1999/12/31 21:27:28 jsquyres Exp $
  *
  *	Function:	- form a new group by range inclusion
  *	Accepts:	- original group
@@ -49,14 +48,42 @@
 #include <net.h>
 #include <terror.h>
 
-int
-MPI_Group_range_incl(g, n, ranges, png)
+/*@
 
-MPI_Group		g;
-int			n;
-int			ranges[][3];
-MPI_Group		*png;
+MPI_Group_range_incl - Creates a new group from ranges of ranks in an 
+        existing group
 
+Input Parameters:
++ g - group (handle) 
+. n - number of triplets in array  'ranges' (integer) 
+- ranges - a one-dimensional array of integer triplets, of the 
+form (first rank, last rank, stride) indicating ranks in
+'g'  or processes to be included in 'png'  
+
+Output Parameter:
+. png - new group derived from above, in the order defined by 'ranges'
+(handle)
+
+Note:
+
+When a group is no longer being used, it should be freed with
+'MPI_Group_free'.
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_GROUP
+.N MPI_ERR_EXHAUSTED
+.N MPI_ERR_ARG
+.N MPI_ERR_RANK
+
+.seealso: MPI_Group_free
+
+.N ACK
+@*/
+int MPI_Group_range_incl(MPI_Group g, int n, 
+			 int ranges[][3], MPI_Group *png)
 {
 	int		i, j;
 	int		nproc;			/* # processes */
