@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD
  *
- *	$Id: iccreate.c,v 6.4 1999/08/04 21:43:50 kmeyer1 Exp $
+ *	$Id: iccreate.c,v 6.5 1999/12/31 21:27:29 jsquyres Exp $
  *
  *	Function:	- create a new inter-communicator
  *	Accepts:	- local intra-communicator
@@ -52,16 +51,53 @@
 #include <rpisys.h>
 #include <terror.h>
 
-int
-MPI_Intercomm_create(lcomm, lleader, pcomm, pleader, tag, newcomm)
+/*@
 
-MPI_Comm		lcomm;
-int			lleader;
-MPI_Comm		pcomm;
-int			pleader;
-int			tag;
-MPI_Comm		*newcomm;
+MPI_Intercomm_create - Creates an intercommuncator from two
+intracommunicators
 
+Input Paramters:
++ lcomm - Local (intra)communicator
+. lleader - Rank in local_comm of leader (often 0)
+. pcomm - Remote communicator
+. pleader - Rank in peer_comm of remote leader (often 0)
+- tag - Message tag to use in constructing intercommunicator; if
+multiple 'MPI_Intercomm_creates' are being made, they should use
+different tags (more precisely, ensure that the local and remote
+leaders are using different tags for each 'MPI_intercomm_create').
+
+Output Parameter:
+. newcomm - Created intercommunicator
+
+Notes:
+
+The MPI 1.1 Standard contains two mutually exclusive comments on the
+input intracommunicators.  One says that their repective groups must
+be disjoint; the other that the leaders can be the same process.
+After some discussion by the MPI Forum, it has been decided that the
+groups must be disjoint.  Note that the `reason` given for this in the
+standard is `not` the reason for this choice; rather, the `other`
+operations on intercommunicators (like 'MPI_Intercomm_merge') do not
+make sense if the groups are not disjoint.
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_TAG
+.N MPI_ERR_ARG
+.N MPI_ERR_EXHAUSTED
+.N MPI_ERR_RANK
+
+.seealso: MPI_Intercomm_merge, MPI_Comm_free, MPI_Comm_remote_group, 
+          MPI_Comm_remote_size
+
+.N ACK
+@*/
+int MPI_Intercomm_create(MPI_Comm lcomm, int lleader, 
+			 MPI_Comm pcomm, int pleader, int tag, 
+			 MPI_Comm *newcomm)
 {
 	MPI_Status	stat;			/* message status */
 	MPI_Group	lgroup;			/* local group */
