@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: icmerge.c,v 6.4 1999/08/04 21:43:50 kmeyer1 Exp $
+ *	$Id: icmerge.c,v 6.5 1999/12/31 21:27:29 jsquyres Exp $
  *
  *	Function:	- merge inter-communicator into intra-communicator
  *	Accepts:	- inter-communicator
@@ -49,13 +48,32 @@
 #include <rpisys.h>
 
 
-int
-MPI_Intercomm_merge(comm, high, newcomm)
+/*@
 
-MPI_Comm		comm;
-int			high;
-MPI_Comm		*newcomm;
+MPI_Intercomm_merge - Creates an intracommuncator from an intercommunicator
 
+Input Parameters:
++ comm - Intercommunicator
+- high - Used to order the groups of the two intracommunicators within comm
+  when creating the new communicator.  
+
+Output Parameter:
+. newcomm - Created intracommunicator
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_ARG
+.N MPI_ERR_EXHAUSTED
+
+.seealso: MPI_Intercomm_create, MPI_Comm_free
+
+.N ACK
+@*/
+int MPI_Intercomm_merge(MPI_Comm comm, int high, 
+			MPI_Comm *newcomm)
 {
 	MPI_Request	req;
 	MPI_Status	stat;
