@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: infoget.c,v 6.3 1999/05/25 22:08:00 kmeyer1 Exp $
+ *	$Id: infoget.c,v 6.6 2001/02/03 20:24:44 jsquyres Exp $
  *
  *	Function:	- get info value associated with key 
  *	Accepts:	- info
@@ -50,15 +49,35 @@
 #include <terror.h>
 
 
-int
-MPI_Info_get(info, key, valuelen, value, flag)
+/*@
+  MPI_Info_get - Get a (key, value) pair from an 'MPI_Info' object
 
-MPI_Info		info;
-char			*key;
-int			valuelen;
-char			*value;
-int			*flag;
+Input Parameters:
++ info - info object (handle)
+. key - null-terminated character string of the index key
+. valuelen - maximum length of 'value' (integer)
 
+Output Parameters:
++ value - null-terminated character string of the value
+- flag - true (1) if 'key' defined on 'info', false (0) if not
+(logical)
+
+Notes:
+
+In C and C++, 'valuelen' should be one less than the allocated space
+to allow for for the null terminator.
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_ARG
+.N MPI_ERR_INFO_KEY
+
+.N WEB
+@*/
+int MPI_Info_get(MPI_Info info, char *key, 
+		 int valuelen, char *value, int *flag)
 {
 	struct _infoent	search;			/* search element */
 	struct _infoent	*found;			/* found key/value pair */
@@ -88,7 +107,7 @@ int			*flag;
 		    strcpy(value, found->ie_value);
 		} else {
 		    strncpy(value, found->ie_value, valuelen);
-		    value[valuelen - 1] = 0;
+		    value[valuelen] = 0;
 		}
 	} else {
 		*flag = 0;
