@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: infoset.c,v 6.4 1999/05/25 22:08:01 kmeyer1 Exp $
+ *	$Id: infoset.c,v 6.7 2001/02/03 20:24:30 jsquyres Exp $
  *
  *	Function:	- set info value associated with key
  *	Accepts:	- info (inout)
@@ -48,13 +47,28 @@
 #include <mpisys.h>
 
 
-int
-MPI_Info_set(info, key, value)
+/*@
+  MPI_Info_set - Set a (key, value) pair in an 'MPI_Info' object
 
-MPI_Info		info;
-char			*key;
-char			*value;
+Input Parameters:
++ key - null-terminated character string of the index key
+- value - null-terminated character string of the value
 
+Input/Output Parameter:
+. info - info object (handle)
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_ARG
+.N MPI_ERR_INFO_KEY
+.N MPI_ERR_INFO_NOKEY
+.N MPI_ERR_INTERN
+
+.N WEB
+@*/
+int MPI_Info_set(MPI_Info info, char *key, char *value)
 {
 	struct _infoent	newinfo;		/* new info pair */
 	struct _infoent	*old;			/* existing pair with key */
@@ -91,6 +105,7 @@ char			*value;
 					lam_mkerr(MPI_ERR_OTHER, 0)));
 	}
 
+	LAM_ZERO_ME(newinfo);
 	strcpy(newinfo.ie_key, key);
 	strcpy(newval, value);
 /*
