@@ -1,33 +1,32 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
+ * 
  *
- *
- *	$Id: init.c,v 6.20 1999/09/13 03:40:19 jsquyres Exp $
+ *	$Id: init.c,v 6.39 2001/03/20 06:16:06 jsquyres Exp $
  *
  *	Function:	- initialize the MPI session
  *			- the kitchen-sink of MPI
@@ -42,7 +41,9 @@
 
 #include <all_list.h>
 #include <app_mgmt.h>
+#include <args.h>
 #include <blktype.h>
+#include <laminternal.h>
 #include <mpi.h>
 #include <MPISYSF.h>
 #include <mpisys.h>
@@ -57,6 +58,7 @@
 #include <impi.h>
 #endif
 
+
 /*
  * MPISYSF.h undefines the corresponding C constants defined in mpi.h.
  */
@@ -65,6 +67,7 @@
 #define MPI_C_WIN_NULL_COPY_FN		((MPI_Win_copy_attr_function *) 0)
 #define MPI_C_WIN_NULL_DELETE_FN	((MPI_Win_delete_attr_function *) 0)
 
+
 /*
  * private variables
  */
@@ -76,46 +79,53 @@ static int		mpi_nprocs;		/* # world processes */
 static int		mpi_nparent;		/* # parent processes */
 static int		mpi_cid;		/* CID of parent intercomm */
 static struct _gps	*mpi_procs;		/* array world & parent GPS */
-static int              fl_debug = 0;
+#if !LAM_WANT_IMPI
+/* When The 6.3 and 6.4 distributions merge (i.e., support for IMPI
+   becomes part of the default distribution), these variables can go
+   away, because they'll be in libimpi.la. */
+static int impi_client_size = 1;
+static int impi_client_color = 0;
+static int impi_host_size = 1;
+static int impi_host_color = 0;
+#endif
+
+
 /*
  * external variables
  */
 #if LAM_SIZEOF_LONG_DOUBLE == 16
-extern long double	mpi_bottom_[];
-extern long double	mpi_argv_null_[];
-extern long double	mpi_argvs_null_[];
-extern long double	mpi_errcodes_ignore[];
-extern long double	mpi_status_ignore[];
-extern long double	mpi_statuses_ignore[];
+extern LAM_LONG_DOUBLE	mpi_bottom_[];
+extern LAM_LONG_DOUBLE	mpi_argv_null_[];
+extern LAM_LONG_DOUBLE	mpi_argvs_null_[];
+extern LAM_LONG_DOUBLE	mpi_errcodes_ignore_[];
+extern LAM_LONG_DOUBLE	mpi_status_ignore_[];
+extern LAM_LONG_DOUBLE	mpi_statuses_ignore_[];
 #else
 extern double		mpi_bottom_[];
 extern double		mpi_argv_null_[];
 extern double		mpi_argvs_null_[];
-extern double		mpi_errcodes_ignore[];
-extern double		mpi_status_ignore[];
-extern double		mpi_statuses_ignore[];
+extern double		mpi_errcodes_ignore_[];
+extern double		mpi_status_ignore_[];
+extern double		mpi_statuses_ignore_[];
 #endif
 
-/*
- * exported functions
- */
-int			lam_init_comm_world(struct _gps *mpi_procs, 
-					    int mpi_nprocs);
 
 /*
  * private functions
  */
-static int		init_comm();
-static int		init_env();
-static int		init_rdtype();
-static int		init_f77();
-static void		init_dtype();
-static void		init_errhdl();
-static void		init_op();
-static void		make_dtype();
-static void		make_op();
-static int		comm_cmp(MPI_Comm *a, MPI_Comm *b);
-static int		check_cid(MPI_Comm *a, MPI_Comm *b);
+static int init_comm(void);
+static int init_env(void);
+static int init_rdtype(void);
+static int init_f77(void);
+static void init_dtype(void);
+static void init_errhdl(void);
+static void init_op(void);
+static void make_dtype(MPI_Datatype dtype, int size, int align, int label, 
+		       char *name);
+static void make_op(MPI_Op op, void (*func)());
+static int comm_cmp(MPI_Comm *a, MPI_Comm *b);
+static int check_cid(MPI_Comm *a, MPI_Comm *b);
+
 
 /*
  * local structures for maxloc/minloc operations
@@ -132,7 +142,7 @@ struct dbl_int {
 
 struct longdbl_int {
 #if LAM_SIZEOF_LONG_DOUBLE
-	long double	ldi_double;
+	LAM_LONG_DOUBLE	ldi_double;
 #else
 	double		ldi_double;
 #endif
@@ -149,15 +159,125 @@ struct short_int {
 	int		li_int;
 };
 
+
 /*
  * Create the whole MPI universe.
  */
-int
-MPI_Init(pargc, pargv)
+/*@
+   MPI_Init - Initialize the MPI execution environment
 
-int			*pargc;
-char			***pargv;
+Input Parameters:
++ pargc - Pointer to the number of arguments 
+- pargv - Pointer to the argument vector
 
+Notes:
+
+MPI specifies no command-line arguments but does allow an MPI
+implementation to make use of them.  LAM/MPI neither uses nor adds any
+values to the 'argc' and 'argv' parameters.  As such, it is legal to
+pass 'NULL' for both 'argc' and 'argv' in LAM/MPI.
+
+Instead, LAM/MPI relies upon the 'mpirun' command to pass
+meta-information between nodes in order to start MPI programs (of
+course, the LAM daemons must have previously been launched with the
+'lamboot' command).  As such, every rank in 'MPI_COMM_WORLD' will
+receive the 'argc' and 'argv' that was specified with the 'mpirun'
+command (either via the 'mpirun' command line or an app schema) as
+soon as 'main' begins.  See the 'mpirun'(1) man page for more
+information.
+
+If 'mpirun' is `not` used to start MPI programs, the resulting process
+will be rank 0 in 'MPI_COMM_WORLD', and 'MPI_COMM_WORLD' will have a
+size of 1.  This is known as a "singleton" MPI.  It should be noted
+that LAM daemons are still used for singleton MPI programs - 'lamboot'
+must still have been successfully executed before running a singleton
+process.
+
+LAM/MPI takes care to ensure that the normal Unix process model of
+execution is preserved: no extra threads or processes are forked from
+the user''s process.  Instead, the LAM daemons are used for all
+process management and meta-environment information.  Consequently,
+LAM/MPI places no restriction on what may be invoked before
+'MPI_Init*' or after 'MPI_Finalize'; this is `not` a safe assumption
+for those attempting to write portable MPI programs - see "Portability
+Concerns", below.
+
+MPI mandates that the same thread must call 'MPI_Init' or
+'MPI_Init_thread' and 'MPI_Finalize'.
+
+Note that the Fortran binding for this routine has only the error
+return argument ('MPI_INIT(ierror)').
+
+Because the Fortran and C versions of 'MPI_Init' are different, there
+is a restriction on who can call 'MPI_Init'.  The version (Fortran or
+C) must match the main program.  That is, if the main program is in C,
+then the C version of 'MPI_Init' must be called.  If the main program
+is in Fortran, the Fortran version must be called.
+
+On exit from this routine, all processes will have a copy of the
+argument list.  This is `not required` by the MPI standard, and truely
+portable codes should not rely on it.  This is provided as a service
+by this implementation (an MPI implementation is allowed to distribute
+the command line arguments but is not required to).
+
+Signals Used:
+
+The LAM implementation of MPI uses, by default, 'SIGUSR2'.  This may
+be changed when LAM is compiled, however, with the '--with-signal'
+command line switch to LAM''s 'configure' script.  Consult your system
+administrator to see if they specified a different signal when LAM was
+installed.
+
+LAM/MPI catches several signals for the purpose of printing error
+messages before invoking the next signal handler.  That is, LAM
+"chains" its signal handler to be executed before the signal handler
+that was already set.  This scheme prevents nodes (remote nodes,
+especially) from silently dying and hanging the remaining MPI ranks
+because of unfinished communications - a very confusing situation when
+debugging parallel programs.
+
+Therefore, it is safe for users to set their own signal handlers.  If
+they wish the LAM signal handlers to be executed as well, users should
+set their handlers before 'MPI_Init*' is invoked.  If users do not
+wish to have LAM catch signals (a bad idea!), they should set their
+handlers `after` 'MPI_Init*' is invoked.
+
+LAM/MPI catches the following signals
+
+'SIGSEGV', 'SIGBUS', 'SIGFPE', 'SIGILL'
+
+All other signals are unused by LAM/MPI, and will be passed to their
+respective signal handlers.
+
+Portability Concerns:
+
+Portable MPI programs `cannot` assume the same process model that LAM
+uses (i.e., essentially the same as POSIX).  MPI does not mandate
+anything before 'MPI_Init' (or 'MPI_Init_thread'), nor anything after
+'MPI_Finalize' executes.  Different MPI implementations make different
+assumptions; some fork auxillary threads and/or processes to "help"
+with the MPI run-time environment (this may interfere with the
+constructors and destructors of global C++ objects, particularly in
+the case where using atexit() or onexit(), for example).  As such, if
+you are writing a portable MPI program, you cannot make the same
+assumptions that LAM/MPI does.
+
+In general, it is safest to call 'MPI_Init' (or 'MPI_Init_thread') as
+soon as possible after 'main' begins, and call 'MPI_Finalize'
+immediately before the program is supposed to end.  Consult the
+documentation for each MPI implementation for their intialize and
+finalize behavior.
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_INIT
+.N MPI_ERR_OTHER
+
+.seealso MPI_Init_thread, MPI_Finalize, lamboot, mpirun, lamhalt
+
+.N ACK
+@*/
+int MPI_Init(int *pargc, char ***pargv)
 {
 	int		fl_init;		/* already init'ed? */
 	int		err;			/* return error code */
@@ -173,7 +293,6 @@ char			***pargv;
 		return(lam_errfunc(MPI_COMM_WORLD, BLKMPIINIT,
 				lam_mkerr(MPI_ERR_OTHER, EMPIINIT)));
 	}
-	DBUG("In the mpi_init\n");
 /*
  * Initialize LAM.
  */
@@ -181,8 +300,9 @@ char			***pargv;
 
 	if (lam_linit(name, &mpi_nprocs, &mpi_nparent, &mpi_cid,
 			&mpi_procs, &root)) {
-		terror("MPI_Init: LAM error");
-		exit(errno);
+	  if (errno != ENOKERNEL && errno != ENOKDESCRIPTORS)
+	    show_help("MPI", "bad-mpi-init", NULL);
+	  exit(errno);
 	}
 /*
  * Initialize MPI pre-defined "stuff".
@@ -244,37 +364,39 @@ char			***pargv;
  */
 #if LAM_WANT_IMPI
 	if (LAM_IS_IMPI(MPI_COMM_WORLD)) {
-	  DBUG("Calling MPI_Barrier on MPI_COMM_WORLD shadow\n");
 	  err = MPI_Barrier(MPI_COMM_WORLD->c_shadow);
 	} else {
-	  DBUG("Calling MPI_Barrier on MPI_COMM_WORLD\n");
 	  err = MPI_Barrier(MPI_COMM_WORLD);
 	}
-	DBUG("MPI_Init past barrier\n");
 #else	
 	err = MPI_Barrier(MPI_COMM_WORLD);
 #endif
-	if (err != MPI_SUCCESS) return(LAMERROR);
+	if (err != MPI_SUCCESS) 
+	  return(LAMERROR);
 
 	if ((mpi_nparent > 0) && (MPI_COMM_WORLD->c_group->g_myrank == 0)) {
 	        MPI_Status status;
 
 		err = MPI_Send((void *) 0, 0, MPI_BYTE,
 					root, 0, lam_comm_parent);
-		if (err != MPI_SUCCESS) return(LAMERROR);
+		if (err != MPI_SUCCESS) 
+		  return(LAMERROR);
 		err = MPI_Recv((void *) 0, 0, MPI_BYTE,
 					root, 0, lam_comm_parent, &status);
-		if (err != MPI_SUCCESS) return(LAMERROR);
+		if (err != MPI_SUCCESS) 
+		  return(LAMERROR);
 	}
 /*
  * Record an initialization trace.
  * If we are tracing and trace generation is initially to be on, turn it on.
  */
-	if (lam_tr_init(name, lam_clockskew)) return(LAMERROR);
+	if (lam_tr_init(name, lam_clockskew)) 
+	  return(LAMERROR);
 
 	if ((_kio.ki_rtf & RTF_TRON) == RTF_TRON) {
 		_kio.ki_rtf &= ~RTF_TRSWITCH;
-		if (lam_tr_on() < 0) return(LAMERROR);
+		if (lam_tr_on() < 0) 
+		  return(LAMERROR);
 	}
 	lam_resetfunc(BLKMPIINIT);
 	return(MPI_SUCCESS);
@@ -286,8 +408,7 @@ char			***pargv;
  *	Function:	- initialize pre-defined error handles
  */
 static void
-init_errhdl()
-
+init_errhdl(void)
 {
 	MPI_ERRORS_ARE_FATAL->eh_func = 0;
 	MPI_ERRORS_ARE_FATAL->eh_f77handle = -1;
@@ -307,8 +428,7 @@ init_errhdl()
  *	Returns:	- 0 or LAMERROR
  */
 static int
-init_comm()
-
+init_comm(void)
 {
 	MPI_Group	group;			/* a process group */
 	MPI_Comm	comm;			/* a communicator */
@@ -327,12 +447,13 @@ init_comm()
  * Initialize the list of communicators.
  */
 	lam_comms = al_init(sizeof(MPI_Comm), comm_cmp);
-	if (lam_comms == 0) return(LAMERROR);
+	if (lam_comms == 0) 
+	  return(LAMERROR);
 /*
  * Create the "world" communicator.
  */
 	if (lam_init_comm_world(mpi_procs, mpi_nprocs) != 0)
-	  return (LAMERROR);
+	  return(LAMERROR);
 /*
  * Set the pid under which run time traces are stored and write the
  * trace for MPI_COMM_WORLD.
@@ -345,7 +466,8 @@ init_comm()
 
 	group = (MPI_Group) malloc((unsigned) sizeof(struct _group) +
 						sizeof(struct _proc *));
-	if (group == 0) return(LAMERROR);
+	if (group == 0) 
+	  return(LAMERROR);
 
 	group->g_nprocs = 1;
 	group->g_myrank = 0;
@@ -370,8 +492,11 @@ init_comm()
 	lam_setcid(cid);
 	comm->c_errhdl->eh_refcount++;
 	strcpy(comm->c_name, "MPI_COMM_SELF");
+	if (LAM_TRACE_TOP())
+	  lam_tr_commname(comm->c_name, comm->c_contextid, MPI_Wtime());
 
-	if (!al_insert(lam_comms, &comm)) return(LAMERROR);
+	if (!al_insert(lam_comms, &comm)) 
+	  return(LAMERROR);
 /*
  * Create the parent intercommunicator if spawned.
  */
@@ -379,7 +504,8 @@ init_comm()
 
 		group = (MPI_Group) malloc((unsigned) sizeof(struct _group) +
 					(mpi_nparent * sizeof(struct _proc *)));
-		if (group == 0) return(LAMERROR);
+		if (group == 0) 
+		  return(LAMERROR);
 
 		group->g_nprocs = mpi_nparent;
 		group->g_myrank = MPI_UNDEFINED;
@@ -395,7 +521,8 @@ init_comm()
 
 		for (i = 0; i < mpi_nparent; ++i, ++g, ++p) {
 			*p = lam_procfind(g);
-			if (*p == 0) return(LAMERROR);
+			if (*p == 0) 
+			  return(LAMERROR);
 			(*p)->p_refcount++;
 		}
 
@@ -413,82 +540,24 @@ init_comm()
 		MPI_COMM_WORLD->c_group->g_refcount++;
 		lam_comm_parent->c_errhdl->eh_refcount++;
 		strcpy(lam_comm_parent->c_name, "MPI_COMM_PARENT");
+		if (LAM_TRACE_TOP())
+		  lam_tr_commname(lam_comm_parent->c_name, 
+				  lam_comm_parent->c_contextid, MPI_Wtime());
 
-		if (!al_insert(lam_comms, &lam_comm_parent)) return(LAMERROR);
+		if (!al_insert(lam_comms, &lam_comm_parent)) 
+		  return(LAMERROR);
 	}
 
-	DBUG("Done with init_comm\n");
 	return(0);
 }
 
-/*
- *	init_comm_world
- *
- *	Function:	- initialize MPI_COMM_WORLD
- */
-int
-lam_init_comm_world(struct _gps *mpi_procs, int mpi_nprocs)
-{
-	MPI_Group	group;			/* a process group */
-	MPI_Comm	comm;			/* a communicator */
-	int		i;
-	struct _gps	*g;
-	struct _proc	**p;
-	int             cid;
-
-	comm = MPI_COMM_WORLD;
-
-	group = (MPI_Group) malloc((unsigned) sizeof(struct _group) +
-					(mpi_nprocs * sizeof(struct _proc *)));
-	if (group == 0) return(LAMERROR);
-
-	group->g_nprocs = mpi_nprocs;
-	DBUG("IN mpi_init, the number of lam procs is %d\n", mpi_nprocs);
-	group->g_myrank = MPI_UNDEFINED;
-	group->g_refcount = 1;
-	group->g_f77handle = -1;
-	group->g_procs = (struct _proc **)
-				((char *) group + sizeof(struct _group));
-/*
- * Fill the group processes and determine my rank.
- */
-	g = mpi_procs;
-	p = group->g_procs;
-
-	for (i = 0; i < mpi_nprocs; ++i, ++g, ++p) {
-
-		if ((*p = lam_procfind(g)) == 0) {
-			return(LAMERROR);
-		}
-		if (*p == lam_myproc) {
-			group->g_myrank = i;
-		}
-		(*p)->p_refcount++;
-	}
-
-	DBUG("Calling lam_comm_new for MPI_COMM_WORLD\n");
-	cid = lam_getcid();
-	if (lam_comm_new(cid, group, MPI_GROUP_NULL, LAM_PREDEF, &comm))
-		return(LAMERROR);
-
-	lam_setcid(cid);
-	comm->c_errhdl->eh_refcount++;
-	strcpy(comm->c_name, "MPI_COMM_WORLD");
-
-	if (!al_insert(lam_comms, &comm)) return(LAMERROR);
-
-	DBUG("Finished with lam_init_comm_world\n");
-	return 0;
-}
-
 /*
  *	init_dtype
  *
  *	Function:	- initialize basic (intrinsic) datatypes
  */
 static void
-init_dtype()
-
+init_dtype(void)
 {
 /*
  * common datatypes
@@ -515,7 +584,7 @@ init_dtype()
 	make_dtype(MPI_DOUBLE, sizeof(double),
 		   LAM_ALIGNMENT_DOUBLE, TRDTDOUBLE, "MPI_DOUBLE");
 #if LAM_SIZEOF_LONG_DOUBLE
-	make_dtype(MPI_LONG_DOUBLE, sizeof(long double),
+	make_dtype(MPI_LONG_DOUBLE, sizeof(LAM_LONG_DOUBLE),
 		   LAM_ALIGNMENT_LONG_DOUBLE, TRDTLONGDOUBLE, 
 		   "MPI_LONG_DOUBLE");
 #else
@@ -570,8 +639,7 @@ init_dtype()
  *	Returns:	- 0 or LAMERROR
  */
 static int
-init_rdtype()
-
+init_rdtype(void)
 {
 	MPI_Datatype	newdtype;		/* new datatype */
 	MPI_Datatype	types[2];		/* struct datatypes */
@@ -589,7 +657,8 @@ init_rdtype()
  * Create MPI_2INT.
  */
 	err = MPI_Type_contiguous(2, MPI_INT, &newdtype);
-	if (err != MPI_SUCCESS) return(LAMERROR);
+	if (err != MPI_SUCCESS) 
+	  return(LAMERROR);
 
 	memcpy((char *) MPI_2INT, (char *) newdtype, sizeof(struct _dtype));
 	free((char *) newdtype);
@@ -609,7 +678,8 @@ init_rdtype()
 	disps[1] -= disps[0]; disps[0] = 0;
 
 	err = MPI_Type_struct(2, lengths, disps, types, &newdtype);
-	if (err != MPI_SUCCESS) return(LAMERROR);
+	if (err != MPI_SUCCESS) 
+	  return(LAMERROR);
 
 	memcpy((char *) MPI_FLOAT_INT, (char *) newdtype, sizeof(struct _dtype));
 	free((char *) newdtype);
@@ -629,7 +699,8 @@ init_rdtype()
 	disps[1] -= disps[0]; disps[0] = 0;
 
 	err = MPI_Type_struct(2, lengths, disps, types, &newdtype);
-	if (err != MPI_SUCCESS) return(LAMERROR);
+	if (err != MPI_SUCCESS) 
+	  return(LAMERROR);
 
 	memcpy((char *) MPI_DOUBLE_INT, (char *) newdtype, sizeof(struct _dtype));
 	free((char *) newdtype);
@@ -649,7 +720,8 @@ init_rdtype()
 	disps[1] -= disps[0]; disps[0] = 0;
 
 	err = MPI_Type_struct(2, lengths, disps, types, &newdtype);
-	if (err != MPI_SUCCESS) return(LAMERROR);
+	if (err != MPI_SUCCESS) 
+	  return(LAMERROR);
 
 	memcpy((char *) MPI_LONG_DOUBLE_INT,
 		(char *) newdtype, sizeof(struct _dtype));
@@ -670,7 +742,8 @@ init_rdtype()
 	disps[1] -= disps[0]; disps[0] = 0;
 
 	err = MPI_Type_struct(2, lengths, disps, types, &newdtype);
-	if (err != MPI_SUCCESS) return(LAMERROR);
+	if (err != MPI_SUCCESS) 
+	  return(LAMERROR);
 
 	memcpy((char *) MPI_LONG_INT, (char *) newdtype, sizeof(struct _dtype));
 	free((char *) newdtype);
@@ -690,7 +763,8 @@ init_rdtype()
 	disps[1] -= disps[0]; disps[0] = 0;
 
 	err = MPI_Type_struct(2, lengths, disps, types, &newdtype);
-	if (err != MPI_SUCCESS) return(LAMERROR);
+	if (err != MPI_SUCCESS) 
+	  return(LAMERROR);
 
 	memcpy((char *) MPI_SHORT_INT, (char *) newdtype, sizeof(struct _dtype));
 	free((char *) newdtype);
@@ -702,7 +776,8 @@ init_rdtype()
  * Create MPI_2INTEGER.
  */
 	err = MPI_Type_contiguous(2, MPI_F_INTEGER, &newdtype);
-	if (err != MPI_SUCCESS) return(LAMERROR);
+	if (err != MPI_SUCCESS) 
+	  return(LAMERROR);
 
 	memcpy((char *) MPI_F_2INTEGER, (char *) newdtype, sizeof(struct _dtype));
 	free((char *) newdtype);
@@ -714,7 +789,8 @@ init_rdtype()
  * Create MPI_2REAL.
  */
 	err = MPI_Type_contiguous(2, MPI_F_REAL, &newdtype);
-	if (err != MPI_SUCCESS) return(LAMERROR);
+	if (err != MPI_SUCCESS) 
+	  return(LAMERROR);
 
 	memcpy((char *) MPI_F_2REAL, (char *) newdtype, sizeof(struct _dtype));
 	free((char *) newdtype);
@@ -726,7 +802,8 @@ init_rdtype()
  * Create MPI_2DOUBLE_PRECISION.
  */
 	err = MPI_Type_contiguous(2, MPI_F_DOUBLE_PRECISION, &newdtype);
-	if (err != MPI_SUCCESS) return(LAMERROR);
+	if (err != MPI_SUCCESS) 
+	  return(LAMERROR);
 
 	memcpy((char *) MPI_F_2DOUBLE_PRECISION,
 			(char *) newdtype, sizeof(struct _dtype));
@@ -745,8 +822,7 @@ init_rdtype()
  *	Function:	- initialize intrinsic reduction operations
  */
 static void
-init_op()
-
+init_op(void)
 {
 	make_op(MPI_MAX, lam_max);
 	make_op(MPI_MIN, lam_min);
@@ -770,44 +846,46 @@ init_op()
  *	Returns:	- 0 or LAMERROR
  */
 static int
-init_env()
-
+init_env(void)
 {
 	MPI_Group	world;			/* world group */
 	struct _attrkey *keystate;		/* key state */
 	struct _proc	**p;			/* process */
 	int		key;			/* attribute key */
 	int		err;			/* error code */
+	struct route	r;			/* router table entry */
 	int		i;
+	int		nnodes;			/* total number of nodes */
+	int		*nodes;			/* node ID array */
 /*
  * Create the predefined keys for MPI_COMM_WORLD.
  */
 	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
-				&key, (void *) 0);
+				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_TAG_UB)) return(LAMERROR);
 
 	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
-				&key, (void *) 0);
+				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_HOST)) return(LAMERROR);
 
 	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
-				&key, (void *) 0);
+				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_IO)) return(LAMERROR);
 
 	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
-				&key, (void *) 0);
+				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_WTIME_IS_GLOBAL)) {
 		return(LAMERROR);
 	}
 
 	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
-				&key, (void *) 0);
+				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_UNIVERSE_SIZE)) {
 		return(LAMERROR);
 	}
 
 	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
-				&key, (void *) 0);
+				     &key, (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_APPNUM)) {
 		return(LAMERROR);
 	}
@@ -815,18 +893,40 @@ init_env()
  * Create the predefined keys for windows.
  */
 	err = MPI_Win_create_keyval(MPI_C_WIN_NULL_COPY_FN,
-				MPI_C_WIN_NULL_DELETE_FN, &key, (void *) 0);
+				    MPI_C_WIN_NULL_DELETE_FN, &key, 
+				    (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_WIN_BASE)) return(LAMERROR);
 
 	err = MPI_Win_create_keyval(MPI_C_WIN_NULL_COPY_FN,
-				MPI_C_WIN_NULL_DELETE_FN, &key, (void *) 0);
+				    MPI_C_WIN_NULL_DELETE_FN, &key, 
+				    (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_WIN_SIZE)) return(LAMERROR);
 
 	err = MPI_Win_create_keyval(MPI_C_WIN_NULL_COPY_FN,
-				MPI_C_WIN_NULL_DELETE_FN, &key, (void *) 0);
+				    MPI_C_WIN_NULL_DELETE_FN, &key, 
+				    (void *) LAM_INT_TO_VOID_P 0);
 	if ((err != MPI_SUCCESS) || (key != MPI_WIN_DISP_UNIT)) {
 		return(LAMERROR);
 	}
+/* 
+ * Make the predefined keys for IMPI attributes
+ */
+	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+				     &key, (void *) 0);
+	if ((err != MPI_SUCCESS) || (key != IMPI_CLIENT_SIZE)) 
+	  return LAMERROR;
+	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+				     &key, (void *) 0);
+	if ((err != MPI_SUCCESS) || (key != IMPI_CLIENT_COLOR)) 
+	  return LAMERROR;
+	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+				     &key, (void *) 0);
+	if ((err != MPI_SUCCESS) || (key != IMPI_HOST_SIZE)) 
+	  return LAMERROR;
+	err = MPI_Comm_create_keyval(MPI_C_NULL_COPY_FN, MPI_C_NULL_DELETE_FN,
+				     &key, (void *) 0);
+	if ((err != MPI_SUCCESS) || (key != IMPI_HOST_COLOR)) 
+	  return LAMERROR;
 /*
  * Initialize the attribute values.
  */
@@ -875,69 +975,124 @@ init_env()
 	host = (i >= world->g_nprocs) ? MPI_PROC_NULL : i;
 /*
  * The universe size is inherited from the parents or is the number of
- * nodes in the LAM.
+ * CPUs in the LAM.
  */
 	if (lam_universe_size < 0) {
-		if ((lam_universe_size = getnall()) < 0) {
-			return(LAMERROR);
-		}
+	  nnodes = getnall();
+	  nodes = malloc(sizeof(int) * nnodes);
+	  if (nodes == NULL)
+	    return (LAMERROR);
+
+	  getnodes(nodes, nnodes, 0, NT_CAST);
+	  for (lam_universe_size = i = 0; i < nnodes; i++) {
+	    r.r_nodeid = nodes[i];
+	    getrent(&r);
+	    lam_universe_size += r.r_ncpus;
+	  }
+	  free(nodes);
 	}
 /*
  * Store the attribute values.
  */
-	err = MPI_Comm_set_attr(MPI_COMM_WORLD, MPI_TAG_UB, (void *) maxtag);
+	err = MPI_Comm_set_attr(MPI_COMM_WORLD, MPI_TAG_UB, 
+				(void *) LAM_INT_TO_VOID_P maxtag);
 	if (err != MPI_SUCCESS) return(LAMERROR);
 
-	err = MPI_Comm_set_attr(MPI_COMM_WORLD, MPI_HOST, (void *) host);
+	err = MPI_Comm_set_attr(MPI_COMM_WORLD, MPI_HOST, 
+				(void *) LAM_INT_TO_VOID_P host);
 	if (err != MPI_SUCCESS) return(LAMERROR);
 
-	err = MPI_Comm_set_attr(MPI_COMM_WORLD, MPI_IO, (void *) io);
+	err = MPI_Comm_set_attr(MPI_COMM_WORLD, MPI_IO, 
+				(void *) LAM_INT_TO_VOID_P io);
 	if (err != MPI_SUCCESS) return(LAMERROR);
 
 	err = MPI_Comm_set_attr(MPI_COMM_WORLD,
-				MPI_WTIME_IS_GLOBAL, (void *) wtimeglob);
+				MPI_WTIME_IS_GLOBAL, 
+				(void *) LAM_INT_TO_VOID_P wtimeglob);
 	if (err != MPI_SUCCESS) return(LAMERROR);
 
 	err = MPI_Comm_set_attr(MPI_COMM_WORLD,
-				MPI_UNIVERSE_SIZE, (void *) lam_universe_size);
+				MPI_UNIVERSE_SIZE, 
+				(void *) LAM_INT_TO_VOID_P lam_universe_size);
 	if (err != MPI_SUCCESS) return(LAMERROR);
 
 	if (lam_appnum >= 0) {
 		err = MPI_Comm_set_attr(MPI_COMM_WORLD,
-					MPI_APPNUM, (void *) lam_appnum);
+					MPI_APPNUM, 
+					(void *) LAM_INT_TO_VOID_P lam_appnum);
 		if (err != MPI_SUCCESS) return(LAMERROR);
 	}
 /*
  * Mark them as predefined and mark the style, integer valued is F77 style.
  */
-	if ((keystate = lam_getattr(MPI_TAG_UB)) == 0) return(LAMERROR);
+	if ((keystate = lam_getattr(MPI_TAG_UB)) == 0) 
+	  return(LAMERROR);
 	keystate->ak_flags |= LAM_PREDEF | LAM_LANGF77;
 
-	if ((keystate = lam_getattr(MPI_HOST)) == 0) return(LAMERROR);
+	if ((keystate = lam_getattr(MPI_HOST)) == 0) 
+	  return(LAMERROR);
 	keystate->ak_flags |= LAM_PREDEF | LAM_LANGF77;
 
-	if ((keystate = lam_getattr(MPI_IO)) == 0) return(LAMERROR);
+	if ((keystate = lam_getattr(MPI_IO)) == 0) 
+	  return(LAMERROR);
 	keystate->ak_flags |= LAM_PREDEF | LAM_LANGF77;
 
-	if ((keystate = lam_getattr(MPI_WTIME_IS_GLOBAL)) == 0) {
-		return(LAMERROR);
-	}
+	if ((keystate = lam_getattr(MPI_WTIME_IS_GLOBAL)) == 0)
+	  return(LAMERROR);
 	keystate->ak_flags |= LAM_PREDEF | LAM_LANGF77;
 
-	if ((keystate = lam_getattr(MPI_UNIVERSE_SIZE)) == 0) return(LAMERROR);
+	if ((keystate = lam_getattr(MPI_UNIVERSE_SIZE)) == 0) 
+	  return(LAMERROR);
 	keystate->ak_flags |= LAM_PREDEF | LAM_LANGF77;
 
-	if ((keystate = lam_getattr(MPI_APPNUM)) == 0) return(LAMERROR);
+	if ((keystate = lam_getattr(MPI_APPNUM)) == 0) 
+	  return(LAMERROR);
 	keystate->ak_flags |= LAM_PREDEF | LAM_LANGF77;
 
-	if ((keystate = lam_getattr(MPI_WIN_BASE)) == 0) return(LAMERROR);
+	if ((keystate = lam_getattr(MPI_WIN_BASE)) == 0) 
+	  return(LAMERROR);
 	keystate->ak_flags |= LAM_PREDEF;
 
-	if ((keystate = lam_getattr(MPI_WIN_SIZE)) == 0) return(LAMERROR);
+	if ((keystate = lam_getattr(MPI_WIN_SIZE)) == 0) 
+	  return(LAMERROR);
 	keystate->ak_flags |= LAM_PREDEF | LAM_LANGF77;
 
-	if ((keystate = lam_getattr(MPI_WIN_DISP_UNIT)) == 0) return(LAMERROR);
+	if ((keystate = lam_getattr(MPI_WIN_DISP_UNIT)) == 0) 
+	  return(LAMERROR);
 	keystate->ak_flags |= LAM_PREDEF | LAM_LANGF77;
+/*
+ * Go do the same for the IMPI attributes
+
+ * JMS: Note -- we currently have the function call #if'ed because of
+ * the two different tarballs that are currently being distirubuted --
+ * with and without IMPI support.  Hence, when they merge back into a
+ * single distribution (and libimpi.la is always built), we can make
+ * this always be a function call (as it should be -- it's IMPI setup,
+ * after all, regardless of whether this is an IMPI job, these
+ * attributes need to be set, and the code should therefore be in
+ * libimpi.la).
+
+ */
+#if LAM_WANT_IMPI
+	IMPI_Fill_attributes();
+#else
+	err = MPI_Comm_set_attr(MPI_COMM_WORLD, IMPI_CLIENT_SIZE, 
+				(void *) LAM_INT_TO_VOID_P &impi_client_size);
+	if (err != MPI_SUCCESS)
+	  return LAMERROR;
+	err = MPI_Comm_set_attr(MPI_COMM_WORLD, IMPI_CLIENT_COLOR, 
+				(void *) LAM_INT_TO_VOID_P &impi_client_color);
+	if (err != MPI_SUCCESS)
+	  return LAMERROR;
+	err = MPI_Comm_set_attr(MPI_COMM_WORLD, IMPI_HOST_SIZE, 
+				(void *) LAM_INT_TO_VOID_P &impi_host_size);
+	if (err != MPI_SUCCESS)
+	  return LAMERROR;
+	err = MPI_Comm_set_attr(MPI_COMM_WORLD, IMPI_HOST_COLOR, 
+				(void *) LAM_INT_TO_VOID_P &impi_host_color);
+	if (err != MPI_SUCCESS)
+	  return LAMERROR;
+#endif
 
 	return(0);
 }
@@ -953,14 +1108,7 @@ init_env()
  *			- datatype name
  */
 static void
-make_dtype(dtype, size, align, label, name)
-
-MPI_Datatype		dtype;
-int			size;
-int			align;
-int			label;
-char			*name;
-
+make_dtype(MPI_Datatype dtype, int size, int align, int label, char *name)
 {
 	lam_type_setdefaults(dtype);
 
@@ -997,11 +1145,7 @@ char			*name;
  *			- reduction function
  */
 static void
-make_op(op, func)
-
-MPI_Op			op;
-void			(*func)();
-
+make_op(MPI_Op op, void (*func)())
 {
 	op->op_func = func;
 	op->op_commute = 1;
@@ -1017,10 +1161,7 @@ void			(*func)();
  *	Returns:	- 0 if same communicator, else 1
  */
 static int
-comm_cmp(c1, c2)
-
-MPI_Comm		*c1, *c2;
-
+comm_cmp(MPI_Comm *c1, MPI_Comm *c2)
 {
 #if LAM_WANT_IMPI
   if ((*c1)->c_flags & LAM_CFAKE) {
@@ -1050,10 +1191,7 @@ MPI_Comm		*c1, *c2;
  *	Returns:	- 0 if same communicator, else 1
  */
 static int
-check_cid(c1, c2)
-
-MPI_Comm		*c1, *c2;
-
+check_cid(MPI_Comm *c1, MPI_Comm *c2)
 {
 	return( !( ((*c1)->c_contextid == (*c2)->c_contextid)
 			|| ((*c1)->c_contextid == -((*c2)->c_contextid + 1))));
@@ -1067,7 +1205,6 @@ MPI_Comm		*c1, *c2;
  */
 static int
 init_f77(void)
-
 {
 /*
  * Initialize the type lookup table.
@@ -1204,9 +1341,9 @@ init_f77(void)
 	lam_F_bottom = (char *) &mpi_bottom_[0];
 	lam_F_argvnull = &mpi_argv_null_[0];
 	lam_F_argvsnull = &mpi_argvs_null_[0];
-	lam_F_errorcodes_ignore = &mpi_errcodes_ignore[0];
-	lam_F_status_ignore = &mpi_status_ignore[0];
-	lam_F_statuses_ignore = &mpi_statuses_ignore[0];
+	lam_F_errorcodes_ignore = &mpi_errcodes_ignore_[0];
+	lam_F_status_ignore = &mpi_status_ignore_[0];
+	lam_F_statuses_ignore = &mpi_statuses_ignore_[0];
 
 	MPI_F_STATUS_IGNORE = (MPI_Fint *) lam_F_status_ignore;
 	MPI_F_STATUSES_IGNORE = (MPI_Fint *) lam_F_statuses_ignore;
