@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: irecv.c,v 6.17 1999/11/12 05:19:29 jsquyres Exp $
+ *	$Id: irecv.c,v 6.19 2000/10/25 23:29:19 jsquyres Exp $
  *
  *	Function:	- immediate receive
  *	Accepts:	- buffer
@@ -54,17 +53,45 @@
 #include <debug.h>
 
 
-int
-MPI_Irecv(buf, count, dtype, src, tag, comm, req)
+/*@
+    MPI_Irecv - Begins a non-blocking receive
 
-void			*buf;
-int			count;
-MPI_Datatype		dtype;
-int			src;
-int			tag;
-MPI_Comm		comm;
-MPI_Request		*req;
+Input Parameters:
++ buf - initial address of receive buffer (choice) 
+. count - number of elements in receive buffer (integer) 
+. dtype - datatype of each receive buffer element (handle) 
+. src - rank of source (integer) 
+. tag - message tag (integer) 
+- comm - communicator (handle) 
 
+Output Parameter:
+. req - communication request (handle) 
+
+Notes:
+
+The communication started with this function is not guaranteed to
+progress or complete until 'req' has been given to one of the test or
+wait functions ('MPI_Test', 'MPI_Testall', 'MPI_Testany',
+'MPI_Testsome', 'MPI_Wait', 'MPI_Waitall', 'MPI_Waitany',
+'MPI_Waitsome').
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_TYPE
+.N MPI_ERR_COUNT
+.N MPI_ERR_TAG
+.N MPI_ERR_RANK
+
+.seealso MPI_Recv, MPI_Test, MPI_Testall, MPI_Testany, MPI_Testsome, MPI_Wait, MPI_Waitall, MPI_Waitany, MPI_Waitsome
+
+.N ACK
+@*/
+int MPI_Irecv(void *buf, int count, MPI_Datatype dtype, 
+	      int src, int tag, MPI_Comm comm, 
+	      MPI_Request *req)
 {
 	int		err;			/* error code */
 	int		fl_trace;		/* do tracing? */
@@ -94,7 +121,7 @@ MPI_Request		*req;
 	_mpi_req_blkclr();
 
 #if LAM_WANT_IMPI
-	IMPI_Register_ping(src, tag, comm, &((*req)->rq_shadow));
+	IMPI_Register_datasync(src, tag, comm, &((*req)->rq_shadow));
 #endif
 
 	err = _mpi_req_advance();
