@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: keycreate.c,v 6.5 1999/05/25 22:08:03 kmeyer1 Exp $
+ *	$Id: keycreate.c,v 6.6 1999/12/31 21:27:32 jsquyres Exp $
  *
  *	Function:	- create an attribute key
  *	Accepts:	- copy function
@@ -46,14 +45,25 @@
 #include <terror.h>
 
 
-int
-MPI_Keyval_create(cpyfunc, delfunc, key, extra)
+/*@
 
-int			(*cpyfunc)();
-int			(*delfunc)();
-int			*key;
-void			*extra;
+MPI_Keyval_create - Generates a new communicator attribute key
 
+Input Parameters:
+. cpyfunc - Copy callback function for 'keyval' 
+. delfunc - Delete callback function for 'keyval' 
+. extra - Extra state for callback functions 
+
+Output Parameter:
+. key - key value for future access (integer) 
+
+.N Wrapper MPI_Comm_create_keyval
+
+.N ACK
+@*/
+int MPI_Keyval_create(MPI_Copy_function *cpyfunc, 
+		      MPI_Delete_function *delfunc, 
+		      int *key, void *extra)
 {
 	int		err;
 
