@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN/RBD
  *
- *	$Id: lamcomm.c,v 6.6 1999/08/01 05:16:05 jsquyres Exp $
+ *	$Id: lamcomm.c,v 6.9 2000/10/31 03:58:58 jsquyres Exp $
  *
  *	Function:	- miscellaneous communicator functions
  */
@@ -48,25 +47,22 @@
 #include <impi.h>
 #endif
 
-/*
- * public functions
- */
-int			lam_comm_free();
-int			lam_comm_new();
 
 /*
  * private functions
  */
-#if WANT_IMPI
-static int              num_remotes(MPI_Group group);
-static MPI_Group        make_local(MPI_Group orig);
+#if LAM_WANT_IMPI
+static int num_remotes(MPI_Group group);
+static MPI_Group make_local(MPI_Group orig);
 #endif
 
+
 /*
  * private variables
  */
 static int fl_debug = 0;
 
+
 /*
  *	lam_comm_free
  *
@@ -75,14 +71,15 @@ static int fl_debug = 0;
  *	Returns:	- 0 or LAMERROR
  */
 int
-lam_comm_free(comm)
-
-MPI_Comm		comm;
-
+lam_comm_free(MPI_Comm comm)
 {
 	int		err;
 	int		key;
 	struct _attr	*p;
+/* 
+ * Drop a trace saying that this name is no longer being used 
+ */
+	MPI_Comm_set_name(comm, "");
 /*
  * Free the groups.
  */
@@ -127,6 +124,12 @@ MPI_Comm		comm;
  * Free the context ID.
  */
 	lam_rmcid(comm->c_contextid);
+/*
+ * Remove the fortran handle if the user called MPI_Comm_f2c on this
+ * handle
+ */
+	if (comm->c_f77handle >= 0)
+	  lam_F_free_hdl(comm->c_f77handle);
 /*
  * Remove the communicator from the communicator list and free it.
  */
@@ -150,14 +153,8 @@ MPI_Comm		comm;
  *	Returns:	- 0 or LAMERROR
  */
 int
-lam_comm_new(cid, l_group, r_group, flags, comm)
-
-int			cid;
-MPI_Group		l_group;
-MPI_Group		r_group;
-int			flags;
-MPI_Comm		*comm;
-
+lam_comm_new(int cid, MPI_Group l_group, MPI_Group r_group, int flags,
+	     MPI_Comm *comm)
 {
 	if (*comm == 0) {
 		if ((*comm = (MPI_Comm) malloc(sizeof(struct _comm))) == 0) {
@@ -186,7 +183,7 @@ MPI_Comm		*comm;
 	memset((*comm)->c_name, 0, sizeof((*comm)->c_name));
 
 	(*comm)->c_shadow = 0;
-#if WANT_IMPI
+#if LAM_WANT_IMPI
         /* If at least one member of the local or remote group is not
 	   within this LAM, we need to build a duplicate communicator
 	   in c_shadow, but only with members that are local to this
@@ -219,7 +216,7 @@ MPI_Comm		*comm;
 }
 
 
-#if WANT_IMPI
+#if LAM_WANT_IMPI
 /*
  *	num_remotes
  *
