@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: laminit.c,v 6.17 1999/09/12 05:07:24 jsquyres Exp $
+ *	$Id: laminit.c,v 6.24 2000/10/16 01:17:44 jsquyres Exp $
  *
  *	Function:	- LAM specific initialization for MPI
  */
@@ -51,6 +50,8 @@
 #include <terror.h>
 #include <typical.h>
 #include <t_types.h>
+#include <args.h>
+#include <trreq.h>
 #if LAM_WANT_IMPI
 #include <impi.h>
 #endif
@@ -117,30 +118,16 @@ MPI_Fint		*MPI_F_STATUSES_IGNORE;
 struct _gps             gimpid;
 #endif
 
-/*
- * external functions
- */
-extern int		lam_rtrstore(int4 nodeid, int4 lnum, int4 pid, 
-				     CONST char *buffer, int4 length);
-extern int		lpattach(CONST char *name);
-extern void		_lam_atexit();
-
 /*
  * private variables
  */
 static int fl_debug = 0;
 
 
-/*
- * public functions
- */
-int                     lam_get_proc_array(struct _gps **procs, int *world_n, 
-					   int *cid, int *procs_n,
-					   int is_impi);
 /*
  * private functions
  */
-static int		get_singleton_idx();
+static int get_singleton_idx(int pid);
 
 
 /*
@@ -156,15 +143,8 @@ static int		get_singleton_idx();
  *	Returns:	- 0 or LAMERROR
  */
 int
-lam_linit(name, world_n, parent_n, cid, worlds, root)
-
-char			*name;
-int			*world_n;
-int			*parent_n;
-int			*cid;
-struct _gps		**worlds;
-int			*root;
-
+lam_linit(char *name, int *world_n, int *parent_n, int *cid, 
+	  struct _gps **worlds, int *root)
 {
     	struct pstate	pstate;			/* for getting kenya index */
 	char		*trworld;		/* world trace */
@@ -181,10 +161,33 @@ int			*root;
  */
 	DBUG("In laminit\n");
 
-	if (kenter(name, 0)) return(LAMERROR);
-	if (_kio.ki_rtf & RTF_FORKED) {
-		_kio.ki_rtf &= ~RTF_TRON;
+	if (kenter(name, 0)) {
+	  /* ENOKERNEL = no kernel */
+	  /* ENOKDESCRIPTORS = kernel descriptors full */
+	  if (errno == ENOKERNEL)
+	    show_help("MPI", "no-lamd", "MPI_Init", NULL);
+	  else if (errno == ENOKDESCRIPTORS) {
+	    char hostname[128];
+	    char num[128];
+	    gethostname(hostname, 128);
+	    snprintf(num, 127, "%d", KPMAX);
+	    show_help("MPI", "lamd-full", "MPI_Init", num, hostname, NULL);
+	  }
+
+	  errno = ENOKERNEL;
+	  return(LAMERROR);
 	}
+	if (_kio.ki_rtf & RTF_FORKED) {
+	  _kio.ki_rtf &= ~RTF_TRON;
+	}
+
+	/* If we didn't use mpirun, force C2C mode so that we can
+           connect up with MPI_COMM_CONNECT / MPI_COMM_ACCEPT to
+           processes that run in C2C mode */
+
+	if (!(_kio.ki_rtf & RTF_MPIRUN))
+	  _kio.ki_rtf |= RTF_MPIC2C;
+
 	_kio.ki_rtf |= RTF_MPI;
 /*
  * If process was not launched with mpirun, it will not be set to 
@@ -193,7 +196,8 @@ int			*root;
  */
 	if ((_kio.ki_rtf & RTF_MPIRUN) == 0)
 	  _kio.ki_rtf |= RTF_MPISIGS;
-	if (lpattach(name)) return(LAMERROR);
+	if (lpattach(name)) 
+	  return(LAMERROR);
 	lam_flinit = 1;
 
 	if (getenv("LAM_MPI_PAUSE")) {
@@ -374,6 +378,66 @@ int			*root;
 
 }
 
+/*
+ *	init_comm_world
+ *
+ *	Function:	- initialize MPI_COMM_WORLD
+ */
+int
+lam_init_comm_world(struct _gps *mpi_procs, int mpi_nprocs)
+{
+	MPI_Group	group;			/* a process group */
+	MPI_Comm	comm;			/* a communicator */
+	int		i;
+	struct _gps	*g;
+	struct _proc	**p;
+	int             cid;
+
+	comm = MPI_COMM_WORLD;
+
+	group = (MPI_Group) malloc((unsigned) sizeof(struct _group) +
+					(mpi_nprocs * sizeof(struct _proc *)));
+	if (group == 0) return(LAMERROR);
+
+	group->g_nprocs = mpi_nprocs;
+	group->g_myrank = MPI_UNDEFINED;
+	group->g_refcount = 1;
+	group->g_f77handle = -1;
+	group->g_procs = (struct _proc **)
+				((char *) group + sizeof(struct _group));
+/*
+ * Fill the group processes and determine my rank.
+ */
+	g = mpi_procs;
+	p = group->g_procs;
+
+	for (i = 0; i < mpi_nprocs; ++i, ++g, ++p) {
+
+		if ((*p = lam_procfind(g)) == 0) {
+			return(LAMERROR);
+		}
+		if (*p == lam_myproc) {
+			group->g_myrank = i;
+		}
+		(*p)->p_refcount++;
+	}
+
+	cid = lam_getcid();
+	if (lam_comm_new(cid, group, MPI_GROUP_NULL, LAM_PREDEF, &comm))
+		return(LAMERROR);
+
+	lam_setcid(cid);
+	comm->c_errhdl->eh_refcount++;
+	strcpy(comm->c_name, "MPI_COMM_WORLD");
+	if (LAM_TRACE_TOP())
+	  lam_tr_commname(comm->c_name, comm->c_contextid, MPI_Wtime());
+
+	if (!al_insert(lam_comms, &comm)) 
+	  return(LAMERROR);
+
+	return 0;
+}
+
 /*
  *	get_singleton_idx
  *
@@ -382,10 +446,7 @@ int			*root;
  *	Returns:	- kenya index or LAMERROR
  */
 static int
-get_singleton_idx(pid)
-
-int			pid;
-
+get_singleton_idx(int pid)
 {
 	struct pstate	state;			/* state returned from kenyad */
 	
@@ -397,14 +458,8 @@ int			pid;
 }
 
 int
-lam_get_proc_array(procs, world_n, cid, procs_n, is_impi)
-
-struct _gps     	**procs;	     	/* process GPS array */
-int			*world_n;
-int			*cid;
-int                     *procs_n;
-int                     is_impi;
-
+lam_get_proc_array(struct _gps **procs, int *world_n, int *cid,
+		   int *procs_n, int is_impi)
 {
 /*
  *  This subroutine is called twice if it is an IMPI job 
