@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/JRV/NJN
  *
- *	$Id: lamreduce.c,v 6.5 1999/08/14 22:06:55 jsquyres Exp $
+ *	$Id: lamreduce.c,v 6.6 2001/02/03 17:48:47 jsquyres Exp $
  *
  *	Function:	- all predefined reduce operations
  *			- min, max, sum, product
@@ -58,7 +57,7 @@ struct intint { int v; int k; };
 struct longint { long v; int k; };
 struct shortint { short v; int k; };
 #if LAM_SIZEOF_LONG_DOUBLE
-struct ldblint { long double v; int k; };
+struct ldblint { LAM_LONG_DOUBLE v; int k; };
 #else
 struct ldblint { double v; int k; };
 #endif
@@ -82,7 +81,7 @@ MPI_Datatype		*datatype;
 	float		*pfin, *pfout;
 	double		*pdin, *pdout;
 #if LAM_SIZEOF_LONG_DOUBLE
-	long double	*pldin, *pldout;
+	LAM_LONG_DOUBLE	*pldin, *pldout;
 #else
 	double		*pldin, *pldout;
 #endif
@@ -185,8 +184,8 @@ MPI_Datatype		*datatype;
 
 	if (*datatype == MPI_LONG_DOUBLE) {
 #if LAM_SIZEOF_LONG_DOUBLE
-		pldin = (long double *) invec;
-		pldout = (long double *) inoutvec;
+		pldin = (LAM_LONG_DOUBLE *) invec;
+		pldout = (LAM_LONG_DOUBLE *) inoutvec;
 #else
 		pldin = (double *) invec;
 		pldout = (double *) inoutvec;
@@ -254,7 +253,7 @@ MPI_Datatype		*datatype;
 	float		*pfin, *pfout;
 	double		*pdin, *pdout;
 #if LAM_SIZEOF_LONG_DOUBLE
-	long double	*pldin, *pldout;
+	LAM_LONG_DOUBLE	*pldin, *pldout;
 #else
 	double		*pldin, *pldout;
 #endif
@@ -349,8 +348,8 @@ MPI_Datatype		*datatype;
 
 	if (*datatype == MPI_LONG_DOUBLE) {
 #if LAM_SIZEOF_LONG_DOUBLE
-		pldin = (long double *) invec;
-		pldout = (long double *) inoutvec;
+		pldin = (LAM_LONG_DOUBLE *) invec;
+		pldout = (LAM_LONG_DOUBLE *) inoutvec;
 #else
 		pldin = (double *) invec;
 		pldout = (double *) inoutvec;
@@ -388,7 +387,7 @@ MPI_Datatype		*datatype;
 	struct complex	*pxin, *pxout;
 	struct dblcplex	*pdxin, *pdxout;
 #if LAM_SIZEOF_LONG_DOUBLE
-	long double	*pldin, *pldout;
+	LAM_LONG_DOUBLE	*pldin, *pldout;
 #else
 	double		*pldin, *pldout;
 #endif
@@ -487,8 +486,8 @@ MPI_Datatype		*datatype;
 
 	if (*datatype == MPI_LONG_DOUBLE) {
 #if LAM_SIZEOF_LONG_DOUBLE
-		pldin = (long double *) invec;
-		pldout = (long double *) inoutvec;
+		pldin = (LAM_LONG_DOUBLE *) invec;
+		pldout = (LAM_LONG_DOUBLE *) inoutvec;
 #else
 		pldin = (double *) invec;
 		pldout = (double *) inoutvec;
@@ -526,7 +525,7 @@ MPI_Datatype		*datatype;
 	struct complex	*pxin, *pxout;
 	struct dblcplex	*pdxin, *pdxout;
 #if LAM_SIZEOF_LONG_DOUBLE
-	long double	*pldin, *pldout;
+	LAM_LONG_DOUBLE	*pldin, *pldout;
 #else
 	double		*pldin, *pldout;
 #endif
@@ -629,8 +628,8 @@ MPI_Datatype		*datatype;
 
 	if (*datatype == MPI_LONG_DOUBLE) {
 #if LAM_SIZEOF_LONG_DOUBLE
-		pldin = (long double *) invec;
-		pldout = (long double *) inoutvec;
+		pldin = (LAM_LONG_DOUBLE *) invec;
+		pldout = (LAM_LONG_DOUBLE *) inoutvec;
 #else
 		pldin = (double *) invec;
 		pldout = (double *) inoutvec;
