@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB/RBD/NJN
  *
- *	$Id: lamreqs.c,v 6.11 1999/11/15 20:36:05 jsquyres Exp $
+ *	$Id: lamreqs.c,v 6.15 2000/11/01 02:01:01 jsquyres Exp $
  *
  *	Function:	- requests management functions
  */
@@ -48,39 +47,6 @@
 #endif
 #include <debug.h>
 
-/*
- * public functions
- */
-int			_mpi_req_build();
-int			_mpi_req_start();
-int			_mpi_req_destroy();
-void			_mpi_req_add();
-void			_mpi_req_rem();
-int			_mpi_req_advance();
-void			_mpi_req_blkclr();
-void			_mpi_req_blkset();
-int			_mpi_req_getn();
-void			_mpi_req_get();
-int			_mpi_req_end();
-
-/*
- * external functions
- */
-extern int		_rpi_c2c_start();
-extern int		_rpi_lamd_start();
-extern int		_rpi_c2c_build();
-extern int		_rpi_lamd_build();
-extern int		_rpi_c2c_advance();
-extern int		_rpi_lamd_advance();
-
-extern int		lam_comm_free();
-extern int		lam_dtype_free();
-extern int		lam_buffreebsend_();
-extern int		lam_bufinit();
-extern int		lam_bufinitbsend_();
-extern int		lam_mkerr();
-extern int		lam_pack();
-extern int		lam_unpack();
 
 /*
  * external variables
@@ -109,17 +75,8 @@ MPI_Request		lam_rq_bottom = 0;	/* bottom list of requests */
  *	Returns: 	- MPI_SUCCESS or error code
  */
 int
-_mpi_req_build(buf, count, dtype, rank, tag, comm, reqtype, preq)
-
-void			*buf;
-int			count;
-MPI_Datatype		dtype;
-int			rank;
-int			tag;
-MPI_Comm		comm;
-int			reqtype;
-MPI_Request		*preq;
-
+_mpi_req_build(void *buf, int count, MPI_Datatype dtype, int rank,
+	       int tag, MPI_Comm comm, int reqtype, MPI_Request *preq)
 {
 	MPI_Request	req;			/* request */
 	int		err;			/* error code */
@@ -154,7 +111,8 @@ MPI_Request		*preq;
  */
 	if (*preq == MPI_REQUEST_NULL) {
 		*preq = (MPI_Request) malloc(sizeof(struct _req));
-		if (*preq == 0) return(lam_mkerr(MPI_ERR_OTHER, errno));
+		if (*preq == 0) 
+		  return(lam_mkerr(MPI_ERR_OTHER, errno));
 		(*preq)->rq_marks = LAM_RQFDYNREQ;
 	} else {
 		(*preq)->rq_marks = 0;
@@ -183,6 +141,7 @@ MPI_Request		*preq;
 	req->rq_hdlr = 0;
 	req->rq_shadow = MPI_REQUEST_NULL;
 	req->rq_extra = 0;
+	req->rq_f77handle = -1;
 /*
  * Save the original communication parameters.
  */
@@ -241,7 +200,8 @@ MPI_Request		*preq;
 			req->rq_packsize = 0;
 		} else {
 			err = lam_bufinit(req);
-			if (err != MPI_SUCCESS) return(err);
+			if (err != MPI_SUCCESS) 
+			  return(err);
 		}
 	}
 /*
@@ -255,7 +215,8 @@ MPI_Request		*preq;
 
 	if (RPI_SPLIT(_rpi_lamd_build, _rpi_c2c_build, (req))) {
 		err = lam_mkerr(MPI_ERR_INTERN, errno);
-		if (err != MPI_SUCCESS) return(err);
+		if (err != MPI_SUCCESS) 
+		  return(err);
 	}
 
 	return(MPI_SUCCESS);
@@ -269,10 +230,7 @@ MPI_Request		*preq;
  *	Returns:	- MPI_SUCCESS or error code
  */
 int
-_mpi_req_start(req)
-
-MPI_Request		req;
-
+_mpi_req_start(MPI_Request req)
 {
 	int		err;
 	MPI_Request	cur;
@@ -315,7 +273,8 @@ MPI_Request		req;
  */
 		if (cur->rq_type == LAM_RQIBSEND) {
 			err = lam_bufinitbsend_(cur);
-			if (err != MPI_SUCCESS) return(err);
+			if (err != MPI_SUCCESS) 
+			  return(err);
 			cur->rq_flags |= LAM_RQFORPHAN;
 		}
 /*
@@ -356,10 +315,7 @@ MPI_Request		req;
  *	Returns:	- MPI_SUCCESS or error code
  */
 int
-_mpi_req_destroy(preq)
-
-MPI_Request		*preq;
-
+_mpi_req_destroy(MPI_Request *preq)
 {
 	MPI_Request	req;
 	int		err;
@@ -400,6 +356,12 @@ MPI_Request		*preq;
 			|| (req->rq_marks & LAM_RQFDYNBUF)) {
 		free(req->rq_packbuf);
 	}
+/*
+ * Remove the fortran handle if the user called MPI_Request_f2c on
+ * this handle
+ */
+	if (req->rq_f77handle >= 0)
+	  lam_F_free_hdl(req->rq_f77handle);
 /*
  * Clear request and free it.
  */
@@ -422,10 +384,7 @@ MPI_Request		*preq;
  *	Accepts:	- request
  */
 void
-_mpi_req_add(req)
-
-MPI_Request		req;
-
+_mpi_req_add(MPI_Request req)
 {
 /*
  * Ensure to add all the shadows, too.  Do this in a reverse-list
@@ -452,10 +411,7 @@ MPI_Request		req;
  *	Accepts:	- request
  */
 void
-_mpi_req_rem(req)
-
-MPI_Request		req;
-
+_mpi_req_rem(MPI_Request req)
 {
 	MPI_Request	p, p2;		/* favourite pointers */
 
@@ -463,7 +419,8 @@ MPI_Request		req;
  * Locate the request in the list.
  */
 	for (p = lam_rq_top, p2 = 0; p && (p != req); p2 = p, p = p->rq_next);
-	if (p == 0) return;
+	if (p == 0) 
+	  return;
 /*
  * Unlink the request from the list.
  */
@@ -485,8 +442,7 @@ MPI_Request		req;
  *	Returns:	- MPI_SUCCESS or error code
  */
 int
-_mpi_req_advance()
-
+_mpi_req_advance(void)
 {
 	MPI_Request	p;
 	MPI_Request	p2;
@@ -496,7 +452,8 @@ _mpi_req_advance()
 /*
  * If there are no requests, we are done.
  */
-	if (lam_rq_nreqs < 1) return(MPI_SUCCESS);
+	if (lam_rq_nreqs < 1) 
+	  return(MPI_SUCCESS);
 /*
  * If there are blocking requests, we continue advancing until one
  * of the blocking requests reaches the done state.
@@ -520,19 +477,21 @@ _mpi_req_advance()
 
 		    p = lam_rq_bottom;
 		    if (p->rq_flags & LAM_RQFBLOCK) {
-			break;
+		      break;
 		    }
 
 		    if (p->rq_hdlr && 
 			(p->rq_flags & LAM_RQFHDLDONE) == 0) {
 			err = _mpi_req_end(p);
-			if (err != MPI_SUCCESS) return(err);
+			if (err != MPI_SUCCESS) 
+			  return(err);
 /*			
  * Only invoke handlers if the request was not canceled
  */
 			if ((p->rq_flags & LAM_RQFCANCEL) == 0) {
 			  err = (*p->rq_hdlr)(p);
-			  if (err != MPI_SUCCESS) return(err);
+			  if (err != MPI_SUCCESS) 
+			    return(err);
 			}
 			p->rq_flags |= LAM_RQFHDLDONE;
 
@@ -540,7 +499,8 @@ _mpi_req_advance()
 			    _mpi_req_rem(p);
 
 			    err = _mpi_req_destroy(&p);
-			    if (err != MPI_SUCCESS) return(err);
+			    if (err != MPI_SUCCESS) 
+			      return(err);
 			}
 		    }
 		}
@@ -551,20 +511,21 @@ _mpi_req_advance()
 
 		    if (p->rq_state == LAM_RQSDONE) {
 			if (p->rq_flags & LAM_RQFBLOCK) {
-			    break;
+			  break;
 			}
 
 			if (p->rq_hdlr && 
 			    (p->rq_flags & LAM_RQFHDLDONE) == 0) {
 			    err = _mpi_req_end(p);
-			    if (err != MPI_SUCCESS) return(err);
-
+			    if (err != MPI_SUCCESS) 
+			      return(err);
 /*			
  * Only invoke handlers if the request was not canceled
  */
 			    if ((p->rq_flags & LAM_RQFCANCEL) == 0) {
 			      err = (*p->rq_hdlr)(p);
-			      if (err != MPI_SUCCESS) return(err);
+			      if (err != MPI_SUCCESS) 
+				return(err);
 			    }
 			    p->rq_flags |= LAM_RQFHDLDONE;
 
@@ -574,7 +535,8 @@ _mpi_req_advance()
 				_mpi_req_rem_m(p2);
 
 				err = _mpi_req_destroy(&p2);
-				if (err != MPI_SUCCESS) return(err);
+				if (err != MPI_SUCCESS) 
+				  return(err);
 
 				continue;
 			    }
@@ -596,7 +558,8 @@ _mpi_req_advance()
  */
 		r = RPI_SPLIT(_rpi_lamd_advance,
 				_rpi_c2c_advance, (lam_rq_top, FALSE));
-		if (r < 0) return(lam_mkerr(MPI_ERR_INTERN, errno));
+		if (r < 0) 
+		  return(lam_mkerr(MPI_ERR_INTERN, errno));
 	    } while (r == 1);
 	}
 /*
@@ -614,14 +577,16 @@ _mpi_req_advance()
 
 		if (p->rq_hdlr && (p->rq_flags & LAM_RQFHDLDONE) == 0) {
 		    err = _mpi_req_end(p);
-		    if (err != MPI_SUCCESS) return(err);
+		    if (err != MPI_SUCCESS) 
+		      return(err);
 
 /*			
  * Only invoke handlers if the request was not canceled
  */
 		    if ((p->rq_flags & LAM_RQFCANCEL) == 0) {
 		      err = (*p->rq_hdlr)(p);
-		      if (err != MPI_SUCCESS) return(err);
+		      if (err != MPI_SUCCESS) 
+			return(err);
 		    }
 		    p->rq_flags |= LAM_RQFHDLDONE;
 		}
@@ -631,11 +596,13 @@ _mpi_req_advance()
 
 		    if (!p->rq_hdlr) {
 			err = _mpi_req_end(p);
-			if (err != MPI_SUCCESS) return(err);
+			if (err != MPI_SUCCESS) 
+			  return(err);
 		    }
 		    
 		    err = _mpi_req_destroy(&p);
-		    if (err != MPI_SUCCESS) return(err);
+		    if (err != MPI_SUCCESS) 
+		      return(err);
 		} else {
 		    prev = p;
 		}
@@ -653,8 +620,7 @@ _mpi_req_advance()
  *	Function:	- clear requests block flag
  */
 void
-_mpi_req_blkclr()
-
+_mpi_req_blkclr(void)
 {
 	MPI_Request	p;			/* favourite pointer */
 
@@ -672,10 +638,7 @@ _mpi_req_blkclr()
  *	Accepts:	- request
  */
 void
-_mpi_req_blkset(req)
-
-MPI_Request		req;
-
+_mpi_req_blkset(MPI_Request req)
 {
 	req->rq_flags |= LAM_RQFBLOCK;
 	lam_rq_flblock = 1;
@@ -688,8 +651,7 @@ MPI_Request		req;
  *	Returns:	- # requests
  */
 int
-_mpi_req_getn()
-
+_mpi_req_getn(void)
 {
 	return(lam_rq_nreqs);
 }
@@ -702,11 +664,7 @@ _mpi_req_getn()
  *			- requests array (returned values)
  */
 void
-_mpi_req_get(n, reqs)
-
-int			n;
-MPI_Request		*reqs;
-
+_mpi_req_get(int n, MPI_Request *reqs)
 {
 	MPI_Request	p;			/* favourite pointer */
 	int		i;			/* favourite index */
@@ -726,10 +684,7 @@ MPI_Request		*reqs;
  *	Returns:	- MPI_SUCCESS or error code
  */
 int
-_mpi_req_end(req)
-
-MPI_Request		req;
-
+_mpi_req_end(MPI_Request req)
 {
     int			err;
 /*
