@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB/NJN
  *
- *	$Id: lamsend.c,v 6.20 1999/11/12 05:19:30 jsquyres Exp $
+ *	$Id: lamsend.c,v 6.22 2000/10/25 23:31:55 jsquyres Exp $
  *
  *	Function:	- shared code for send functions
  */
@@ -46,13 +45,6 @@
 #include <debug.h>
 #include <blktype.h>
 
-/*
- * public functions
- */
-int			lam_send();
-int			lam_isend();
-
-
 /*
  * external variables
  */
@@ -64,6 +56,7 @@ extern struct _proc     *lam_impid_proc;
  */
 static int		fl_debug = 0;
 
+
 /*
  *	lam_send
  *
@@ -73,16 +66,8 @@ static int		fl_debug = 0;
  *	Returns:	- MPI_SUCCESS or error code
  */
 int
-lam_send(buf, count, dtype, dest, tag, comm, reqtype)
-
-void			*buf;
-int			count;
-MPI_Datatype		dtype;
-int			dest;
-int			tag;
-MPI_Comm		comm;
-int			reqtype;
-
+lam_send(void *buf, int count, MPI_Datatype dtype, int dest, int tag,
+	 MPI_Comm comm, int reqtype)
 {
 	int		err;
 	int		fl_trace;		/* do tracing? */
@@ -98,9 +83,11 @@ int			reqtype;
 /*
  * Handle the trivial cases.
  */
-	if (dest == MPI_ANY_SOURCE) return(lam_mkerr(MPI_ERR_RANK, 0));
+	if (dest == MPI_ANY_SOURCE) 
+	  return(lam_mkerr(MPI_ERR_RANK, 0));
 
-	if (dest == MPI_PROC_NULL) return(MPI_SUCCESS);
+	if (dest == MPI_PROC_NULL) 
+	  return(MPI_SUCCESS);
 
 	if ((fl_trace = LAM_TRACE_TOP())) {
 		startt = MPI_Wtime();
@@ -125,7 +112,7 @@ int			reqtype;
 	}
 #endif
 
-#ifdef SHORTCIRCUIT
+#if SHORTCIRCUIT
 	if (reqtype == LAM_RQISEND && lam_c2c && lam_rq_nactv == 0) {
 	    if (comm == MPI_COMM_NULL) {
 		return(lam_mkerr(MPI_ERR_COMM, 0));
@@ -153,19 +140,22 @@ int			reqtype;
 	req = &req_storage;
 	err = _mpi_req_build(buf, count, dtype, dest, tag, comm, reqtype, 
 			     &req);
-	if (err != MPI_SUCCESS) return(err);
+	if (err != MPI_SUCCESS) 
+	  return(err);
 
 	req->rq_marks |= (LAM_RQFBLKTYPE | LAM_RQFMAND);
 
 	err = _mpi_req_start(req);
-	if (err != MPI_SUCCESS) return(err);
+	if (err != MPI_SUCCESS) 
+	  return(err);
 
 	_mpi_req_add_m(req);
 	_mpi_req_blkclr_m();
 	_mpi_req_blkset_m(req);
 
 	err = _mpi_req_advance();
-	if (err != MPI_SUCCESS) return(err);
+	if (err != MPI_SUCCESS) 
+	  return(err);
 
 	req_err = req->rq_status.MPI_ERROR;
 	seqnum = req->rq_seq;
@@ -173,7 +163,8 @@ int			reqtype;
 	_mpi_req_rem_m(req);
 
 	err = _mpi_req_destroy(&req);
-	if (err != MPI_SUCCESS) return(err);
+	if (err != MPI_SUCCESS) 
+	  return(err);
 /*
  * Generate a trace.
  */
@@ -189,6 +180,7 @@ int			reqtype;
 	return(req_err);
 }
 
+
 /*
  *	lam_isend
  *
@@ -198,30 +190,24 @@ int			reqtype;
  *	Returns:	- MPI_SUCCESS or error code
  */
 int
-lam_isend(buf, count, dtype, dest, tag, comm, preq, reqtype)
-
-void			*buf;
-int			count;
-MPI_Datatype		dtype;
-int			dest;
-int			tag;
-MPI_Comm		comm;
-MPI_Request		*preq;
-int			reqtype;
-
+lam_isend(void *buf, int count, MPI_Datatype dtype, int dest, int tag,
+	  MPI_Comm comm, MPI_Request *preq, int reqtype)
 {
 	int		err;
 #if LAM_WANT_IMPI
 	MPI_Request     lreq;
 #endif
 
-	if (dest == MPI_ANY_SOURCE) return(lam_mkerr(MPI_ERR_RANK, 0));
+	if (dest == MPI_ANY_SOURCE) 
+	  return(lam_mkerr(MPI_ERR_RANK, 0));
 
 #if LAM_WANT_IMPI
 	/* If IMPI_Isend_lamgiappe fills in a request, this is an IMPI
            proxy send.  Need to re-route to the impid.  */
 
-	IMPI_Isend_lamgiappe(LAM_RQISEND, count, dtype, dest, tag, 
+	/* Values that reqtype can be: lam_rqibsend, lam_rqirsend,
+           lam_rqisend, lam_rqissend */
+	IMPI_Isend_lamgiappe(reqtype, count, dtype, dest, tag, 
 			     comm, &lreq);
 	if (lreq != MPI_REQUEST_NULL) {
 	  dest = impid_comm->c_group->g_nprocs - 1;
@@ -233,12 +219,14 @@ int			reqtype;
 	*preq = MPI_REQUEST_NULL;
 	err = _mpi_req_build(buf, count, dtype, dest, tag, comm,
 			     reqtype, preq);
-	if (err != MPI_SUCCESS) return(err);
+	if (err != MPI_SUCCESS) 
+	  return(err);
 
 	(*preq)->rq_marks |= LAM_RQFMAND;
 
 	err = _mpi_req_start(*preq);
-	if (err != MPI_SUCCESS) return(err);
+	if (err != MPI_SUCCESS) 
+	  return(err);
 
 #if LAM_WANT_IMPI
 /*
