@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: lamtrace.c,v 6.4 1999/05/25 22:08:07 kmeyer1 Exp $
+ *	$Id: lamtrace.c,v 6.8 2000/10/31 14:26:27 jsquyres Exp $
  *
  *	Function:	- MPI trace generation
  */
@@ -50,6 +49,7 @@
 #include <t_types.h>
 #include <terror.h>
 #include <typical.h>
+#include <trreq.h>
 
 /*
  * macros
@@ -67,42 +67,22 @@ static int		trace_num = 0;		/* current trace number */
 static int		cff_func = 0;		/* collective/fin function */
 static double		cff_start;		/* collective/fin start time */
 
-/*
- * global functions
- */
-double			lam_tr_timer();
-int			lam_tr_comm();
-int			lam_tr_dtype();
-void			lam_tr_dtypefree();
-int			lam_tr_off();
-int			lam_tr_on();
-int			lam_tr_init();
-void			lam_tr_msg();
-void			lam_tr_sub();
-void			lam_tr_startall();
-int			lam_tr_wrapstart();
-void			lam_tr_wrapend();
-int			lam_tr_incff();
-void			lam_tr_cffstart();
-void			lam_tr_cffend();
-
-/*
- * external functions
- */
-extern int		lam_rtrstore();
-
 /*
  * local functions
  */
-static int		checkdtbuf();
-static int		flat_basic();
-static int		flat_dtype();
-static int		flat_contig();
-static int		flat_hvector();
-static int		flat_hindexed();
-static int		flat_struct();
-static int		mkflatdtype();
-static void		setfunctions();
+static void setfunctions(struct trmsg *pmsg, int reqtype);
+static int checkdtbuf(struct trdtype **pbf, int *psz, int nrec);
+static int flat_struct(MPI_Datatype dtype, struct trdtype **pbuff, int *psize);
+static int flat_hindexed(MPI_Datatype dtype, struct trdtype **pbuff, 
+			 int *psize, int fmt);
+static int flat_hvector(MPI_Datatype dtype, struct trdtype **pbuff, 
+			int *psize, int fmt);
+static int flat_contig(MPI_Datatype dtype, struct trdtype **pbuff, int *psize);
+static int flat_basic(MPI_Datatype dtype, struct trdtype **pbuff, int *psize);
+static int flat_dtype(MPI_Datatype datatype, struct trdtype **pbuffer, 
+		      int *prec);
+static int mkflatdtype(MPI_Datatype dtype, int dtlabel, char **pbuf, 
+		       int *psize);
 
 /*
  *	lam_tr_comm
@@ -112,10 +92,7 @@ static void		setfunctions();
  *	Returns:	- 0 or LAMERROR
  */
 int
-lam_tr_comm(comm)
-
-MPI_Comm		comm;
-
+lam_tr_comm(MPI_Comm comm)
 {
 	int		bufsize;		/* buffer size */
 	int		size1;			/* group1 size */
@@ -200,10 +177,7 @@ MPI_Comm		comm;
  *	Returns:	- 0 or LAMERROR
  */
 int
-lam_tr_dtype(dtype)
-
-MPI_Datatype		dtype;
-
+lam_tr_dtype(MPI_Datatype dtype)
 {
 	char		*buf;			/* datatype buffer */
 	int		bufsize;		/* buffer size */
@@ -242,10 +216,7 @@ MPI_Datatype		dtype;
  *	Accepts:	- datatype
  */
 void
-lam_tr_dtypefree(dtype)
-
-MPI_Datatype		dtype;
-
+lam_tr_dtypefree(MPI_Datatype dtype)
 {
 }
 
@@ -257,7 +228,6 @@ MPI_Datatype		dtype;
  */
 double
 lam_tr_timer()
-
 {
 	if ((_kio.ki_rtf & RTF_TRON) == RTF_TRON) {
 		return(ttime());
@@ -275,7 +245,6 @@ lam_tr_timer()
  */
 int
 lam_tr_off()
-
 {
 	int		trmode;			/* previous mode */
 	int		trsize;			/* trace size */
@@ -330,7 +299,6 @@ lam_tr_off()
  */
 int
 lam_tr_on()
-
 {
 	int		trmode;			/* previous mode */
 	int		trsize;			/* trace size */
@@ -384,11 +352,7 @@ lam_tr_on()
  *	Returns:	- 0 or LAMERROR
  */
 int
-lam_tr_init(name, skew)
-
-char			*name;
-float8			skew;
-
+lam_tr_init(char *name, float8 skew)
 {
 	struct trsrc	*psrc;			/* ptr src header */
 	struct trrthdr  *ptrr;			/* ptr runtime header */
@@ -460,23 +424,9 @@ float8			skew;
  *			- request type
  */
 void
-lam_tr_msg(type, time, syst, blkt, peer, tag, comm, dtype, count,
-		mrank,	mtag, seqnum, reqtype)
-
-int			type;
-double			time;
-int			syst;
-int			blkt;
-int			peer;
-int			tag;
-MPI_Comm		comm;
-MPI_Datatype		dtype;
-int			count;
-int			mrank;
-int			mtag;
-int			seqnum;
-int			reqtype;
-
+lam_tr_msg(int type, double time, int syst, int blkt, int peer, int tag,
+	   MPI_Comm comm, MPI_Datatype dtype, int count, int mrank,
+	   int mtag, int seqnum, int reqtype)
 {
 	struct trsrc	*psrc;			/* ptr src header */
 	struct trrthdr  *ptrr;			/* ptr runtime header */
@@ -523,12 +473,7 @@ int			reqtype;
  *			- substrate
  */
 void
-lam_tr_sub(func, time, sub)
-
-int			func;
-double			time;
-int			sub;
-
+lam_tr_sub(int func, double time, int sub)
 {
 	struct trsrc	*psrc;			/* ptr src header */
 	struct trrthdr  *ptrr;			/* ptr runtime header */
@@ -568,14 +513,8 @@ int			sub;
  *			- finish time of MPI_Startall
  */
 void
-lam_tr_startall(nreq, preq, startt, advt, finisht)
-
-int			nreq;
-MPI_Request		*preq;
-double			startt;
-double			advt;
-double			finisht;
-
+lam_tr_startall(int nreq, MPI_Request *preq, double startt, double advt,
+		double finisht)
 {
 	MPI_Request	*p;			/* favourite pointer */
 	int		i;			/* favourite index */
@@ -614,10 +553,7 @@ double			finisht;
  *	Returns:	- true iff this function should be traced
  */
 int
-lam_tr_wrapstart(func)
-
-int			func;
-
+lam_tr_wrapstart(int func)
 {
 	if (func == lam_getfunc() && ! lam_tr_incff()) {
 		
@@ -637,10 +573,7 @@ int			func;
  *	Accepts:	- wrapper function
  */
 void
-lam_tr_wrapend(func)
-
-int			func;
-
+lam_tr_wrapend(int func)
 {
 	if (func == lam_getfunc()) {
 
@@ -657,7 +590,6 @@ int			func;
  */
 int
 lam_tr_incff()
-
 {
 	return(cff_func != 0);
 }
@@ -669,10 +601,7 @@ lam_tr_incff()
  *	Accepts:	- function
  */
 void
-lam_tr_cffstart(func)
-
-int			func;
-
+lam_tr_cffstart(int func)
 {
 	if (cff_func == 0) {
 		_kio.ki_blktime = 0.0;
@@ -692,14 +621,8 @@ int			func;
  *			- count (if any)
  */
 void
-lam_tr_cffend(func, root, comm, dtype, count)
-
-int			func;
-int			root;
-MPI_Comm		comm;
-MPI_Datatype		dtype;
-int			count;
-
+lam_tr_cffend(int func, int root, MPI_Comm comm, MPI_Datatype dtype, 
+	      int count)
 {
 	double		totaltime;		/* total time in function */
 	
@@ -722,7 +645,6 @@ int			count;
  */
 void
 lam_nuketrace()
-
 {
         dtlabel = TRDTMAX + 1;
 
@@ -735,6 +657,196 @@ lam_nuketrace()
 	trace_num = 0;
 }
 
+
+/*
+ *      lam_tr_buoy
+ *
+ *      Function:       - drops a TRBUOY into the trace sea
+ *      Accepts:        - name and time for buoy
+ */
+int
+lam_tr_buoy(const char *name, double t)
+{
+  struct trsrc *psrc;
+  struct trrthdr *ptrr;
+  struct trbuoy *pbuoy;
+  int trsize;
+
+  trsize = (sizeof(struct trsrc) +
+	    sizeof(struct trrthdr) +
+	    sizeof(struct trbuoy));
+  
+  psrc = (struct trsrc *) malloc(trsize);
+  psrc->trs_node = ltot(getnodeid());
+  psrc->trs_pid = ltot(getpid());
+  psrc->trs_listno = ltot(TRRUNTIME);
+  
+  /* advance to the trrthdr struct */
+
+  ptrr = (struct trrthdr *) (psrc + 1);
+  ptrr->trr_type = ltot(TRBUOY);
+  ltotf8(&t, &(ptrr->trr_time));
+  
+  /* advance to the trbuoy struct */
+
+  pbuoy = (struct trbuoy *) (ptrr + 1);
+  memset(pbuoy->trb_name, 0, sizeof(pbuoy->trb_name));
+  strncpy(pbuoy->trb_name, name, 32);
+  
+  if (lam_rtrstore(LOCAL,
+		   TRRUNTIME,
+		   lam_myproc->p_gps.gps_pid,
+		   (char*) psrc,
+		   trsize)){
+    free((char*) psrc);
+    return LAMERROR;
+  }
+
+  free((char*) psrc);
+  return 0;
+}
+
+/*
+ *      lam_tr_coloron
+ *
+ *      Function:       - drops a TRCOLORON into the trace sea
+ *      Accepts:        - red, green, blue values
+ *                      - time
+ */
+int
+lam_tr_coloron(int red, int green, int blue, double t)
+{
+  struct trsrc *psrc;
+  struct trrthdr *ptrr;
+  struct trcolor *pcolor;
+  int trsize;
+
+  trsize = (sizeof(struct trsrc) +
+	    sizeof(struct trrthdr) +
+	    sizeof(struct trcolor));
+  
+  psrc = (struct trsrc *) malloc(trsize);
+  psrc->trs_node = ltot(getnodeid());
+  psrc->trs_pid = ltot(getpid());
+  psrc->trs_listno = ltot(TRRUNTIME);
+  
+  /* advance to the trrthdr struct */
+
+  ptrr = (struct trrthdr *) (psrc + 1);
+  ptrr->trr_type = ltot(TRCOLORON);
+  ltotf8(&t, &(ptrr->trr_time));
+  
+  /* advance to the trcolor struct */
+
+  pcolor = (struct trcolor *) (ptrr + 1);
+  LAM_ZERO_ME(*pcolor);
+  pcolor->trcol_red = ltot(red);
+  pcolor->trcol_green = ltot(green);
+  pcolor->trcol_blue = ltot(blue);
+  
+  if (lam_rtrstore(LOCAL,
+		   TRRUNTIME,
+		   lam_myproc->p_gps.gps_pid,
+		   (char*) psrc,
+		   trsize)){
+    free((char*) psrc);
+    return LAMERROR;
+  }
+
+  free((char*) psrc);
+  return 0;
+}
+
+
+/*
+ *      lam_tr_coloroff
+ *
+ *      Function:       - drops a TRCOLOROFF into the trace sea
+ *      Accepts:        - time
+ */
+int
+lam_tr_coloroff(double t)
+{
+  struct trsrc *psrc;
+  struct trrthdr *ptrr;
+  int trsize;
+
+  trsize = (sizeof(struct trsrc) +
+	    sizeof(struct trrthdr));
+  
+  psrc = (struct trsrc *) malloc(trsize);
+  psrc->trs_node = ltot(getnodeid());
+  psrc->trs_pid = ltot(getpid());
+  psrc->trs_listno = ltot(TRRUNTIME);
+  
+  /* advance to the trrthdr struct */
+
+  ptrr = (struct trrthdr *) (psrc + 1);
+  ptrr->trr_type = ltot(TRCOLOROFF);
+  ltotf8(&t, &(ptrr->trr_time));
+  
+  if (lam_rtrstore(LOCAL,
+		   TRRUNTIME,
+		   lam_myproc->p_gps.gps_pid,
+		   (char*) psrc,
+		   trsize)){
+    free((char*) psrc);
+    return LAMERROR;
+  }
+
+  free((char*) psrc);
+  return 0;
+}
+
+/*
+ *      lam_tr_commname
+ *
+ *      Function:       - drops a TRCOMMNAME into the trace sea
+ *      Accepts:        - communicator name and cid, and time
+ */
+int
+lam_tr_commname(char *name, int cid, double t)
+{
+  struct trsrc *psrc;
+  struct trrthdr *ptrr;
+  struct trcommname *pcomm;
+  int trsize;
+
+  trsize = (sizeof(struct trsrc) +
+	    sizeof(struct trrthdr) +
+	    sizeof(struct trcommname));
+  
+  psrc = (struct trsrc *) malloc(trsize);
+  psrc->trs_node = ltot(getnodeid());
+  psrc->trs_pid = ltot(getpid());
+  psrc->trs_listno = ltot(TRRUNTIME);
+  
+  /* advance to the trrthdr struct */
+
+  ptrr = (struct trrthdr *) (psrc + 1);
+  ptrr->trr_type = ltot(TRCOMMNAME);
+  ltotf8(&t, &(ptrr->trr_time));
+  
+  /* advance to the trbuoy struct */
+
+  pcomm = (struct trcommname *) (ptrr + 1);
+  memset(pcomm->trcomm_name, 0, sizeof(pcomm->trcomm_name));
+  strncpy(pcomm->trcomm_name, name, 128);
+  pcomm->trcomm_cid = ltot(cid);
+  
+  if (lam_rtrstore(LOCAL,
+		   TRRUNTIME,
+		   lam_myproc->p_gps.gps_pid,
+		   (char*) psrc,
+		   trsize)){
+    free((char*) psrc);
+    return LAMERROR;
+  }
+
+  free((char*) psrc);
+  return 0;
+}
+
 /*
  *	mkflatdtype
  *
@@ -757,13 +869,7 @@ lam_nuketrace()
  *	Returns:	- 0 or LAMERROR
  */
 static int
-mkflatdtype(dtype, dtlabel, pbuf, psize)
-
-MPI_Datatype		dtype;
-int			dtlabel;
-char			**pbuf;
-int			*psize;
-
+mkflatdtype(MPI_Datatype dtype, int dtlabel, char **pbuf, int *psize)
 {
 	int		nrec;			/* # records available */
 	struct trsrc    *psrc;			/* ptr src header */
@@ -818,12 +924,7 @@ int			*psize;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-flat_dtype(datatype, pbuffer, prec)
-
-MPI_Datatype		datatype;
-struct trdtype		**pbuffer;
-int			*prec;
-
+flat_dtype(MPI_Datatype datatype, struct trdtype **pbuffer, int *prec)
 {
 	int		ret;			/* return value */
 	int		fmt;			/* datatype format */
@@ -888,12 +989,7 @@ int			*prec;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-flat_basic(dtype, pbuff, psize)
-
-MPI_Datatype		dtype;
-struct trdtype		**pbuff;
-int			*psize;
-
+flat_basic(MPI_Datatype dtype, struct trdtype **pbuff, int *psize)
 {
 	int4		type;
 /*
@@ -995,12 +1091,7 @@ int			*psize;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-flat_contig(dtype, pbuff, psize)
-
-MPI_Datatype		dtype;
-struct trdtype		**pbuff;
-int			*psize;
-
+flat_contig(MPI_Datatype dtype, struct trdtype **pbuff, int *psize)
 {
 /*
  * Make sure datatype buffer has at least 1 extra record.
@@ -1030,13 +1121,8 @@ int			*psize;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-flat_hvector(dtype, pbuff, psize, fmt)
-
-MPI_Datatype		dtype;
-struct trdtype		**pbuff;
-int			*psize;
-int			fmt;
-
+flat_hvector(MPI_Datatype dtype, struct trdtype **pbuff, int *psize, 
+	     int fmt)
 {
 	int		extent;			/* datatype extent */
 /*
@@ -1075,13 +1161,8 @@ int			fmt;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-flat_hindexed(dtype, pbuff, psize, fmt)
-
-MPI_Datatype		dtype;
-struct trdtype		**pbuff;
-int			*psize;
-int			fmt;
-
+flat_hindexed(MPI_Datatype dtype, struct trdtype **pbuff, int *psize, 
+	      int fmt)
 {
 	int		i;			/* favourite index */
 	int		extent;			/* datatype extent */
@@ -1124,12 +1205,7 @@ int			fmt;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-flat_struct(dtype, pbuff, psize)
-
-MPI_Datatype		dtype;
-struct trdtype		**pbuff;
-int			*psize;
-
+flat_struct(MPI_Datatype dtype, struct trdtype **pbuff, int *psize)
 {
 	int		i;			/* favourite index */
 /*
@@ -1177,12 +1253,7 @@ int			*psize;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-checkdtbuf(pbf, psz, nrec)
-
-struct trdtype		**pbf;
-int			*psz;
-int			nrec;
-
+checkdtbuf(struct trdtype **pbf, int *psz, int nrec)
 {
 	char		*newbuf;
 	int		newsize;
@@ -1229,11 +1300,7 @@ int			nrec;
  *			- request type
  */
 static void
-setfunctions(pmsg, reqtype)
-
-struct trmsg		*pmsg;
-int			reqtype;
-
+setfunctions(struct trmsg *pmsg, int reqtype)
 {
 	int		topfunc;
 
