@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN/RBD
  *
- *	$Id: lamupdown.c,v 6.8 1999/08/26 20:55:19 jsquyres Exp $
+ *	$Id: lamupdown.c,v 6.12 2000/01/27 19:16:23 jsquyres Exp $
  *
  *	Function:	- take top level info down
  *			- take error info up
@@ -42,6 +41,10 @@
 #include <mpisys.h>
 #include <rpisys.h>
 #include <blktype.h>
+#include <lam_config.h>
+#if LAM_HAVE_THREADS
+#include <lamthreads.h>
+#endif
 
 /*
  * global variables
@@ -70,6 +73,21 @@ lam_setfunc(locfunc)
 int			locfunc;
 
 {
+#if LAM_HAVE_THREADS
+/*
+ * There are several places where MPI functions call each other -- we
+ * want to allow this.  But we can't let other threads in until this
+ * one finishes.  The lam_mpi_mutex will be released in
+ * lam_reset_func().
+ */
+  if (lam_thread_level > MPI_THREAD_SINGLE) {
+    if (!lam_mutex_is_owner(&lam_mpi_mutex)) {
+      lam_mutex_lock(&lam_mpi_mutex);
+    }
+    lam_mutex_lock(&lam_updown_mutex);
+  }
+#endif
+
   /* Grow the stack if necessary */
 
   if (max_funcs <= num_funcs) {
@@ -86,6 +104,12 @@ int			locfunc;
   lam_topfunc = locfunc;
   funcs[num_funcs] = locfunc;
   num_funcs++;
+
+#if LAM_HAVE_THREADS
+  if (lam_thread_level > MPI_THREAD_SINGLE) {
+    lam_mutex_unlock(&lam_updown_mutex);
+  }
+#endif
 }
 
 /*
@@ -101,6 +125,13 @@ int			locfunc;
 
 {
   struct _fyiproc	*p;			/* favourite pointer */
+
+#if LAM_HAVE_THREADS
+  if (lam_thread_level > MPI_THREAD_SINGLE) {
+    lam_mutex_lock(&lam_updown_mutex);
+  }
+#endif
+
   p = (struct _fyiproc *) _kio.ki_fyi;
   
   if (num_funcs > 0) {
@@ -113,6 +144,23 @@ int			locfunc;
 	lam_topfunc = p->fyp_func = 0;
     }
   }
+#if LAM_HAVE_THREADS
+/*
+ * There are several places where MPI functions call each other -- we
+ * want to allow this.  But we can't let other threads in until this
+ * one finishes.  lam_mpi_mutex was locked in lam_setfunc().
+ *
+ * Special case: if we're resetting and we're in BLKMPIINITTHREAD and
+ * the mutex owner is -1, don't try to unlock it.  See MPI_Init_thread
+ * for the reason why.
+ */
+  if (lam_thread_level > MPI_THREAD_SINGLE) {
+    if (lam_mutex_is_owner(&lam_mpi_mutex) && num_funcs == 0) {
+      lam_mutex_unlock(&lam_mpi_mutex);
+    }
+    lam_mutex_unlock(&lam_updown_mutex);
+  }
+#endif
 }
 
 /*
@@ -124,7 +172,21 @@ int			locfunc;
 int
 lam_numfuncs()
 {
+#if LAM_HAVE_THREADS
+  int ret;
+
+  if (lam_thread_level > MPI_THREAD_SINGLE) 
+    lam_mutex_lock(&lam_updown_mutex);
+
+  ret = num_funcs;
+
+  if (lam_thread_level > MPI_THREAD_SINGLE) 
+    lam_mutex_unlock(&lam_updown_mutex);
+
+  return ret;
+#else
   return num_funcs;
+#endif
 }
 
 
@@ -138,10 +200,24 @@ int
 lam_getfunc()
 
 {
+  int ret;
+
+#if LAM_HAVE_THREADS
+  if (lam_thread_level > MPI_THREAD_SINGLE) 
+    lam_mutex_lock(&lam_updown_mutex);
+#endif
+
   if (num_funcs > 0)
-    return funcs[num_funcs - 1];
+    ret = funcs[num_funcs - 1];
   else
-    return 0;
+    ret = 0;
+
+#if LAM_HAVE_THREADS
+  if (lam_thread_level > MPI_THREAD_SINGLE) 
+    lam_mutex_unlock(&lam_updown_mutex);
+#endif
+
+  return ret;
 }
 
 /*
@@ -160,10 +236,20 @@ int			root;
 int			rootgps;
 
 {
+#if LAM_HAVE_THREADS
+	if (lam_thread_level > MPI_THREAD_SINGLE) 
+	  lam_mutex_lock(&lam_updown_mutex);
+#endif
+
 	if (lam_topfunc == locfunc) {
 		lam_toproot = root;
 		lam_toprootgps = rootgps;
 	}
+
+#if LAM_HAVE_THREADS
+	if (lam_thread_level > MPI_THREAD_SINGLE) 
+	  lam_mutex_unlock(&lam_updown_mutex);
+#endif
 }
 
 /*
@@ -180,8 +266,18 @@ int			*proot;
 int			*prootgps;
 
 {
+#if LAM_HAVE_THREADS
+	if (lam_thread_level > MPI_THREAD_SINGLE) 
+	  lam_mutex_lock(&lam_updown_mutex);
+#endif
+
 	*proot = lam_toproot;
 	*prootgps = lam_toprootgps;
+
+#if LAM_HAVE_THREADS
+	if (lam_thread_level > MPI_THREAD_SINGLE) 
+	  lam_mutex_unlock(&lam_updown_mutex);
+#endif
 }
 
 /*
@@ -201,8 +297,19 @@ int			error;
 {
 	int		errcode;
 
+#if LAM_HAVE_THREADS
+	if (lam_thread_level > MPI_THREAD_SINGLE) 
+	  lam_mutex_lock(&lam_updown_mutex);
+#endif
+
 	errcode = ((error & 0xFFFF) << 8) | (lam_topfunc & 0xFF);
 	errcode = (errcode << 8) | (class & 0xFF);
+
+#if LAM_HAVE_THREADS
+	if (lam_thread_level > MPI_THREAD_SINGLE) 
+	  lam_mutex_unlock(&lam_updown_mutex);
+#endif
+
 	return(errcode);
 }
 
@@ -288,10 +395,11 @@ lam_printfunc()
 
   if (num_funcs > 0) {
     myrank = lam_myproc->p_gps.gps_grank;
-    printf("Rank %d: Call stack within LAM:\n", myrank);
+    printf("Rank (%d, MPI_COMM_WORLD): Call stack within LAM:\n", myrank);
     for (i = --num_funcs; i >= 0; i--)
-      printf("Rank %d:  - %s()\n", myrank, blktype(funcs[i]));
-    printf("Rank %d:  - main()\n", myrank);
+      printf("Rank (%d, MPI_COMM_WORLD):  - %s()\n", myrank, 
+	     blktype(funcs[i]));
+    printf("Rank (%d, MPI_COMM_WORLD):  - main()\n", myrank);
   }
 }
 
@@ -305,6 +413,11 @@ void
 lam_nukefunc()
 
 {
+#if LAM_HAVE_THREADS
+  if (lam_thread_level > MPI_THREAD_SINGLE) 
+    lam_mutex_lock(&lam_updown_mutex);
+#endif
+
   lam_topfunc = 0;
   if (max_funcs > 0) {
     max_funcs = 0;
@@ -315,6 +428,11 @@ lam_nukefunc()
 
   lam_topfunc = 0;
   ((struct _fyiproc *) _kio.ki_fyi)->fyp_func = 0;
+
+#if LAM_HAVE_THREADS
+  if (lam_thread_level > MPI_THREAD_SINGLE) 
+    lam_mutex_unlock(&lam_updown_mutex);
+#endif
 }
 
 /*
