@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: probe.c,v 6.6 1999/08/27 23:46:07 jsquyres Exp $
+ *	$Id: probe.c,v 6.7 1999/12/31 21:27:35 jsquyres Exp $
  *
  *	Function:	- blocking check of incoming messages
  *			- message is not received
@@ -48,14 +47,30 @@
 #include <rpisys.h>
 
 
-int
-MPI_Probe(src, tag, comm, stat)
+/*@
+    MPI_Probe - Blocking test for a message
 
-int			src;
-int			tag;
-MPI_Comm		comm;
-MPI_Status		*stat;
+Input Parameters:
++ src - source rank, or 'MPI_ANY_SOURCE' (integer) 
+. tag - tag value or 'MPI_ANY_TAG' (integer) 
+- comm - communicator (handle) 
 
+Output Parameter:
+. stat - status object (Status), which may be the MPI constant
+'MPI_STATUS_IGNORE'
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_TAG
+.N MPI_ERR_RANK
+
+.N ACK
+@*/
+int MPI_Probe(int src, int tag, MPI_Comm comm, 
+	      MPI_Status *stat)
 {
 	struct _req	request;		/* request structure */
 	MPI_Request	req;			/* request */
