@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: recv.c,v 6.19 1999/11/12 05:19:31 jsquyres Exp $
+ *	$Id: recv.c,v 6.22 2000/07/10 21:28:41 arodrig6 Exp $
  *
  *	Function:	- receive a message
  *	Accepts:	- buffer
@@ -64,17 +63,40 @@ extern int lam_in_impi_irecv;
 static int fl_debug = 0;
 
 
-int
-MPI_Recv(buf, count, dtype, src, tag, comm, stat)
+/*@
+    MPI_Recv - Basic receive
 
-void			*buf;
-int			count;
-MPI_Datatype		dtype;
-int			src;
-int			tag;
-MPI_Comm		comm;
-MPI_Status		*stat;
+Input Parameters:
++ count - maximum number of elements in receive buffer (integer) 
+. dtype - datatype of each receive buffer element (handle) 
+. src - rank of source (integer) 
+. tag - message tag (integer) 
+- comm - communicator (handle) 
 
+Output Parameters:
++ buf - initial address of receive buffer (choice) 
+- stat - status object (Status), which can be the MPI constant
+'MPI_STATUS_IGNORE' if the return status is not desired
+
+Notes:
+
+The 'count' argument indicates the maximum length of a message; the actual 
+number can be determined with 'MPI_Get_count'.  
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_TYPE
+.N MPI_ERR_COUNT
+.N MPI_ERR_TAG
+.N MPI_ERR_RANK
+
+.N ACK
+@*/
+int MPI_Recv(void *buf, int count, MPI_Datatype dtype, 
+	     int src, int tag, MPI_Comm comm, MPI_Status *stat)
 {
 	int		err;
 	int		staterr;		/* error in status */
@@ -149,7 +171,7 @@ MPI_Status		*stat;
 #endif
 	DBUG("NOT AN IMPI PROXY IRECEIVE\n");
 
-#ifdef SHORTCIRCUIT
+#if SHORTCIRCUIT
 	if (lam_c2c && lam_rq_nactv == 0) {
 		if (comm == MPI_COMM_NULL) {
 			return(lam_mkerr(MPI_ERR_COMM, 0));
