@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/NJN
  *
- *	$Id: reduce.c,v 6.4 1999/08/04 21:43:50 kmeyer1 Exp $
+ *	$Id: reduce.c,v 6.7 2000/10/17 12:11:30 jsquyres Exp $
  *
  *	Function:	- reduce values to root
  *	Accepts:	- send buffer
@@ -52,30 +51,66 @@
 #include <mpisys.h>
 #include <rpisys.h>
 #include <terror.h>
+#include <impi.h>
 
-/*
- * external functions
- */
-extern void		lam_dtcpy();
 
 /*
  * local functions
  */
-static int		reduce_lin();
-static int		reduce_log();
+static int reduce_lin(void *sbuf, void *rbuf, int count, MPI_Datatype dtype,
+		      MPI_Op op, int root, MPI_Comm comm);
+static int reduce_log(void *sbuf, void *rbuf, int count, MPI_Datatype dtype,
+		      MPI_Op op, int root, MPI_Comm comm);
 
 
-int
-MPI_Reduce(sbuf, rbuf, count, dtype, op, root, comm)
+/*@
 
-void			*sbuf;
-void			*rbuf;
-int			count;
-MPI_Datatype		dtype;
-MPI_Op			op;
-int			root;
-MPI_Comm		comm;
+MPI_Reduce - Reduces values on all processes to a single value
 
+Input Parameters:
++ sbuf - address of send buffer (choice) 
+. count - number of elements in send buffer (integer) 
+. dtype - data type of elements of send buffer (handle) 
+. op - reduce operation (handle) 
+. root - rank of root process (integer) 
+- comm - communicator (handle) 
+
+Output Parameter:
+. rbuf - address of receive buffer (choice, 
+significant only at 'root') 
+
+.N IMPI_YES
+
+Algorithm:
+
+If there are 4 or less ranks involved, the root loops over receiving
+from each rank, and then performs the final reduction locally.  
+
+If there are more than 4 ranks involved, a tree-based algorithm is
+used to collate the reduced data at the root (the data is reduced at
+each parent in the tree so that the reduction operations are actaully
+distributed).
+
+.N fortran
+
+.N collops
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_INTERCOMM
+.N MPI_ERR_IMPI
+.N MPI_ERR_COUNT
+.N MPI_ERR_TYPE
+.N MPI_ERR_BUFFER
+.N MPI_ERR_BUFFER_ALIAS
+.N MPI_ERR_ROOT
+
+.N ACK
+@*/
+int MPI_Reduce(void *sbuf, void* rbuf, int count, 
+	       MPI_Datatype dtype, MPI_Op op, int root, 
+	       MPI_Comm comm)
 {
 	int		size;			/* group size */
 	int		err;			/* error code */
@@ -113,16 +148,6 @@ MPI_Comm		comm;
 				lam_mkerr(MPI_ERR_OP, 0)));
 	}
 
-#if LAM_WANT_IMPI
-
-	/* Remove this when IMPI collectives are implemented */
-
-        if (LAM_IS_IMPI(comm)) {
-	  return lam_err_comm(comm, MPI_ERR_COMM, 0, 
-			      "Collectives not yet implemented on IMPI communicators");
-	}
-#endif
-
 	LAM_TRACE(lam_tr_cffstart(BLKMPIREDUCE));
 /*
  * Remember required parameters.
@@ -131,6 +156,18 @@ MPI_Comm		comm;
 
 	lam_setparam(BLKMPIREDUCE, root | (p->gps_grank << 16),
 				(p->gps_node << 16) | p->gps_idx);
+
+#if LAM_WANT_IMPI
+	/* The IMPI case must be before the 0 count optimization -- if
+           it's an IMPI communicator, we must do the whole IMPI
+           algorithm */
+
+        if (LAM_IS_IMPI(comm)) {
+	  err = IMPI_Reduce(sbuf, rbuf, count, dtype, op, root, comm);
+	  lam_resetfunc_m(BLKMPIREDUCE);
+	  return err;
+	}
+#endif
 /*
  * Check for zero count case.
  */
@@ -161,16 +198,8 @@ MPI_Comm		comm;
  *	Returns:	- MPI_SUCCESS or error code
  */
 static int
-reduce_lin(sbuf, rbuf, count, dtype, op, root, comm)
-
-void			*sbuf;
-void			*rbuf;
-int			count;
-MPI_Datatype		dtype;
-MPI_Op			op;
-int			root;
-MPI_Comm		comm;
-
+reduce_lin(void *sbuf, void *rbuf, int count, MPI_Datatype dtype,
+	   MPI_Op op, int root, MPI_Comm comm)
 {
 	int		i;			/* favourite index */
 	int		size;			/* group size */
@@ -276,16 +305,8 @@ MPI_Comm		comm;
  *	Returns:	- MPI_SUCCESS or error code
  */
 static int
-reduce_log(sbuf, rbuf, count, dtype, op, root, comm)
-
-void			*sbuf;
-void			*rbuf;
-int			count;
-MPI_Datatype		dtype;
-MPI_Op			op;
-int			root;
-MPI_Comm		comm;
-
+reduce_log(void *sbuf, void *rbuf, int count, MPI_Datatype dtype,
+	   MPI_Op op, int root, MPI_Comm comm)
 {
 	int		i;			/* favourite index */
 	int		size;			/* group size */
