@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD/JRV
  *
- *	$Id: reducescatter.c,v 6.3 1999/08/04 21:43:51 kmeyer1 Exp $
+ *	$Id: reducescatter.c,v 6.4 1999/12/31 21:27:36 jsquyres Exp $
  *
  *	Function:	- reduce and scatter data to all processes
  *	Accepts:	- send buffer
@@ -50,16 +49,44 @@
 #include <mpisys.h>
 #include <terror.h>
 
-int
-MPI_Reduce_scatter(sbuf, rbuf, rcounts, dtype, op, comm)
+/*@
 
-void			*sbuf;
-void			*rbuf;
-int			*rcounts;
-MPI_Datatype		dtype;
-MPI_Op			op;
-MPI_Comm		comm;
+MPI_Reduce_scatter - Combines values and scatters the results
 
+Input Parameters:
++ sbuf - starting address of send buffer (choice) 
+. rcounts - integer array specifying the 
+number of elements in result distributed to each process.
+Array must be identical on all calling processes. 
+. dtype - data type of elements of input buffer (handle) 
+. op - operation (handle) 
+- comm - communicator (handle) 
+
+Output Parameter:
+. rbuf - starting address of receive buffer (choice) 
+
+.N IMPI
+
+.N fortran
+
+.N collops
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_INTERCOMM
+.N MPI_ERR_IMPI
+.N MPI_ERR_COUNT
+.N MPI_ERR_TYPE
+.N MPI_ERR_BUFFER
+.N MPI_ERR_OP
+.N MPI_ERR_BUFFER
+.N MPI_ERR_BUFFER_ALIAS
+
+.N ACK
+@*/
+int MPI_Reduce_scatter(void *sbuf, void *rbuf, int *rcounts, 
+		       MPI_Datatype dtype, MPI_Op op, MPI_Comm comm)
 {
 	int		i;
 	int		size;			/* group size */
