@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD
  *
- *	$Id: reqfree.c,v 6.3 1999/11/12 05:19:32 jsquyres Exp $
+ *	$Id: reqfree.c,v 6.4 1999/12/31 21:27:36 jsquyres Exp $
  *
  *	Function:	- free communication request
  *	Accepts:	- ptr to request
@@ -54,11 +53,37 @@ extern int		lam_mkerr();
 extern int		_mpi_req_destroy();
 extern int		_mpi_req_end();
 
-int
-MPI_Request_free(preq)
+/*@
+    MPI_Request_free - Frees a communication request object
 
-MPI_Request		*preq;
+Input Parameter:
+. preq - communication request (handle) 
 
+Notes:
+
+This routine is normally used to free persistent requests created with
+either 'MPI_Recv_init' or 'MPI_Send_init' (and friends).  However, it
+can be used to free a request created with 'MPI_Irecv' or 'MPI_Isend'
+(and friends); in that case the user can not use the test/wait
+routines on the request.
+
+It `is` permitted to free an active request.  However, once freed, you
+can not use the request in a wait or test routine (e.g., 'MPI_Wait').
+
+'preq' is set to 'MPI_REQUEST_NULL' upon completion.
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_REQUEST
+.N MPI_ERR_ARG
+
+.see also: MPI_Isend, MPI_Irecv, MPI_Issend, MPI_Ibsend, MPI_Irsend, MPI_Recv_init, MPI_Send_init, MPI_Ssend_init, MPI_Rsend_init, MPI_Wait, MPI_Test, MPI_Waitall, MPI_Waitany, MPI_Waitsome, MPI_Testall, MPI_Testany, MPI_Testsome
+
+.N ACK
+@*/
+int MPI_Request_free(MPI_Request *preq)
 {
 	MPI_Request	req;			/* request */
 	int		err;			/* error code */
