@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	RBD/JRV
  *
- *	$Id: scatter.c,v 6.3 1999/08/04 21:43:51 kmeyer1 Exp $
+ *	$Id: scatter.c,v 6.4 1999/12/31 21:27:36 jsquyres Exp $
  *
  *	Function:	- scatters buffers from root in process rank order
  *	Accepts:	- send buffer
@@ -51,18 +50,44 @@
 #include <mpisys.h>
 #include <rpisys.h>
 
-int
-MPI_Scatter(sbuf, scount, sdtype, rbuf, rcount, rdtype, root, comm)
+/*@
 
-void			*sbuf;
-int			scount;
-MPI_Datatype		sdtype;
-void			*rbuf;
-int			rcount;
-MPI_Datatype		rdtype;
-int			root;
-MPI_Comm		comm;
+MPI_Scatter - Sends data from one task to all other tasks in a group
 
+Input Parameters:
++ sbuf - address of send buffer (choice, significant 
+only at 'root') 
+. scount - number of elements sent to each process 
+(integer, significant only at 'root') 
+. sdtype - data type of send buffer elements (significant only at 'root') 
+(handle) 
+. rcount - number of elements in receive buffer (integer) 
+. rdtype - data type of receive buffer elements (handle) 
+. root - rank of sending process (integer) 
+- comm - communicator (handle) 
+
+Output Parameter:
+. rbuf - address of receive buffer (choice) 
+
+.N IMPI
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_INTERCOMM
+.N MPI_ERR_IMPI
+.N MPI_ERR_COUNT
+.N MPI_ERR_TYPE
+.N MPI_ERR_BUFFER
+.N MPI_ERR_ROOT
+
+.N ACK
+@*/
+int MPI_Scatter(void *sbuf, int scount, MPI_Datatype sdtype, 
+		void *rbuf, int rcount, MPI_Datatype rdtype, 
+		int root, MPI_Comm comm)
 {
 	int		i;			/* favourite index */
 	int		rank;			/* my rank */
