@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD
  *
- *	$Id: sendrecvrep.c,v 6.3 1999/05/25 22:08:15 kmeyer1 Exp $
+ *	$Id: sendrecvrep.c,v 6.5 1999/12/31 23:16:43 jsquyres Exp $
  *
  *	Function:	- send and receive using same buffer
  *	Accepts:	- buffer
@@ -53,19 +52,70 @@
 #include <terror.h>
 
 
-int
-MPI_Sendrecv_replace(buf, count, dtype, dest, stag, src, rtag, comm, status)
+/*@
+    MPI_Sendrecv_replace - Sends and receives using a single buffer
 
-void			*buf;
-int			count;
-MPI_Datatype		dtype;
-int			dest;
-int			stag;
-int			src;
-int			rtag;
-MPI_Comm		comm;
-MPI_Status		*status;
+Input Parameters:
++ count - number of elements in send and receive buffer (integer) 
+. dtype - type of elements in send and receive buffer (handle) 
+. dest - rank of destination (integer) 
+. stag - send message tag (integer) 
+. src - rank of source (integer) 
+. rtag - receive message tag (integer) 
+- comm - communicator (handle) 
 
+Output Parameters:
++ buf - initial address of send and receive buffer (choice) 
+- status - status object (Status) 
+
+Notes:
+
+To dispell a common misconception: 'src' and 'dest' do not have to be
+the same.  Additionally, a common mistake when using this function is
+to mismatch the tags with the source and destination ranks, which can
+result in deadlock.
+
+This function is guaranteed not to deadlock in situations where pairs
+of blocking sends and receives may deadlock.  For example, the
+following code may deadlock if all ranks in 'MPI_COMM_WORLD' execute
+it simultaneously
+
+.vb
+  int rank, size, to, from;
+
+  MPI_Comm_rank(MPI_COMM_WORLD, &rank);
+  MPI_Comm_size(MPI_COMM_WORLD, &size);
+  to = (rank + 1) % size;
+  from = (rank + size - 1) % size;
+
+  MPI_Send(send_buffer, ..., to, tag, MPI_COMM_WORLD);
+  MPI_Recv(recv_buffer, ..., from, tag, MPI_COMM_WORLD);
+.ve
+
+If even one rank''s 'MPI_Send' blocks and never completes, the entire
+operation may deadlock.  One alternative is to use 'MPI_Sendrecv' in
+this situation because it is guaranteed not to deadlock.
+  
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_COUNT
+.N MPI_ERR_TYPE
+.N MPI_ERR_TAG
+.N MPI_ERR_RANK
+.N MPI_ERR_TRUNCATE
+.N MPI_ERR_EXHAUSTED
+
+.seealso MPI_Sendrecv
+
+.N ACK
+@*/
+int MPI_Sendrecv_replace(void *buf, int count, 
+			 MPI_Datatype dtype, int dest, int stag, 
+			 int src, int rtag, MPI_Comm comm, 
+			 MPI_Status *status)
 {
 	int		err;			/* error code */
 	int		fl_trace;		/* do tracing? */
