@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: spawn.c,v 6.16 1999/09/12 05:07:51 jsquyres Exp $
+ *	$Id: spawn.c,v 6.28 2001/01/23 22:25:06 jsquyres Exp $
  *
  *	Function:	- spawn MPI program
  *	Accepts:	- program name
@@ -71,23 +70,142 @@ static int              spawn(LIST *app, MPI_Comm comm, int cid, int *numkids,
 			      struct _gps **kids);
 static int		build_app(MPI_Comm comm, char *command, char **argv,
 				  int maxprocs, MPI_Info info, LIST **app);
-static void             set_error_codes(int err, LIST *app, int *errs, 
-					int *msg);
+static void             set_error_codes(int err, LIST *app, int *errs);
 static char 		*locate_aschema(char *filename);
 
 
+/*@
+   MPI_Comm_spawn - Spawn a dynamic MPI process
+
+Input Parameters:
++ command - Name of program to spawn (only significant at root)
+. argv - arguments to command (only significant at root)
+. maxprocs - max number of processes to start (only significant at root)
+. info - startup hints
+. root - rank of process to perform the spawn
+- comm - parent intracommunicator
+
+Output Parameters:
++ intercomm - child intercommunicator containing spawned processes
+- errcodes - one code per process
+
+Description:
+
+A group of processes can create another group of processes with
+'MPI_Comm_spawn'.  This function is a collective operation over the
+parent communicator.  The child group starts up like any MPI
+application.  The processes must begin by calling 'MPI_Init', after
+which the pre-defined communicator, 'MPI_COMM_WORLD', may be used.
+This world communicator contains only the child processes.  It is
+distinct from the 'MPI_COMM_WORLD' of the parent processes.
+ 
+'MPI_Comm_spawn_multiple' is used to manually specify a group of
+different executables and arguments to spawn.  'MPI_Comm_spawn' is
+used to specify one executable and set of arguments (although a
+LAM/MPI appschema(5) can be provided to 'MPI_Comm_spawn' via the
+"file" info key).
+ 
+Communication With Spawned Processes
+
+The natural communication mechanism between two groups is the
+intercommunicator.  The second communicator argument to
+'MPI_Comm_spawn' returns an intercommunicator whose local group
+contains the parent processes (same as the first communicator
+argument) and whose remote group contains child processes. The child
+processes can access the same intercommunicator by using the
+'MPI_Comm_get_parent' call.  The remote group size of the parent
+communicator is zero if the process was created by 'mpirun'(1) instead
+of one of the spawn functions.  Both groups can decide to merge the
+intercommunicator into an intracommunicator (with the 'MPI_Comm_merge'
+function) and take advantage of other MPI collective operations.  They
+can then use the merged intracommunicator to create new communicators
+and reach other processes in the MPI application.
+ 
+Resource Allocation
+
+As requested by users, LAM/MPI offers one MPI_Info key - "file".  The
+value of this key can be the filename of an appschema(1).  This allows
+the programmer to specify an arbitrary set of LAM CPUs or nodes to
+spawn MPI processes on.  In this case, only the appschema is used to
+spawn the application; 'command', 'argv', and 'maxprocs' are all
+ignored (even at the root).  Note that even though 'maxprocs' is
+ignored, 'errcodes' must still be an array long enough to hold an
+integer error code for every process that tried to launch, or be the
+MPI constant 'MPI_ERRCODES_IGNORE'.  Also note that
+'MPI_Comm_spawn_multiple' does `not` accept the "file" info key.  As
+such, the "file" info key to 'MPI_Comm_spawn' is mainly intended to
+spawn MPMD applications and/or specify an arbitrary number of nodes to
+run on.
+
+Also note that this "file" key is `not` portable to other MPI
+implementations; it is a LAM/MPI-specific info key.  If specifying
+exact LAM nodes or CPUs is not necessary, users should probably use
+'MPI_Comm_spawn_multiple' to make their program more portable.
+
+If the "file" info key is not used, the value of 'MPI_INFO_NULL'
+should be given for 'info' (all other keys are ignored, anyway - there
+is no harm in providing other keys).  In this case, LAM schedules the
+given number of processes onto LAM nodes by starting with CPU 0 (or
+the lowest numbered CPU), and continuing through higher CPU numbers,
+placing one process on each CPU.  If the process count is greater than
+the CPU count, the procedure repeats.
+ 
+Process Count
+
+The 'maxprocs' parameter to 'MPI_Comm_spawn' specifies the exact
+number of processes to be started.  If it is not possible to start the
+desired number of processes, 'MPI_Comm_spawn' will return an error
+code.  Note that even though 'maxprocs' is only relevant on the root,
+all ranks must have an 'errcodes' array long enough to handle an
+integer error code for every process that tries to launch, or give MPI
+constant 'MPI_ERRCODES_IGNORE' for the 'errcodes' argument.  While
+this appears to be a contradiction, it is per the MPI-2 standard.  :-\
+ 
+Frequently, an application wishes to chooses a process count so as to
+fill all processors available to a job.  MPI indicates the maximum
+number of processes recommended for a job in the pre-defined
+attribute, 'MPI_UNIVERSE_SIZE', which is cached on 'MPI_COMM_WORLD'.
+The typical usage is to subtract the value of 'MPI_UNIVERSE_SIZE' from
+the number of processes currently in the job and spawn the difference.
+LAM sets 'MPI_UNIVERSE_SIZE' to the number of CPUs in the user''s LAM
+session (as defined in the boot schema [bhost(5)] via 'lamboot'(1)).
+ 
+Locating an Executable Program
+
+The executable program file must be located on the node(s) where the
+process(es) will run.  On any node, the directories specified by the
+user''s PATH environment variable are searched to find the program.
+ 
+All MPI runtime options selected by 'mpirun'(1) in the initial
+application launch remain in effect for all child processes created by
+the spawn functions.
+
+Command-line Arguments
+
+The 'argv' parameter to 'MPI_Comm_spawn' should not contain the
+program name since it is given in the first parameter.  The command
+line that is passed to the newly launched program will be the program
+name followed by the strings in 'argv'.
+
+.N IMPI_MPI2
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_SPAWN
+.N MPI_ERR_ARG
+.N MPI_ERR_ROOT
+.N MPI_ERR_OTHER
+.N MPI_ERR_INTERN
+
+.seealso appschema(5), bhost(5), lamboot(1), MPI_Comm_get_parent(3), MPI_Comm_merge(3), MPI_Comm_spawn_multiple(3), MPI_Info_create(3), MPI_Info_set(3), MPI_Info_delete(3), MPI_Info_free(3), MPI_Init(3), mpirun(1)
+
+.N ACK
+@*/
 int
-MPI_Comm_spawn(command, argv, maxprocs, info, root, comm, intercomm, errcodes)
-
-char			*command;
-char			**argv;
-int			maxprocs;
-MPI_Info		info;
-int			root;
-MPI_Comm 		comm;
-MPI_Comm 		*intercomm;
-int			*errcodes;
-
+MPI_Comm_spawn(char* command, char** argv, int maxprocs, MPI_Info info, 
+	       int root, MPI_Comm comm, MPI_Comm *intercomm, 
+	       int *errcodes)
 {
 	MPI_Status	stat;
 	MPI_Group	kgrp;			/* child group */
@@ -98,10 +216,11 @@ int			*errcodes;
 	int		rank;			/* caller rank */
 	int		size;			/* group size */
 	int		err;			/* error code */
-	int		numkids = 0;		/* num. of children spawned */
+	int		numkids;		/* num. of children spawned */
 	int		mycid;			/* local max context ID */
 	int		cid;			/* context ID for intercomm */
-	int		*msg;			/* message buffer */
+	int		msg[3];			/* message buffer */
+	int		*ecodes = errcodes;	/* error code array */
 	int		i;
 
 	lam_initerr_m();
@@ -158,96 +277,91 @@ int			*errcodes;
 		return(lam_errfunc(comm, BLKMPICOMMSPAWN, err));
 	}
 
-	msg = malloc(sizeof(int) * (maxprocs + 3));
-
 	if (rank == root) {
 /*
  * The root does the process spawning.
  */
 		err = build_app(comm, command, argv, maxprocs, info, &app);
 		if (err != MPI_SUCCESS) {
-		    return(lam_errfunc(comm, BLKMPICOMMSPAWN, err));
+			return(lam_errfunc(comm, BLKMPICOMMSPAWN, err));
 		}
 
 		if (spawn(app, comm, cid, &numkids, &kids)) {
-		    err = lam_mkerr(MPI_ERR_SPAWN, 0);
+			err = lam_mkerr(MPI_ERR_SPAWN, 0);
 		}
 
-		set_error_codes(err, app, errcodes, msg + 3);
-		msg[0] = cid; msg[1] = numkids; msg[2] = maxprocs;
-/*
- * Free the app schema
- */
+		if (err != MPI_SUCCESS && errcodes == MPI_ERRCODES_IGNORE) {
+			ecodes = malloc(numkids*sizeof(int));
+			if (!ecodes)
+				return(lam_errfunc(comm, BLKMPICOMMSPAWN,
+					lam_mkerr(MPI_ERR_OTHER, errno)));
+		}
+
+		set_error_codes(err, app, ecodes);
 		asc_free(app);
 /*
- * Inform parent group of spawn error.
+ * Inform parent group of spawn status.
  */
-		if (err != MPI_SUCCESS) {
-			msg[0] = -1; msg[1] = err;
+		msg[0] = numkids;
+		msg[1] = cid;
+		msg[2] = err;
+		if (err == MPI_SUCCESS) {
+			err = MPI_Bcast(msg, 3, MPI_INT, root, comm);
+			if (err != MPI_SUCCESS)
+				return(lam_errfunc(comm, BLKMPICOMMSPAWN, err));
+		} else {
 			MPI_Bcast(msg, 3, MPI_INT, root, comm);
-			free((char *) msg);
+			MPI_Bcast(ecodes, numkids, MPI_INT, root, comm);
+			if (errcodes == MPI_ERRCODES_IGNORE)
+				free(ecodes);
 			return(lam_errfunc(comm, BLKMPICOMMSPAWN, err));
 		}
-	}
+	} else {
 /*
- * Broadcast the context ID for the parent-child intercommunicator and the
- * number of children spawned to the parents.  In the case of an error
- * in spawning the root broadcasted an error code.
+ * Get spawn status from root.
  */
-	err = MPI_Bcast(msg, 3, MPI_INT, root, comm);
-	if (err != MPI_SUCCESS) {
-	  free((char *) msg);
-	  return(lam_errfunc(comm, BLKMPICOMMSPAWN, err));
-	}
-/* 
- * #%$^#$%^$#^ MPI-2!!  Since maxprocs is only significant at the
- * root, we can't depend on the value that the non-root nodes give.
- * So we first have to bcast the maxprocs to all non-root nodes, and
- * *then* send array_of_errcodes.
- */
-	if (rank != root)
-	  maxprocs = msg[2];
-	err = MPI_Bcast(msg + 3, maxprocs, MPI_INT, root, comm);
-	if (err != MPI_SUCCESS) {
-	  free((char *) msg);
-	  return(lam_errfunc(comm, BLKMPICOMMSPAWN, err));
-	}
-
-	if (rank != root) {
-
-		cid = msg[0];
-		if (errcodes != MPI_ERRCODES_IGNORE)
-		  for (i = 0; i < maxprocs; i++)
-		    errcodes[i] = msg[3 + i];
-/*
- * A context ID of -1 means an error occurred in spawning so we
- * return with the error.
- */
-		if (cid == -1) {
-			err = msg[1];
-			free((char *) msg);
+		err = MPI_Bcast(msg, 3, MPI_INT, root, comm);
+		if (err != MPI_SUCCESS)
 			return(lam_errfunc(comm, BLKMPICOMMSPAWN, err));
+
+		numkids = msg[0];
+		cid = msg[1];
+		err = msg[2];
+
+		if (err != MPI_SUCCESS) {
+			if (errcodes == MPI_ERRCODES_IGNORE) {
+				ecodes = malloc(numkids*sizeof(int));
+				if (!ecodes)
+				    return(lam_errfunc(comm, BLKMPICOMMSPAWN,
+					    lam_mkerr(MPI_ERR_OTHER, errno)));
+			}
+
+			MPI_Bcast(ecodes, numkids, MPI_INT, root, comm);
+			if (errcodes == MPI_ERRCODES_IGNORE)
+				free(ecodes);
+			return(lam_errfunc(comm, BLKMPICOMMSPAWN, err));
+		} else {
+			if (errcodes != MPI_ERRCODES_IGNORE) {
+				for (i = 0; i < numkids; i++)
+					errcodes[i] = MPI_SUCCESS;
+			}
 		}
 /*
  * Allocate buffer to receive array of child GPS.
  */
-		numkids = msg[1];
 		kids = (struct _gps *)
 			malloc((unsigned) (numkids * sizeof(struct _gps)));
-		if (kids == 0) {
-		  free((char *) msg);
-		  return(lam_errfunc(comm, BLKMPICOMMSPAWN,
-				     lam_mkerr(MPI_ERR_OTHER, errno)));
-		}
+		if (kids == 0)
+			return(lam_errfunc(comm, BLKMPICOMMSPAWN,
+				lam_mkerr(MPI_ERR_OTHER, errno)));
 	}
-	free((char *) msg);
 /*
  * Broadcast the array of child GPS to parent group.
  */
 	err = MPI_Bcast(kids, numkids * sizeof(struct _gps) / sizeof(int),
 			MPI_INT, root, comm);
 	if (err != MPI_SUCCESS) {
-		free((char *) kids);
+		free(kids);
 		return(lam_errfunc(comm, BLKMPICOMMSPAWN, err));
 	}
 /*
@@ -256,7 +370,7 @@ int			*errcodes;
 	kgrp = (MPI_Group) malloc((unsigned) sizeof(struct _group) +
 					(numkids * sizeof(struct _proc *)));
 	if (kgrp == 0) {
-		free((char *) kids);
+		free(kids);
 		return(lam_errfunc(comm, BLKMPICOMMSPAWN,
 					lam_mkerr(MPI_ERR_OTHER, errno)));
 	}
@@ -265,8 +379,7 @@ int			*errcodes;
 	kgrp->g_myrank = MPI_UNDEFINED;
 	kgrp->g_refcount = 1;
 	kgrp->g_f77handle = -1;
-	kgrp->g_procs = (struct _proc **)
-				((char *) kgrp + sizeof(struct _group));
+	kgrp->g_procs = (struct _proc **)((char *)kgrp + sizeof(struct _group));
 
 	g = kids;
 	p = kgrp->g_procs;
@@ -353,14 +466,7 @@ int			*errcodes;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-spawn(app, comm, cid, numkids, kids)
-
-LIST			*app;
-MPI_Comm		comm;
-int			cid;
-int			*numkids;
-struct _gps		**kids;
-
+spawn(LIST *app, MPI_Comm comm, int cid, int *numkids, struct _gps **kids)
 {
 	struct nmsg	nhead;			/* network msg header */
 	struct _proc	**g;			/* process in group */
@@ -387,7 +493,7 @@ struct _gps		**kids;
 /*
  * Allocate combined parent and child GPS array.
  */
-	world_n = al_count(app);
+	*numkids = world_n = al_count(app);
 	world = (struct _gps *)
 		malloc((unsigned) (world_n + parent_n) * sizeof(struct _gps));
 	if (world == 0) return(LAMERROR);
@@ -417,7 +523,7 @@ struct _gps		**kids;
  * LAM/MPI programs that call MPI_Init).
  */
 	if (lam_get_mpi_world(world_n, world, worldout, 
-			      "MPI_Comm_spawn_multiple")) {
+			      "MPI_Comm_spawn")) {
 		free((char *) world);
 		return(LAMERROR);
 	}
@@ -460,7 +566,6 @@ struct _gps		**kids;
 		}
 	}
 
-	*numkids = world_n;
 	*kids = worldout;
 	return(0);
 }
@@ -478,15 +583,8 @@ struct _gps		**kids;
  *	Returns:	- MPI_SUCCESS or MPI error class
  */
 static int
-build_app(comm, command, argv, maxprocs, info, app)
-
-MPI_Comm		comm;
-char			*command;
-char			**argv;
-int			maxprocs;
-MPI_Info		info;
-LIST			**app;
-
+build_app(MPI_Comm comm, char *command, char **argv, int maxprocs, 
+	  MPI_Info info, LIST **app)
 {
     LIST		*app_sched;		/* scheduled application */
     struct apparg 	*procargv;		/* process argv */
@@ -499,6 +597,7 @@ LIST			**app;
     int			i;
     char		schema[MPI_MAX_OBJECT_NAME];
     struct appenv       *procenv;		/* process env */
+    char                **env = 0;
     
 
     if (info) {
@@ -514,7 +613,9 @@ LIST			**app;
 			"couldn't find application schema"));
 	}
 
-	*app = asc_parse(aschema, &ignore, 0);
+	asc_environment(1, NULL, &env);
+	*app = asc_parse(aschema, &ignore, env);
+	sfh_argv_free(env);
 	free(aschema);
     }
     else {
@@ -576,6 +677,10 @@ LIST			**app;
 	procenv->ape_envv = 0;
 	procenv->ape_wrkdir = 0;
 	proc.asc_env = procenv;
+/*
+ * Add on LAM_MPI_* variables and whatnot.
+ */
+	asc_environment(1, NULL, &procenv->ape_envv);
 
 /*
  * Create a new application.
@@ -616,28 +721,21 @@ LIST			**app;
  *			- array of error codes (out)
  */
 static void
-set_error_codes(err, app, errs, msg)
-
-int			err;
-LIST			*app;
-int			*errs;
-int			*msg;
-
+set_error_codes(int err, LIST *app, int *errs)
 {
 	int		i;
 	struct aschema  *p;
 
+	if (errs == 0)
+		return;
+
 	if (err) {
 		for (i = 0, p = al_top(app); p; p = al_next(app, p), i++) {
-		  if (errs != MPI_ERRCODES_IGNORE)
 		    errs[i] = lam_mkerr(MPI_ERR_SPAWN, p->asc_errno);
-		  msg[i] = lam_mkerr(MPI_ERR_SPAWN, p->asc_errno);
 		}
 	} else {
 		for (i = al_count(app) - 1; i >= 0; i--) {
-		  if (errs != MPI_ERRCODES_IGNORE)
 		    errs[i] = MPI_SUCCESS;
-		  msg[i] = MPI_SUCCESS;
 		}
 	}
 }
@@ -650,10 +748,7 @@ int			*msg;
  *	Returns:	- full pathname or NULL
  */
 static char *
-locate_aschema(filename)
-
-char			*filename;
-
+locate_aschema(char *filename)
 {
 	int		pathc = 0;		/* paths argc */
 	char		**pathv = 0;		/* paths argv */
@@ -664,12 +759,10 @@ char			*filename;
 		argvadd(&pathc, &pathv, appdir);
 	}
 	argvadd(&pathc, &pathv, "");
-	argvadd(&pathc, &pathv, "$LAMHOME/boot");
-	argvadd(&pathc, &pathv, "$TROLLIUSHOME/boot");
+	argvadd(&pathc, &pathv, "$LAMHOME/etc");
+	argvadd(&pathc, &pathv, "$TROLLIUSHOME/etc");
 
 	fullpath = sfh_path_find(filename, pathv, R_OK);
 	argvfree(pathv);
 	return(fullpath);
 }
-
-
