@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: spawnmult.c,v 6.15 1999/09/12 05:08:18 jsquyres Exp $
+ *	$Id: spawnmult.c,v 6.24 2001/01/23 13:56:09 jsquyres Exp $
  *
  *	Function:	- spawn multiple MPI programs
  *	Accepts:	- number of command lines
@@ -82,20 +81,132 @@ int                     lam_get_mpi_world(int4 world_n, struct _gps *world,
 					  char *prefix);
 
 
+/*@
+   MPI_Comm_spawn_multiple - Spawn a dynamic MPI process from multiple
+executables
+
+Input Parameters:
++ count - number of commands (only significant at root)
+. commands - commands to be executed (only significant at root)
+. argvs - arguments for commands (only significant at root)
+. maxprocs - max number of processes for each command (only significant at root)
+. infos - startup hints for each command
+. root - rank of process to perform the spawn
+- comm - parent intracommunicator
+
+Output Parameters:
++ intercomm - child intercommunicator containing spawned processes
+- errcodes - one code per process
+
+Description:
+
+A group of processes can create another group of processes with
+'MPI_Comm_spawn_multiple'.  This function is a collective operation
+over the parent communicator.  The child group starts up like any MPI
+application.  The processes must begin by calling 'MPI_Init', after
+which the pre-defined communicator, 'MPI_COMM_WORLD', may be used.
+This world communicator contains only the child processes.  It is
+distinct from the 'MPI_COMM_WORLD' of the parent processes.
+
+'MPI_Comm_spawn_multiple' is used to manually specify a group of
+different executables and arguments to spawn.  'MPI_Comm_spawn' is
+used to specify one executable and set of arguments (although a
+LAM/MPI appschema(5) can be provided to 'MPI_Comm_spawn' via the
+"file" info key).
+ 
+Communication With Spawned Processes
+
+The natural communication mechanism between two groups is the
+intercommunicator.  The second communicator argument to
+'MPI_Comm_spawn_multiple' returns an intercommunicator whose local
+group contains the parent processes (same as the first communicator
+argument) and whose remote group contains child processes. The child
+processes can access the same intercommunicator by using the
+'MPI_Comm_get_parent' call.  The remote group size of the parent
+communicator is zero if the process was created by 'mpirun'(1) instead
+of one of the spawn functions.  Both groups can decide to merge the
+intercommunicator into an intracommunicator (with the
+'MPI_Comm_merge'() function) and take advantage of other MPI
+collective operations.  They can then use the merged intracommunicator
+to create new communicators and reach other processes in the MPI
+application.
+ 
+Resource Allocation
+
+Note that no MPI_Info keys are recognized by this implementation of
+'MPI_Comm_spawn_multiple'.  To use the "file" info key to specify an
+appschema(5), use LAM''s 'MPI_Comm_spawn'.  This may be preferable to
+'MPI_Comm_spawn_multiple' because it allows the arbitrary
+specification of what nodes and/or CPUs should be used to launch jobs
+(either SPMD or MPMD).  See MPI_Comm_spawn(3) for more details.
+
+The value of 'MPI_INFO_NULL' should be given for each value in 'infos'
+(the 'infos' array is not currently examined by LAM/MPI, so specifying
+non-NULL values for the array values is not harmful).  LAM schedules
+the given number of processes onto LAM nodes by starting with CPU 0
+(or the lowest numbered CPU), and continuing through higher CPU
+numbers, placing one process on each CPU.  If the process count is
+greater than the CPU count, the procedure repeats.
+
+Process Count
+
+The 'maxprocs' array parameter to 'MPI_Comm_spawn_multiple' specifies
+the exact number of processes to be started.  If it is not possible to
+start the desired number of processes, 'MPI_Comm_spawn_multiple' will
+return an error code.  Note that even though 'maxprocs' is only
+relevant on the root, all ranks must have an 'errcodes' array long
+enough to handle an integer error code for every process that tries to
+launch, or give MPI constant 'MPI_ERRCODES_IGNORE' for the 'errcodes'
+argument.  While this appears to be a contradiction, it is per the
+MPI-2 standard.  :-\
+
+Frequently, an application wishes to chooses a process count so as to
+fill all processors available to a job.  MPI indicates the maximum
+number of processes recommended for a job in the pre-defined
+attribute, 'MPI_UNIVERSE_SIZE', which is cached on 'MPI_COMM_WORLD'.
+The typical usage is to subtract the value of 'MPI_UNIVERSE_SIZE' from
+the number of processes currently in the job and spawn the difference.
+LAM sets 'MPI_UNIVERSE_SIZE' to the number of CPUs in the user''s LAM
+session (as defined in the boot schema [bhost(5)] via 'lamboot'(1)).
+ 
+Locating an Executable Program
+
+The executable program file must be located on the node(s) where the
+process(es) will run.  On any node, the directories specified by the
+user''s PATH environment variable are searched to find the program.
+ 
+All MPI runtime options selected by 'mpirun'(1) in the initial
+application launch remain in effect for all child processes created by
+the spawn functions.
+
+Command-line Arguments
+
+The 'argvs' array parameter to 'MPI_Comm_spawn_multiple' should not
+contain the program name since it is given in the first parameter.
+The command line that is passed to the newly launched program will be
+the program name followed by the strings in corresponding entry in the
+'argvs' array.
+
+.N IMPI_MPI2
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_SPAWN
+.N MPI_ERR_ARG
+.N MPI_ERR_ROOT
+.N MPI_ERR_OTHER
+.N MPI_ERR_INTERN
+
+.seealso appschema(5), bhost(5), lamboot(1), MPI_Comm_get_parent(3), MPI_Comm_merge(3), MPI_Comm_spawn_multiple(3), MPI_Info_create(3), MPI_Info_set(3), MPI_Info_delete(3), MPI_Info_free(3), MPI_Init(3), mpirun(1)
+
+.N ACK
+@*/
 int
-MPI_Comm_spawn_multiple(count, commands, argvs,
-			maxprocs, infos, root, comm, intercomm, errcodes)
-
-int			count;
-char			**commands;
-char			***argvs;
-int			*maxprocs;
-MPI_Info		*infos;
-int			root;
-MPI_Comm 		comm;
-MPI_Comm 		*intercomm;
-int			*errcodes;
-
+MPI_Comm_spawn_multiple(int count, char **commands, char ***argvs,
+			int *maxprocs, MPI_Info *infos, int root, 
+			MPI_Comm comm, MPI_Comm *intercomm, 
+			int *errcodes)
 {
 	MPI_Status	stat;
 	MPI_Group	kgrp;			/* child group */
@@ -186,17 +297,24 @@ int			*errcodes;
 			set_error_codes(err, app, errcodes, msg + 3);
 			asc_free(app);
 		}
-/*
- * Inform parent group of spawn error.
- */
+
+		/* Send a "sad" message to the rest of the ranks in
+                   the parent group */
+
 		if (err != MPI_SUCCESS) {
-			msg[0] = -1; msg[1] = err;
+			msg[0] = -1; 
+			msg[1] = err;
 			MPI_Bcast(msg, 3, MPI_INT, root, comm);
 			free((char *) msg);
 			return(lam_errfunc(comm, BLKMPICOMMSPAWNMULT, err));
 		}
 		
-		msg[0] = cid; msg[1] = numkids; msg[2] = size;
+		/* Send a "happy" message to the rest of the ranks in
+                   the parent group */
+
+		msg[0] = cid; 
+		msg[1] = numkids; 
+		msg[2] = size;
 	}
 /*
  * Broadcast the context ID for the parent-child intercommunicator and the
@@ -223,7 +341,6 @@ int			*errcodes;
 	}
 	
 	if (rank != root) {
-
 		cid = msg[0];
 		if (errcodes != MPI_ERRCODES_IGNORE)
 		  for (i = 0; i < size; i++)
@@ -362,15 +479,8 @@ int			*errcodes;
  *	Returns:	- 0 or LAMERROR
  */
 static int
-spawn(app, comm, cid, nprocs, numkids, kids)
-
-LIST			*app;
-MPI_Comm		comm;
-int			cid;
-int			*nprocs;
-int			*numkids;
-struct _gps		**kids;
-
+spawn(LIST *app, MPI_Comm comm, int cid, int *nprocs, int *numkids,
+      struct _gps **kids)
 {
 	struct nmsg	nhead;			/* network msg header */
 	struct _proc	**g;			/* process in group */
@@ -428,7 +538,8 @@ struct _gps		**kids;
  * MPI_Comm_spawn non-MPI jobs (of course, they must eventually run
  * LAM/MPI programs that call MPI_Init).
  */
-	if (lam_get_mpi_world(world_n, world, worldout, "MPI_Comm_spawn")) {
+	if (lam_get_mpi_world(world_n, world, worldout, 
+			      "MPI_Comm_spawn_multiple")) {
 		free((char *) world);
 		return(LAMERROR);
 	}
@@ -498,14 +609,8 @@ struct _gps		**kids;
  *	Returns:	- application descriptor or 0
  */
 static LIST *
-build_app(count, commands, argvs, maxprocs, infos)
-
-int			count;
-char			**commands;
-char			***argvs;
-int			*maxprocs;
-MPI_Info		*infos;
-
+build_app(int count, char **commands, char ***argvs, int *maxprocs,
+	  MPI_Info *infos)
 {
 	LIST		*app;			/* application */
 	LIST		*app_sched;		/* scheduled application */
@@ -588,6 +693,10 @@ MPI_Info		*infos;
 		procenv->ape_envv = 0;
 		procenv->ape_wrkdir = 0;
 		proc.asc_env = procenv;
+/*
+ * Add on LAM_MPI_* variables and whatnot.
+ */
+		asc_environment(1, NULL, &procenv->ape_envv);
 
 		if (al_append(app, &proc) == 0) {
 			asc_free(app);
@@ -616,13 +725,7 @@ MPI_Info		*infos;
  *			- array of error codes (out)
  */
 static void
-set_error_codes(err, app, errs, msg)
-
-int			err;
-LIST			*app;
-int			*errs;
-int			*msg;
-
+set_error_codes(int err, LIST *app, int *errs, int *msg)
 {
 	int		i;
 	struct aschema  *p;
