@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: tcreatekey.c,v 1.0 1999/07/21 19:00:15 jsquyres Exp $
+ *	$Id: tcreatekey.c,v 1.1 2001/01/29 21:45:14 bbarrett Exp $
  *
  *	Function:	- create a datatype attribute key
  *	Accepts:	- copy function
@@ -44,6 +43,31 @@
 #include <mpi.h>
 #include <mpisys.h>
 
+/*@
+    MPI_Type_create_keyval - Create a datatype attribute key
+
+Input Parameters:
++ copyfunc - Copy callback function for type_keyval (function) 
+. delfunc - Delete callback function for type_keyval (function) 
+- extra - extra state for callback functions
+
+Output Parameter:
++ key - key value for future access (integer)
+
+.N fortran
+
+.N IMPI_MPI2
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_TYPE
+.N MPI_ERR_KEYVAL
+.N MPI_ERR_ARG
+
+.seealso MPI_Type_free_keyval(3), MPI_Type_get_attr(3), MPI_Type_set_attr(3), MPI_Type_delete_attr(3)
+
+.N WEB
+@*/
 
 int
 MPI_Type_create_keyval(cpyfunc, delfunc, key, extra)
