@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB/NJN
  *
- *	$Id: testall.c,v 6.3 1999/05/25 22:08:20 kmeyer1 Exp $
+ *	$Id: testall.c,v 6.4 1999/12/31 21:27:39 jsquyres Exp $
  *
  *	Function:	- check if all requests completed
  *	Accepts:	- # of requests
@@ -45,14 +44,38 @@
 #include <mpisys.h>
 
 
-int
-MPI_Testall(count, reqs, flag, stats)
+/*@
+    MPI_Testall - Tests for the completion of all previously initiated
+    communications
 
-int			count;
-MPI_Request		*reqs;
-int			*flag;
-MPI_Status		*stats;
+Input Parameters:
++ count - lists length (integer) 
+- reqs - array of requests (array of handles) 
 
+Output Parameters:
++ flag - (logical) 
+- stats - array of status objects (array of Status), which can be the
+MPI constant 'MPI_STATUSES_IGNORE'
+
+Notes:
+
+'flag' is true (1) only if all requests have completed.  Otherwise,
+'flag' is false (0) and neither 'reqs' nor 'stats' is modified.
+
+.N waitstatus
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COUNT
+.N MPI_ERR_ARG
+.N MPI_ERR_IN_STATUS
+
+.N ACK
+@*/
+int MPI_Testall(int count, MPI_Request *reqs, 
+		int *flag, MPI_Status *stats)
 {
 	int		i;			/* favourite index */
 	int		fl_done;		/* request done? */
