@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: testany.c,v 6.3 1999/05/25 22:08:20 kmeyer1 Exp $
+ *	$Id: testany.c,v 6.4 1999/12/31 21:27:39 jsquyres Exp $
  *
  *	Function:	- check if one request completed
  *	Accepts:	- # of requests
@@ -48,16 +47,35 @@
 #include <rpisys.h>
 
 
-int
+/*@
+    MPI_Testany - Tests for completion of any previdously initiated 
+                  communication
 
-MPI_Testany(count, reqs, index, flag, stat)
+Input Parameters:
++ count - list length (integer) 
+- reqs - array of requests (array of handles) 
 
-int			count;
-MPI_Request		*reqs;
-int			*index;
-int			*flag;
-MPI_Status		*stat;
+Output Parameters:
++ index - index of operation that completed, or 'MPI_UNDEFINED'  if none 
+  completed (integer) 
+. flag - true if one of the operations is complete (logical) 
+- stat - status object (Status), which may be the MPI constant
+'MPI_STATUS_IGNORE'
 
+.N waitstatus
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COUNT
+.N MPI_ERR_REQUEST
+.N MPI_ERR_ARG
+
+.N ACK
+@*/
+int MPI_Testany(int count, MPI_Request *reqs, 
+		int *index, int *flag, MPI_Status *stat)
 {
 	int		i;			/* favourite index */
 	int		fl_done;		/* request done flag */
