@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN
  *
- *	$Id: thindex.c,v 6.3 1999/05/25 22:08:22 kmeyer1 Exp $
+ *	$Id: thindex.c,v 6.5 1999/12/31 23:16:43 jsquyres Exp $
  *
  *	Function:	- create hindexed derived datatype
  *	Accepts:	- # blocks
@@ -46,15 +45,25 @@
 #include <mpi.h>
 #include <mpisys.h>
 
-int
-MPI_Type_hindexed(count, lengths, disps, oldtype, newtype)
+/*@
+    MPI_Type_hindexed - Creates an indexed datatype with offsets in bytes
 
-int			count;
-int			*lengths;
-MPI_Aint		*disps;
-MPI_Datatype		oldtype;
-MPI_Datatype		*newtype;
+Input Parameters:
++ count - number of blocks -- also number of entries in indices and blocklens
+. lengths - number of elements in each block (array of nonnegative integers) 
+. disps - byte displacement of each block (array of MPI_Aint) 
+- oldtype - old datatype (handle) 
 
+Output Parameter:
+. newtype - new datatype (handle) 
+
+.N Wrapper MPI_Type_created_hindexed
+
+.N ACK
+@*/
+int MPI_Type_hindexed(int count, int *lengths, 
+		      MPI_Aint *disps, MPI_Datatype oldtype, 
+		      MPI_Datatype *newtype)
 {
 	int		err;
 
