@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN/RBD
  *
- *	$Id: tindex.c,v 6.3 1999/05/25 22:08:22 kmeyer1 Exp $
+ *	$Id: tindex.c,v 6.4 1999/12/31 21:27:40 jsquyres Exp $
  *
  *	Function:	- create indexed derived datatype
  *	Accepts:	- # blocks
@@ -48,15 +47,59 @@
 #include <mpisys.h>
 #include <terror.h>
 
-int
-MPI_Type_indexed(count, lengths, disps, oldtype, newtype)
+/*@
+    MPI_Type_indexed - Creates an indexed datatype
 
-int			count;
-int			*lengths;
-int			*disps;
-MPI_Datatype		oldtype;
-MPI_Datatype		*newtype;
+Input Parameters:
++ count - number of blocks -- also number of entries in indices and blocklens
+. lengths - number of elements in each block (array of nonnegative integers) 
+. disps - displacement of each block in multiples of old_type (array of 
+  integers)
+- oldtype - old datatype (handle) 
 
+Output Parameter:
+. newtype - new datatype (handle) 
+
+Notes:
+
+The indices are displacements, and are based on a zero origin.  A common error
+is to do something like to following
+
+.vb
+    integer a(100)
+    integer blens(10), indices(10)
+    do i=1,10
+         blens(i)   = 1
+10       indices(i) = 1 + (i-1)*10
+    call MPI_TYPE_INDEXED(10,blens,indices,MPI_INTEGER,newtype,ierr)
+    call MPI_TYPE_COMMIT(newtype,ierr)
+    call MPI_SEND(a,1,newtype,...)
+.ve
+
+expecting this to send 'a(1),a(11),...' because the indices have
+values '1,11,...' (and so on).  Because these are `disps` from the
+beginning of 'a', it actually sends 'a(1+1),a(1+11),...'.
+
+If you wish to consider the displacements as indices into a Fortran
+array, consider declaring the Fortran array with a zero origin
+
+.vb
+    integer a(0:99)
+.ve
+
+.N fortran
+
+.N Errors
+.N MPI_ERR_COUNT
+.N MPI_ERR_TYPE
+.N MPI_ERR_COUNT
+.N MPI_ERR_ARG
+.N MPI_ERR_EXHAUSTED
+
+.N ACK
+@*/
+int MPI_Type_indexed(int count, int *lengths, int *disps, 
+		     MPI_Datatype oldtype, MPI_Datatype *newtype)
 {
 	MPI_Datatype	ntype;			/* new datatype */
 	int		oldext;			/* extent of oldtype */
