@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	NJN/RBD
  *
- *	$Id: tvector.c,v 6.3 1999/05/25 22:08:24 kmeyer1 Exp $
+ *	$Id: tvector.c,v 6.4 1999/12/31 21:27:41 jsquyres Exp $
  *
  *	Function:	- create vector derived datatype
  *	Accepts:	- # blocks
@@ -48,15 +47,39 @@
 #include <mpisys.h>
 #include <terror.h>
 
-int
-MPI_Type_vector(count, length, stride, oldtype, newtype)
+/*@
+    MPI_Type_vector - Creates a vector (strided) datatype
 
-int			count;
-int			length;
-int			stride;
-MPI_Datatype		oldtype;
-MPI_Datatype		*newtype;
+Input Parameters:
++ count - number of blocks (nonnegative integer) 
+. length - number of elements in each block 
+(nonnegative integer) 
+. stride - number of elements between start of each block (integer) 
+- oldtype - old datatype (handle) 
 
+Output Parameter:
+. newtype - new datatype (handle) 
+
+Notes:
+
+Once a datatype is no longer being used, it should be freed with
+'MPI_Type_free'.
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_TYPE
+.N MPI_ERR_COUNT
+.N MPI_ERR_ARG
+.N MPI_ERR_EXHAUSTED
+
+.seealso MPI_Type_free
+
+.N ACK
+@*/
+int MPI_Type_vector(int count, int length, int stride, 
+		    MPI_Datatype oldtype, MPI_Datatype *newtype)
 {
 	MPI_Datatype	ntype;			/* new datatype */
 /*
