@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD
  *
- *	$Id: unpack.c,v 6.3 1999/05/25 22:08:24 kmeyer1 Exp $
+ *	$Id: unpack.c,v 6.4 1999/12/31 21:27:42 jsquyres Exp $
  *
  *	Function:	- unpack to data buffer
  *	Accepts:	- packed buffer
@@ -47,17 +46,40 @@
 #include <mpi.h>
 #include <mpisys.h>
 
-int
-MPI_Unpack(packbuf, packsize, packpos, buf, count, dtype, comm)
+/*@
+    MPI_Unpack - Unpack a datatype into contiguous memory
 
-void			*packbuf;
-int			packsize;
-int			*packpos;
-void			*buf;
-int			count;
-MPI_Datatype		dtype;
-MPI_Comm		comm;
+Input Parameters:
++ packbuf - input buffer start (choice) 
+. packsize - size of input buffer, in bytes (integer) 
+. count - number of items to be unpacked (integer) 
+. dtype - datatype of each output data item (handle) 
+- comm - communicator for packed message (handle) 
 
+Input/Output Parameters:
+. packpos - current position in bytes (integer) 
+
+Output Parameter:
+. buf - output buffer start (choice) 
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_COMM
+.N MPI_ERR_COUNT
+.N MPI_ERR_TYPE
+.N MPI_ERR_ARG
+.N MPI_ERR_BUFFER
+.N MPI_ERR_TRUNCATE
+
+.seealso: MPI_Pack, MPI_Pack_size
+
+.N ACK
+@*/
+int MPI_Unpack(void *packbuf, int packsize, int *packpos, 
+	       void *buf, int count, MPI_Datatype dtype, 
+	       MPI_Comm comm)
 {
 	int		size;
 	char		*p;
