@@ -1,35 +1,34 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *
- *	$Id: wait.c,v 6.12 1999/11/16 01:13:16 jsquyres Exp $
+ *	$Id: wait.c,v 6.17 2001/02/03 20:24:22 jsquyres Exp $
  *
  *	Function:	- wait for completion of immediate request
  *	Accepts:	- request
@@ -81,12 +80,28 @@ The new plan (27 Sep 1999):
 
 */
 
-int
-MPI_Wait(preq, stat)
+/*@
+    MPI_Wait  - Waits for an MPI send or receive to complete
 
-MPI_Request		*preq;
-MPI_Status		*stat;
+Input Parameter:
+. preq - request (handle) 
 
+Output Parameter:
+. stat - status object (Status), which may be the MPI constant
+'MPI_STATUS_IGNORE'
+
+.N waitstatus
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_REQUEST
+.N MPI_ERR_ARG
+
+.N ACK
+@*/
+int MPI_Wait(MPI_Request *preq, MPI_Status *stat)
 {
 	MPI_Request	req;			/* request */
 	MPI_Comm	comm;			/* communicator */
@@ -131,8 +146,8 @@ MPI_Status		*stat;
 /*
  * Set to block on all the shadows that have LAM_RQFMAND set; this
  * entire request cannot finish until all of them finish (including
- * the main request, which will not have LAM_RQFMAND set).  If any
- * of the other shadows finish, that's what we call an "extra bonus".
+ * the main request).  If any of the other shadows finish, that's what
+ * we call an "extra bonus". :-)
  */
 	_mpi_req_blkclr_m();
 	flag = 0;
@@ -155,12 +170,15 @@ MPI_Status		*stat;
 	  } else if ((cur->rq_marks & LAM_RQFMAND) != 0) {
 	    _mpi_req_blkset_m(cur);
 	    num_mandatory++;
-	  }
+	  } 
 	}
 /*
  * If we don't have any mandatory requests left, it still may be
- * possible that a synchronous send ack has not been sent yet.  So do
- * an _mpi_req_advance() to send it out.
+ * possible that a synchronous send ack has not been sent yet (i.e.,
+ * this is a receive request that matched a synchronous send from the
+ * unexpected receive queue, and we never gave the sync ack shadow
+ * request a chance to go).  So do an _mpi_req_advance() to send it
+ * out. 
  */
 	if (num_mandatory == 0 && flag) {
 	  DBUG("SPECIAL CASE WAITING FOR ACK TO GO OUT\n");
@@ -173,7 +191,7 @@ MPI_Status		*stat;
  * pick up some of the non-mandatory requests in the meantime.  We'll
  * call this an "extra bonus".
  */
-	DBUG("WAITING ON MANDATORY REQUESTS\n");
+	DBUG("WAITING ON MANDATORY REQUESTS: %d\n", num_mandatory);
 	while (num_mandatory > 0) {
 	  err = _mpi_req_advance();
 	  if (err != MPI_SUCCESS)
@@ -190,10 +208,13 @@ MPI_Status		*stat;
 /*
  * If this was a mandatory request, decrease the count
  */
-	      if ((cur->rq_marks & LAM_RQFMAND) != 0)
+	      if ((cur->rq_marks & LAM_RQFMAND) != 0) {
+		DBUG("MPI_REQ_ADVANCE IN MANDATORY LOOP: found mand req done: 0x%x\n", (int) cur);
 		num_mandatory--;
+	      }
 	    }
 	  }
+	  DBUG("MANDATORY REQUEST LOOP: looping %d\n", num_mandatory);
 	}
 	DBUG("MANDATORY REQUESTS FINISHED\n");
 /*
