@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: waitany.c,v 6.9 1999/11/12 05:19:34 jsquyres Exp $
+ *	$Id: waitany.c,v 6.10 1999/12/31 21:27:42 jsquyres Exp $
  *
  *	Function:	- wait for first request to finish
  *	Accepts:	- # of requests
@@ -57,14 +56,39 @@
 extern struct _proc     *lam_impid_proc;
 
 
-int
-MPI_Waitany(count, reqs, index, stat)
+/*@
+    MPI_Waitany - Waits for any specified send or receive to complete
 
-int			count;
-MPI_Request		*reqs;
-int			*index;
-MPI_Status		*stat;
+Input Parameters:
++ count - list length (integer) 
+- reqs - array of requests (array of handles) 
 
+Output Parameters:
++ index - index of handle for operation that completed (integer).  In
+the range '0' to 'count-1'.  In Fortran, the range is '1' to 'count'.
+- stat - status object (Status), or the MPI constant
+'MPI_STATUS_IGNORE'
+
+Notes:
+
+If all of the requests are 'MPI_REQUEST_NULL', then 'index' is
+returned as 'MPI_UNDEFINED', and 'stat' is returned as an empty
+status.
+
+.N waitstatus
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_REQUEST
+.N MPI_ERR_COUNT
+.N MPI_ERR_ARG
+
+.N ACK
+@*/
+int MPI_Waitany(int count, MPI_Request *reqs, int *index, 
+		MPI_Status *stat)
 {
 	int		i;
 	int		nactive;		/* # active requests */
