@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB/NJN
  *
- *	$Id: waitsome.c,v 6.3 1999/05/25 22:08:28 kmeyer1 Exp $
+ *	$Id: waitsome.c,v 6.4 1999/12/31 21:27:42 jsquyres Exp $
  *
  *	Function:	- wait for at least one request to finish
  *	Accepts:	- # of requests
@@ -50,15 +49,43 @@
 #include <rpisys.h>
 
 
-int
-MPI_Waitsome(count, reqs, ndone, indices, stats)
+/*@
+    MPI_Waitsome - Waits for some given communications to complete
 
-int			count;
-MPI_Request		*reqs;
-int			*ndone;
-int			*indices;
-MPI_Status		*stats;
+Input Parameters:
++ incount - length of array_of_requests (integer) 
+- reqs - array of requests (array of handles) 
 
+Output Parameters:
++ ndone - number of completed requests (integer) 
+. indices - array of indices of operations that completed (array of
+integers)
+- stats - array of status objects for operations that completed (array
+of Status), or the MPI constant 'MPI_STATUSES_IGNORE'
+
+Notes:
+
+The array of indicies are in the range '0' to 'incount - 1' for C and
+in the range '1' to 'incount' for Fortran.
+
+Null requests are ignored; if all requests are null, then the routine
+returns with 'outcount' set to 'MPI_UNDEFINED'.
+
+.N waitstatus
+
+.N fortran
+
+.N Errors
+.N MPI_SUCCESS
+.N MPI_ERR_REQUEST
+.N MPI_ERR_COUNT
+.N MPI_ERR_ARG
+.N MPI_ERR_IN_STATUS
+
+.N ACK
+@*/
+int MPI_Waitsome(int count, MPI_Request* reqs, int *ndone, 
+		 int *indices, MPI_Status *stats)
 {
 	int		i;
 	int		err;			/* error code */
