@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	GDB
  *
- *	$Id: rload.c,v 6.3 1999/08/27 22:35:25 jsquyres Exp $
+ *	$Id: rload.c,v 6.4 2000/11/02 07:23:29 jsquyres Exp $
  *
  *	Function:	- loads file onto remote node
  *	Accepts:	- source node of file 
@@ -50,20 +49,10 @@
 #include <portable.h>
 #include <terror.h>
 #include <typical.h>
-
-/*
- * external functions
- */
-extern char		*_path_env_find();	/* find name in path vector */
+#include <sfh.h>
 
 int
-rload(src_node, dest_node, tag, filename)
-
-int4			src_node;
-int4			dest_node;
-int4			tag;
-CONST char		*filename;
-
+rload(int4 src_node, int4 dest_node, int4 tag, CONST char *filename)
 {
 	struct lreply	*reply;			/* loadd reply */
 	struct lreq	*req;			/* loadd request */
@@ -76,7 +65,7 @@ CONST char		*filename;
  * file in the client, not loadd.
  */
 	if ((src_node == LOCAL) || (src_node == getnodeid())) {
-		fullpath = _path_env_find(filename, R_OK | X_OK);
+		fullpath = sfh_path_env_find((char*) filename, R_OK | X_OK);
 		if (fullpath == 0) return(LAMERROR);
 		bmalloc = TRUE;
 		nhead.nh_length = strlen(fullpath) + 1;
