@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	SBD/JRV
  *
- *	$Id: tprint.c,v 6.5 1999/08/27 22:35:43 jsquyres Exp $
+ *	$Id: tprint.c,v 6.7 2000/07/06 21:07:13 jsquyres Exp $
  * 
  *	Function:	- tstdio output formatting rountines
  */
@@ -229,11 +228,11 @@ va_list			arglist;
 			case 'i':
 			case 'd':
 				if (dispmod == 'h') {
-					sarg = va_arg(arglist, short int);
+					sarg = (short int) va_arg(arglist, int);
 					ularg = sarg;
 				}
 				else if (dispmod == 'l') {
-					larg = va_arg(arglist, long int);
+					larg = (long int) va_arg(arglist, long int);
 					ularg = larg;
 				}
 				else {
@@ -255,14 +254,14 @@ va_list			arglist;
 			case 'x':
 			case 'X':
 				if (dispmod == 'h') {
-					usarg = va_arg(arglist,unsigned short);
+					usarg = (unsigned short) va_arg(arglist,unsigned int);
 					ularg = usarg;
 				}
 				else if (dispmod == 'l') {
-					ularg = va_arg(arglist, unsigned long);
+					ularg = (unsigned long) va_arg(arglist, unsigned long);
 				}
 				else {
-					uarg = va_arg(arglist, unsigned);
+					uarg = (unsigned) va_arg(arglist, unsigned);
 					ularg = uarg;
 				}
 				returnval = intformat(ularg, width, precision,
@@ -280,7 +279,7 @@ va_list			arglist;
 			case 'E':
 			case 'g':
 			case 'G':
-				darg = va_arg(arglist, double);
+				darg = (double) va_arg(arglist, double);
 				returnval = fegformat(darg, width, precision,
 						      dotf, zerof, plusf,
 						      spacef, dashf, c, fp,
@@ -292,7 +291,7 @@ va_list			arglist;
 				count += returnval;
 				break;
 			case 'c':
-				converted_arg[ 0 ] = va_arg(arglist, char);
+				converted_arg[ 0 ] = (char) va_arg(arglist, int);
 				converted_arg[ 1 ] = '\0';
 				returnval = charformat(converted_arg, width,
 						       precision, dashf, dotf,
