@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1996 The Ohio State University
  *	GDB/RBD
  *
- *	$Id: hboot.c,v 6.7 1999/09/04 21:59:39 jsquyres Exp $
+ *	$Id: hboot.c,v 6.15 2000/11/28 18:10:07 jsquyres Exp $
  *
  *	Function:	- boots OTB operating system
  */
@@ -65,8 +64,8 @@ extern struct psc	*psc_find();
 /*
  * local functions
  */
-static void		setdefaults();
-static void		setvars();
+static void setdefaults(void);
+static void setvars(int *ac, char ***av, char *var, char *opt);
 
 /*
  * local variables
@@ -82,11 +81,7 @@ static int		fl_verbose;		/* verbose option */
 
 
 int
-main(argc, argv)
-
-int			argc;
-char			*argv[];
-
+main(int argc, char *argv[], char *env[])
 {
 	FILE		*fp_psc;	/* process schema file ptr */
 	LIST		*list_psc;	/* parsed process schema list */
@@ -113,7 +108,7 @@ char			*argv[];
  * Initialize option parser.
  */
 	validopts("dhstvNVn");
-	followed("cIR");
+	followed("cIRb");
 
 	if ((do_args(&argc, argv) < 0) || (errno = (argc == 1) ? 0 : EUSAGE)) {
 	  show_help("hboot", "usage", NULL);
@@ -129,7 +124,7 @@ char			*argv[];
 /*
  * Locate the conf file.
  */
-	full = sfh_path_find(f_psc, av_psc_path, R_OK);
+	full = sfh_path_findv(f_psc, av_psc_path, R_OK, env);
 
 	if (! full) {
 		fprintf(stderr, "hboot: cannot find process schema %s: ",
@@ -161,11 +156,15 @@ char			*argv[];
 	av_topo = 0;
 
 	if (opt_taken('I')) {
-		setvars(&ac_topo, &av_topo, "$inet_topo", getparam('I'));
+	  setvars(&ac_topo, &av_topo, "$inet_topo", getparam('I'));
 	}
-
 	if (opt_taken('R')) {
-		setvars(&ac_topo, &av_topo, "$rtr_topo", getparam('R'));
+	  setvars(&ac_topo, &av_topo, "$rtr_topo", getparam('R'));
+	}
+	if (fl_debug) {
+	  setvars(&ac_topo, &av_topo, "$debug", "-d");
+	} else {
+	  setvars(&ac_topo, &av_topo, "$debug", "");
 	}
 /*
  * Parse the conf file.
@@ -215,6 +214,17 @@ char			*argv[];
 		av_cmd = 0;
 		argvadd(&ac_cmd, &av_cmd, t_tkill);
 
+		if (opt_taken('b')) {
+		  argvadd(&ac_cmd, &av_cmd, "-b");
+		  argvadd(&ac_cmd, &av_cmd, getparam('b'));
+		}
+		if (fl_debug) {
+		  printf("hboot: ");
+		  for (i = 0; i < ac_cmd; i++)
+		    printf("%s ", av_cmd[i]);
+		  printf("\n");
+		}
+
 		if (_lam_few(av_cmd)) {
 		  show_help("hboot", "tkill-fail", NULL);
 		  exit(errno);
@@ -232,7 +242,12 @@ char			*argv[];
 	  exit(errno);
 	}
 
+#if 1
+	/* Comment this out to make the TM extensions to PBS work
+           nicely -- everything will be in one session, so TM can kill
+           it when it dies. */
 	setsid();
+#endif
 
 	if (opt_taken('s')) {
 /*
@@ -321,8 +336,7 @@ char			*argv[];
  *	Function:	- sets default files and paths
  */
 static void
-setdefaults()
-
+setdefaults(void)
 {
 /*
  * prefix paths
@@ -330,9 +344,9 @@ setdefaults()
 	ac_psc_path = 0;
 	av_psc_path = 0;
 	argvadd(&ac_psc_path, &av_psc_path, "");
-	argvadd(&ac_psc_path, &av_psc_path, "$LAMHOME/boot");
-	argvadd(&ac_psc_path, &av_psc_path, "$TROLLIUSHOME/boot");
-	argvadd(&ac_psc_path, &av_psc_path, DEFPSCHEMA);
+	argvadd(&ac_psc_path, &av_psc_path, "$LAMHOME/etc");
+	argvadd(&ac_psc_path, &av_psc_path, "$TROLLIUSHOME/etc");
+	argvadd(&ac_psc_path, &av_psc_path, LAM_SYSCONFDIR);
 /*
  * tools
  */
@@ -359,13 +373,7 @@ setdefaults()
  *			- vars: $inet_topo, $rtr_topo
  */
 static void
-setvars(ac, av, var, opt)
-
-int			*ac;
-char			***av;
-char			*var;
-char			*opt;
-
+setvars(int *ac, char ***av, char *var, char *opt)
 {
 	char		*override;
 
