@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: lamboot.c,v 6.15 1999/11/11 18:02:53 jsquyres Exp $
+ *	$Id: lamboot.c,v 6.27 2001/03/01 00:14:24 jsquyres Exp $
  *
  *	Function:	- fully-connected LAM booting tool
  *			- boots Trollius on a network of UNIX hosts
@@ -51,46 +50,32 @@
 #include <net.h>
 #include <sfh.h>
 #include <terror.h>
-#include <patchlevel.h>
+#include <etc_misc.h>
+#include <mpisys.h>
+#include <boot.h>
 
 /*
  * static variables
  */
-static char		*bhost;		/* boot schema file */
-static int		fl_debug;	/* debug mode */
-static int		fl_verbose;	/* verbose mode */
-static int		nboot;		/* # nodes booted */
-static int		nrun;		/* # nodes running */
+static char *bhost;	/* boot schema file */
+static int fl_debug;	/* debug mode */
+static int fl_verbose;	/* verbose mode */
+static int nboot;	/* # nodes booted */
+static int nrun;	/* # nodes running */
 
-/*
- * external functions
- */
-extern int		_lam_few();
-extern int		bhostparse();
-extern int		lambootagent();
-
-/*
- * external variables
- */
-extern struct kio_t	_kio;
 
 /* 
  * private functions
  */
-static void		bail();
-static void		wipe();
-static char		*findbhost();
+static char *findbhost(int cmdc, char **cmdv, char **env);
+static void bail(int);
+static void wipe(void);
 
 
 int
-main(argc, argv)  
-
-int			argc;
-char			*argv[];
-
+main(int argc, char *argv[], char *env[])
 {
 	FILE		*fp;		/* boot schema file pointer */
-	int		idup;		/* index of duplicate node */
 	int		iorigin;	/* index of origin node */
 	int		badhost;	/* bad host index */
 	int		nlamnet;	/* lamnet size */
@@ -100,7 +85,7 @@ char			*argv[];
 /*
  * Parse the command line.
  */
-	validopts("dhvxHV");
+	validopts("bdhsvxHV");
 
 	if (do_args(&argc, argv)) {
 	  show_help("lamboot", "usage", NULL);
@@ -108,20 +93,8 @@ char			*argv[];
 	}
 
 	if (opt_taken('V')) {
-		printf("\nLAM %s", LAM_VERSION);
-#if LAM_WANT_IMPI
-		printf("/IMPI");
-#endif
-#if LAM_WANT_MPI2CPP
-		printf("/MPI 2 C++");
-#endif
-#if LAM_WANT_ROMIO
-		printf("/ROMIO");
-#endif
-		printf(" - University of Notre Dame\n\n");
-		printf("\tArch:\t\t%s\n", LAM_ARCH);
-		printf("\tRPI:\t\t%s\n", LAM_RPI);
-		exit(0);
+	  lam_show_version(1);
+	  exit(0);
 	}
 
 	/* Ensure that we are not root */
@@ -144,23 +117,12 @@ char			*argv[];
 	fl_debug = opt_taken('d');
 	fl_verbose = opt_taken('v') || fl_debug;
 
-	if (! opt_taken('H')) {
-		printf("\nLAM %s", LAM_VERSION);
-#if LAM_WANT_IMPI
-		printf("/IMPI");
-#endif
-#if LAM_WANT_MPI2CPP
-		printf("/MPI 2 C++");
-#endif
-#if LAM_WANT_ROMIO
-		printf("/ROMIO");
-#endif
-		printf(" - University of Notre Dame\n\n");
-	}
+	if (! opt_taken('H'))
+	  lam_show_version(0);
 /*
  * Locate the system file.
  */
-	bhost = findbhost(argc, argv);
+	bhost = findbhost(argc, argv, env);
 /*
  * Open the system file.
  */
@@ -206,14 +168,6 @@ char			*argv[];
 		}
 		exit(errno);
 	}
-/*
- * Make rudimentary check for duplicate hosts.
- */
-	if (lamnet_dups(lamnet, nlamnet, &idup)) {
-	  show_help("boot", "duplicated-host", "lamboot", 
-		    lamnet[idup].lnd_hname, NULL);
-	  exit(EINVAL);
-	}
 /*
  * Find the origin node.
  */
@@ -233,11 +187,12 @@ char			*argv[];
 /*
  * Clean up on interrupt.
  */
-	if (signal(SIGINT, bail) == SIG_ERR) lampanic("lamboot (signal)");
+	if (signal(SIGINT, bail) == SIG_ERR) 
+	  lampanic("lamboot (signal)");
 /*
  * Boot the system.
  */
-	if (lambootagent(lamnet, nlamnet, &nboot, &nrun, fl_verbose)) {
+	if (lambootagent(lamnet, nlamnet, &nboot, &nrun)) {
 
 	  /* If the localhost was not in the boot schema, we must
              print the error message here, because lambootagent() does
@@ -245,12 +200,13 @@ char			*argv[];
              help message) */
 	  /* This shouldn't happen, though, since we check for the
              local host above.  But better safe than sorry... */
+
 	  if (errno == EINVAL)
 	    show_help("boot", "no-localhost", "lamboot", bhost, NULL);
 
 	  /* lambootagent should print all other relevant error messages */
 	  
-	  bail();
+	  bail(1);
 	}
 
 	DBUG("lamboot completed successfully\n");
@@ -266,11 +222,7 @@ char			*argv[];
  *	Returns:	- full pathname of boot schema file
  */
 static char *
-findbhost(cmdc, cmdv)
-
-int			cmdc;
-char			**cmdv;
-
+findbhost(int cmdc, char **cmdv, char **env)
 {
 	char		*fname;
 	char		*full;		/* temporary for full pathname */
@@ -282,9 +234,9 @@ char			**cmdv;
 	pathc = 0;
 	pathv = 0;
 	argvadd(&pathc, &pathv, "");
-	argvadd(&pathc, &pathv, "$TROLLIUSHOME/boot");
-	argvadd(&pathc, &pathv, "$LAMHOME/boot");
-	argvadd(&pathc, &pathv, DEFPBHOST);
+	argvadd(&pathc, &pathv, "$TROLLIUSHOME/etc");
+	argvadd(&pathc, &pathv, "$LAMHOME/etc");
+	argvadd(&pathc, &pathv, LAM_SYSCONFDIR);
 /*
  * Set the boot schema file names.
  */
@@ -298,7 +250,7 @@ char			**cmdv;
 /*
  * Search the directories.
  */
-	full = sfh_path_find(fname, pathv, R_OK);
+	full = sfh_path_findv(fname, pathv, R_OK, env);
 
 	if (full == 0) {
 	  show_help("boot", "open-hostfile", "lamboot", fname, NULL);
@@ -316,8 +268,7 @@ char			**cmdv;
  *	Returns:	- does not return, exits with error code
  */
 static void
-bail()
-
+bail(int sig)
 {
 	int		err_save;	/* saved error code */
 
@@ -335,8 +286,7 @@ bail()
  *			- kills all host Trollius sessions
  */
 static void
-wipe()
-
+wipe(void)
 {
 	int		cmdn;
 	int		r;
