@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	RBD/GDB
  *
- *	$Id: recon.c,v 6.7 1999/07/13 16:48:08 jsquyres Exp $
+ *	$Id: recon.c,v 6.17 2001/03/01 00:14:19 jsquyres Exp $
  * 
  *	Function:	- LAM reconnaissance tool
  *			- tests if Trollius is bootable on the LAN
@@ -47,42 +46,33 @@
 #include <lamnet.h>
 #include <net.h>
 #include <terror.h>
+#include <boot.h>
+#include <etc_misc.h>
+#include <sfh.h>
 
 /*
  * static variables
  */
-static int		fl_debug;		/* debug mode */
-static int		fl_verbose;		/* verbose mode */
-
-/* 
- * external functions
- */
-extern char		*findpath();
-extern int		bhostparse();
-extern int		inetexec();
-extern int		_lam_few();
+static int fl_debug;		/* debug mode */
+static int fl_verbose;		/* verbose mode */
 
 /* 
  * static functions
  */
-static char		*findbhost();
+static char *findbhost(int cmdc, char **cmdv, char **env);
 
 /*
  *	main
  */
 int
-main(argc, argv)  
-
-int			argc;
-char			*argv[];
-
+main(int argc, char *argv[], char *env[])
 {
 	FILE		*fp;		/* boot schema file pointer */
 	char		*bhost;		/* boot schema filename */
 	char		**cmdv;		/* test command argv */
 	int		cmdn;		/* test command argc */
 	int		i, j, success = 1;
-	int		idup;		/* duplicate node index */
+	int		fl_fast;        /* look for .profile */
 	int		iorigin;	/* index of origin node */
 	int		r;		/* child return error code */
 	int		global_ret;	/* global return code */
@@ -99,7 +89,7 @@ char			*argv[];
 /*
  * Parse the command line.
  */
-	validopts("adhv");
+	validopts("abdhv");
 
 	if (do_args(&argc, argv)) {
 	  show_help("recon", "usage", NULL);
@@ -116,12 +106,13 @@ char			*argv[];
 	  exit(0);
 	}
 
+	fl_fast = !opt_taken('b');
 	fl_debug = opt_taken('d');
 	fl_verbose = opt_taken('v') || fl_debug;
 /* 
  * Locate the system file.
  */
-	bhost = findbhost(argc, argv);
+	bhost = findbhost(argc, argv, env);
 /*
  * Open the system file.
  */
@@ -169,15 +160,6 @@ char			*argv[];
 		exit(errno);
 	}
 	DBUG("recon: found addresses for all hosts\n");
-/*
- * Make rudimentary check for duplicate hosts.
- */
-	if (lamnet_dups(lamnet, nlamnet, &idup)) {
-	  show_help("boot", "duplicated-host", "recon", 
-		    lamnet[idup].lnd_hname, NULL);
-	  exit(EINVAL);
-	}
-	DBUG("recon: no duplicated hosts (good)\n");
 /*
  * Find the origin node.
  */
@@ -230,7 +212,8 @@ char			*argv[];
                         DBUG("(remote execution)\n");
 			r = inetexec(lamnet[i].lnd_hname,
 				     lamnet[i].lnd_uname, cmdv, 
-				     (fl_debug ? "recon" : NULL));
+				     (fl_debug ? "recon" : NULL), 
+				     fl_fast);
 		}
 
 		if (r) {
@@ -269,11 +252,7 @@ char			*argv[];
  *	Returns:	- full pathname of boot schema file
  */
 static char *
-findbhost(cmdc, cmdv)
-
-int			cmdc;
-char			**cmdv;
-
+findbhost(int cmdc, char **cmdv, char **env)
 {
 	char		*bhost;
 	char		*full;		/* temporary for full pathname */
@@ -285,9 +264,9 @@ char			**cmdv;
 	pathc = 0;
 	pathv = 0;
 	argvadd(&pathc, &pathv, "");
-	argvadd(&pathc, &pathv, "$TROLLIUSHOME/boot");
-	argvadd(&pathc, &pathv, "$LAMHOME/boot");
-	argvadd(&pathc, &pathv, DEFPBHOST);
+	argvadd(&pathc, &pathv, "$TROLLIUSHOME/etc");
+	argvadd(&pathc, &pathv, "$LAMHOME/etc");
+	argvadd(&pathc, &pathv, LAM_SYSCONFDIR);
 /*
  * Set the boot schema file names.
  */
@@ -301,7 +280,7 @@ char			**cmdv;
 /*
  * Search the directories.
  */
-	full = findpath(bhost, pathv, R_OK);
+	full = sfh_path_findv(bhost, pathv, R_OK, env);
 
 	if (full == 0) {
 	  show_help("boot", "open-hostfile", "recon", bhost, NULL);
