@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB
  *
- *	$Id: tkill.c,v 6.8 1999/07/13 16:48:38 jsquyres Exp $
+ *	$Id: tkill.c,v 6.14 2001/02/16 17:09:56 jsquyres Exp $
  *
  *	Function:	- kills OTB environment
  *			- reads process IDs from the kill file, aka
@@ -47,33 +46,32 @@
 #include <string.h>
 #include <sys/types.h>
 #include <unistd.h>
+#include <dirent.h>
 
 #include <args.h>
 #include <debug.h>
 #include <terror.h>
+#include <laminternal.h>
 
 #define TIMEOUT		10000000	/* timeout on process death */
 
+
 /*
- * external functions
+ * global variables
  */
-extern void		microsleep();
-extern char		*killname();
-extern char		*sockname();
-extern char		*iosockname();
-extern void		lam_cleanup_objects();
+int		fl_debug;	        /* debugging option */
+
+/*
+ * local functions
+ */
+static void lam_rmdir(char *dir);
 
 
 int
-main(argc, argv)
-
-int			argc;
-char			*argv[];
-
+main(int argc, char *argv[])
 {
 	FILE		*fp_kill;	/* kill file ptr */
 	int		fd_kill;	/* kill file desc. */
-	int		fl_debug;	/* debugging option */
 	int		fl_pretend;	/* pretend option */
 	int		fl_verbose;	/* verbose option */
 	int		n;		/* favourite counter */
@@ -82,14 +80,13 @@ char			*argv[];
 	char		*f_kill;	/* kill file */
 	char		*f_sock;	/* socket file */
 	char		*f_iosock;	/* io daemon socket file */
-	char		syscmd[256];	/* system command */
 	char            extra[1024];    /* place for ASCII messages */
 
 /*
  * Initialize option parser.
  */
 	validopts("dhvN");
-	followed("f");
+	followed("fb");
 
 	if ((do_args(&argc, argv)) || (errno = (argc == 1) ? 0 : EUSAGE)) {
 	    show_help("tkill", "usage", NULL);
@@ -112,6 +109,13 @@ char			*argv[];
 
 	fl_debug = opt_taken('d');
 	fl_verbose = opt_taken('v') || fl_debug;
+	if (opt_taken('b')) {
+	  if (fl_debug)
+	    printf("tkill: setting killname to %s\n", getparam('b'));
+	  set_killname(getparam('b'));
+	  if (fl_debug)
+	    printf("tkill: got killname back: %s\n", killname());
+	}
 /*
  * Remove the socket file.
  */
@@ -119,11 +123,12 @@ char			*argv[];
 	f_sock = sockname();
 
 	if (f_sock == 0) {
-	  show_help(NULL, "lib-call-fail", "sockname", NULL);
+	  show_help("lam-temp-files", "badness", "tkill/sockname", NULL);
 	  exit(errno);
 	}
 
 	if (!fl_pretend) {
+	    DBUG("tkill: socket file: %sd\n", f_sock);
 	    if (unlink(f_sock)) {
 		if (errno != ENOENT) {
 		  snprintf(extra, 1024, "unlink(\"%s\")", f_sock);
@@ -138,11 +143,12 @@ char			*argv[];
 	f_iosock = iosockname();
 
 	if (f_iosock == 0) {
-	  show_help(NULL, "lib-call-fail", "iosockname", NULL);
+	  show_help("lam-temp-files", "badness", "tkill/iosockname", NULL);
 	  exit(errno);
 	}
 
 	if (!fl_pretend) {
+	  DBUG("tkill: IO daemon socket file: %s\n", f_iosock);
 	    if (unlink(f_iosock)) {
 		if (errno != ENOENT) {
 		  snprintf(extra, 1024, "unlink(\"%s\")", f_iosock);
@@ -250,25 +256,15 @@ char			*argv[];
 	if (fl_pretend) {
 	    exit(0);
 	}
-/*
- * Remove the kill file.
- */
-	DBUG("tkill: removing kill file ...\n");
-
-	if (unlink(f_kill)) {
-	  snprintf(extra, 1024, "unlink(\"%s\")", f_kill);
-	  show_help(NULL, "system-call-fail", extra, NULL);
-	  exit(errno);
-	}
 /*
  * Cleanup all registered objects.
  */
 	lam_cleanup_objects();
+
 /*
- * Delete any stray temporary files.
+ * Remove the session directory.  Go remove all entries in it first.
  */
-	sprintf(syscmd, "%s %s*", RM, f_kill);
-	system(syscmd);
+	lam_rmdir(f_kill);
 
 	free(f_kill);
 	free(f_sock);
@@ -276,3 +272,106 @@ char			*argv[];
 	return(0);
 }
 
+
+
+/*
+ * Remove all files in a directory and then remove the directory
+ */
+static void
+lam_rmdir(char *dir)
+{
+  int ret, badness;
+  DIR *dp;
+  struct dirent *entry;
+  char *s, *name = strdup(dir);
+
+  s = strrchr(name, '/');
+  *s = '\0';
+  DBUG("tkill: removing session directory \"%s\"\n", name);
+
+  /* Try to go to that directory */
+
+  do {
+    ret = chdir(name);
+    if (ret == -1) {
+      if (errno == EINTR)
+	continue;
+      else if (errno == ENOENT) {
+	free(name);
+	return;
+      } else {
+	show_help(NULL, "unable-rmdir", "tkill", name, NULL);
+	free(name);
+	return;
+      }
+    }
+  } while (ret != 0);
+
+  /* First, remove all files in the session directory */
+
+  dp = opendir(name);
+  if (dp == NULL) {
+    show_help(NULL, "unable-rmdir", "tkill", name, NULL);
+    free(name);
+    return;
+  }
+  badness = 0;
+  while ((entry = readdir(dp)) != NULL) {
+    if (strcmp(entry->d_name, ".") == 0 ||
+	strcmp(entry->d_name, "..") == 0)
+      continue;
+
+    DBUG("tkill: removing extraneous file \"%s\"\n", entry->d_name);
+    do {
+      ret = remove(entry->d_name);
+      if (ret == -1) {
+	if (errno == EINTR)
+	  continue;
+	else
+	  badness++;
+      }
+    } while (ret != 0);
+  }
+  closedir(dp);
+
+  /* Did we remove everything successfully? */
+
+  if (badness != 0) {
+    show_help(NULL, "unable-rmdir", "tkill", name, NULL);
+    free(name);
+    return;
+  }
+
+  /* Move back one directory so that we can remove the target dir */
+
+  do {
+    ret = chdir("..");
+    if (ret == -1) {
+      if (errno == EINTR)
+	continue;
+      else {
+	show_help(NULL, "unable-rmdir", "tkill", name, NULL);
+	free(name);
+	return;
+      }
+    }
+  } while (ret != 0);
+
+  /* Now go remove the directory itself */
+
+  DBUG("tkill: removing the directory\n");
+  do {
+    ret = remove(name);
+    if (ret == -1) {
+      if (errno == EINTR)
+	continue;
+      else {
+	show_help(NULL, "unable-rmdir", "tkill", name, NULL);
+	free(name);
+	return;
+      }
+    }
+  } while (ret != 0);
+
+  free(name);
+}
