@@ -1,36 +1,35 @@
 /*
- *
- * Copyright 1998-1999, University of Notre Dame.
- * Authors: Jeffrey M. Squyres, Kinis L. Meyer with M. D. McNally 
- *          and Andrew Lumsdaine
- *
+ * Copyright 1998-2001, University of Notre Dame.
+ * Authors: Jeffrey M. Squyres and Arun Rodrigues with Brian Barrett,
+ *          Kinis L. Meyer, M. D. McNally, and Andrew Lumsdaine
+ * 
  * This file is part of the Notre Dame LAM implementation of MPI.
- *
- * You should have received a copy of the License Agreement for the
- * Notre Dame LAM implementation of MPI along with the software; see
- * the file LICENSE.  If not, contact Office of Research, University
- * of Notre Dame, Notre Dame, IN 46556.
- *
+ * 
+ * You should have received a copy of the License Agreement for the Notre
+ * Dame LAM implementation of MPI along with the software; see the file
+ * LICENSE.  If not, contact Office of Research, University of Notre
+ * Dame, Notre Dame, IN 46556.
+ * 
  * Permission to modify the code and to distribute modified code is
  * granted, provided the text of this NOTICE is retained, a notice that
  * the code was modified is included with the above COPYRIGHT NOTICE and
  * with the COPYRIGHT NOTICE in the LICENSE file, and that the LICENSE
  * file is distributed with the modified code.
- *
+ * 
  * LICENSOR MAKES NO REPRESENTATIONS OR WARRANTIES, EXPRESS OR IMPLIED.
  * By way of example, but not limitation, Licensor MAKES NO
  * REPRESENTATIONS OR WARRANTIES OF MERCHANTABILITY OR FITNESS FOR ANY
  * PARTICULAR PURPOSE OR THAT THE USE OF THE LICENSED SOFTWARE COMPONENTS
  * OR DOCUMENTATION WILL NOT INFRINGE ANY PATENTS, COPYRIGHTS, TRADEMARKS
- * OR OTHER RIGHTS.  
- *
+ * OR OTHER RIGHTS.
+ * 
  * Additional copyrights may follow.
- *
+ * 
  *	Ohio Trollius
  *	Copyright 1997 The Ohio State University
  *	GDB/RBD
  *
- *	$Id: wipe.c,v 6.10 1999/11/11 18:02:44 jsquyres Exp $
+ *	$Id: wipe.c,v 6.25 2001/03/01 00:14:31 jsquyres Exp $
  * 
  *	Function:	- topology shutdown tool
  *			- kills Trollius on a network of OTB nodes
@@ -50,46 +49,39 @@
 #include <lamnet.h>
 #include <net.h>
 #include <terror.h>
-#include <patchlevel.h>
+#include <laminternal.h>
+#include <etc_misc.h>
+#include <boot.h>
+#include <sfh.h>
 
 /*
  * static variables
  */
-static int		fl_verbose;	/* verbose mode */
-static int		fl_debug;	/* debug mode */
-
-/*
- * external functions
- */
-extern char		*findpath();
-extern int		_lam_few();
-extern int		inetexec();
-extern int		bhostparse();
+static int fl_verbose;	/* verbose mode */
+static int fl_debug;	/* debug mode */
 
 /*
  * static functions
  */
-static char		*findbhost();
+static char *findbhost(int cmdc, char **cmdv, char **env);
+
 
 int
-main(argc, argv)
-
-int			argc;
-char			*argv[];
-
+main(int argc, char *argv[], char *env[])
 {
 	FILE		*fp;		/* boot schema file pointer */
 	char		*bhost;		/* boot schema filename */
 	char		**cmdv;		/* cmd arguments */
+	char		*batchid;	/* batch job id */
 	int		cmdn;		/* # cmd arguments */
 	int		global_ret;	/* global error status */
 	int		i;
+	int		fl_fast;        /* look for .profile */
 	int		iorigin;	/* index of origin node */
 	int		limit;		/* limit # nodes to wipe */
 	int		nlamnet;	/* lamnet size */
 	int		badhost;	/* bad host index */
 	int		r, j, success = 1;
-	int		idup;		/* duplicate node index */
 	struct lamnode	*lamnet;	/* network description array */
 
 	/* Ensure that we are not root */
@@ -102,7 +94,7 @@ char			*argv[];
 /*
  * Parse the command line.
  */
-	validopts("dhvHV");
+	validopts("bdhvHV");
 	followed("n");
 
 	if (do_args(&argc, argv)) {
@@ -120,34 +112,22 @@ char			*argv[];
 	  exit(0);
 	}
 
+	fl_fast = opt_taken('b');
 	fl_debug = opt_taken('d');
 	fl_verbose = opt_taken('v') || fl_debug;
 
 	if (opt_taken('V')) {
-		printf("\nLAM %s", LAM_VERSION);
-#if LAM_WANT_IMPI
-		printf("/IMPI");
-#endif
-#if LAM_WANT_MPI2CPP
-		printf("/MPI 2 C++");
-#endif
-#if LAM_WANT_ROMIO
-		printf("/ROMIO");
-#endif
-		printf(" - University of Notre Dame\n\n");
-		printf("\tArch:\t\t%s\n", LAM_ARCH);
-		printf("\tRPI:\t\t%s\n", LAM_RPI);
-		exit(0);
+	  lam_show_version(1);
+	  exit(0);
 	} else {
 		if (! opt_taken('H')) {
-		    printf("\nLAM %s - University of Notre Dame\n\n", 
-			   LAM_VERSION);
+		  lam_show_version(0);
 		}
 	}
 /* 
  * Locate the system file.
  */
-	bhost = findbhost(argc, argv);
+	bhost = findbhost(argc, argv, env);
 /*
  * Open the system file.
  */
@@ -193,14 +173,6 @@ char			*argv[];
 		}
 		exit(errno);
 	}
-/*
- * Make rudimentary check for duplicate hosts.
- */
-	if (lamnet_dups(lamnet, nlamnet, &idup)) {
-	  show_help("boot", "duplicated-host", "wipe", 
-		    lamnet[idup].lnd_hname, NULL);
-	  exit(EINVAL);
-	}
 /*
  * Find the origin node.
  */
@@ -215,7 +187,7 @@ char			*argv[];
 	  DBUG("wipe: origin node is %d (%s)\n", iorigin, 
 	     lamnet[iorigin].lnd_hname);
 	} else {
-	  DBUG("wipe: killing LAM from a non-member machine");
+	  DBUG("wipe: killing LAM from a non-member machine\n");
 	}
 /*
  * Build the tkill command.
@@ -233,6 +205,15 @@ char			*argv[];
 	} else {
 		limit = -1;
 	}
+/*
+ * If we're running ounder a batch system, we have to propogate the
+ * socket name to all the remote tkill instances.
+ */
+	batchid = get_batchid();
+	if (strlen(batchid) > 0) {
+	  argvadd(&cmdn, &cmdv, "-b");
+	  argvadd(&cmdn, &cmdv, batchid);
+	}
 /*
  * Loop over all host nodes.
  */
@@ -266,7 +247,8 @@ char			*argv[];
 		        DBUG("(remote execution)\n");
 			r = inetexec(lamnet[i].lnd_hname,
 				     lamnet[i].lnd_uname, cmdv, 
-				     (fl_debug ? "wipe" : NULL));
+				     (fl_debug ? "wipe" : NULL),
+				     fl_fast);
 		}
 
 		if (r) {
@@ -303,11 +285,7 @@ char			*argv[];
  *	Returns:	- full pathname of boot schema file
  */
 static char *
-findbhost(cmdc, cmdv)
-
-int			cmdc;
-char			**cmdv;
-
+findbhost(int cmdc, char **cmdv, char **env)
 {
 	char		*bhost;
 	char		*full;		/* temporary for full pathname */
@@ -319,9 +297,9 @@ char			**cmdv;
 	pathc = 0;
 	pathv = 0;
 	argvadd(&pathc, &pathv, "");
-	argvadd(&pathc, &pathv, "$TROLLIUSHOME/boot");
-	argvadd(&pathc, &pathv, "$LAMHOME/boot");
-	argvadd(&pathc, &pathv, DEFPBHOST);
+	argvadd(&pathc, &pathv, "$TROLLIUSHOME/etc");
+	argvadd(&pathc, &pathv, "$LAMHOME/etc");
+	argvadd(&pathc, &pathv, LAM_SYSCONFDIR);
 /*
  * Set the boot schema file names.
  */
@@ -335,7 +313,7 @@ char			**cmdv;
 /*
  * Search the directories.
  */
-	full = findpath(bhost, pathv, R_OK);
+	full = sfh_path_findv(bhost, pathv, R_OK, env);
 
 	if (full == 0) {
 		fprintf(stderr, "wipe: cannot locate \"%s\"\n", bhost);
